﻿using System;
using System.Collections.Generic;
using System.Text;

namespace Popolo.HVAC.HeatSource
{
  /// <summary>ターボ冷凍機</summary>
  public interface ICentrifugalChiller: ImmutableCentrifugalChiller
  {

    /// <summary>運転中か否か</summary>
    new bool IsOperating { get; set; }

    /// <summary>冷水出口温度設定値[C]を設定・取得する</summary>
    new double ChilledWaterOutletSetPointTemperature { get; set; }

    /// <summary>機器を停止させる</summary>
    void ShutOff();

    /// <summary>状態を更新する</summary>
    /// <param name="coolingWaterInletTemperature">冷却水入口温度[C]</param>
    /// <param name="chilledWaterInletTemperature">冷水入口温度[C]</param>
    /// <param name="coolingWaterFlowRate">冷水質量流量[kg/s]</param>
    /// <param name="chilledWaterFlowRate">冷却水質量流量[kg/s]</param>
    void Update
      (double coolingWaterInletTemperature, double chilledWaterInletTemperature, 
      double coolingWaterFlowRate, double chilledWaterFlowRate);

  }

  /// <summary>読み取り専用ターボ冷凍機</summary>
  public interface ImmutableCentrifugalChiller
  {

    /// <summary>運転中か否か</summary>
    bool IsOperating { get; }

    /// <summary>冷水出口温度[C]を取得する</summary>
    double ChilledWaterOutletTemperature { get; }

    /// <summary>冷水出口温度設定値[C]を取得する</summary>
    double ChilledWaterOutletSetPointTemperature { get; }

    /// <summary>冷水入口温度[C]を取得する</summary>
    double ChilledWaterInletTemperature { get; }

    /// <summary>冷却水出口温度[C]を取得する</summary>
    double CoolingWaterOutletTemperature { get; }

    /// <summary>冷却水入口温度[C]を取得する</summary>
    double CoolingWaterInletTemperature { get; }

    /// <summary>冷水流量[kg/s]を取得する</summary>
    double ChilledWaterFlowRate { get; }

    /// <summary>冷却水流量[kg/s]を取得する</summary>
    double CoolingWaterFlowRate { get; }

    /// <summary>定格冷凍能力[kW]を取得する</summary>
    double NominalCapacity { get; }

    /// <summary>定格入力[kW]を取得する</summary>
    double NominalInput { get; }

    /// <summary>定格COP[-]を取得する</summary>
    double NominalCOP { get; }

    /// <summary>容量制御下限値[-]を取得する</summary>
    double MinimumPartialLoadRatio { get; }

    /// <summary>消費電力[kW]を取得する</summary>
    double ElectricConsumption { get; }

    /// <summary>冷却負荷[kW]を取得する</summary>
    double CoolingLoad { get; }

    /// <summary>COP[-]を取得する</summary>
    double COP { get; }

    /// <summary>冷水上限流量[kg/s]を取得する</summary>
    double MaxChilledWaterFlowRate { get; }

    /// <summary>冷水下限流量比[-]を取得する</summary>
    double MinChilledWaterFlowRatio { get; }

    /// <summary>過負荷か否か</summary>
    bool IsOverLoad { get; }

  }

}
