﻿/* IHeatSourceSubSystem.cs
 * 
 * Copyright (C) 2016 E.Togashi
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

using System;
using Popolo.ThermophysicalProperty;

namespace Popolo.HVAC.SubSystem
{
  /// <summary>熱源設備サブシステム</summary>
  public interface IHeatSourceSubSystem
  {

    /// <summary>運転可能モードを取得する</summary>
    HeatSourceSystemModel.OperatingMode SelectableMode { get; }

    /// <summary>運転モードを設定・取得する</summary>
    HeatSourceSystemModel.OperatingMode Mode { get; set; }

    /// <summary>外気条件を設定・取得する</summary>
    ImmutableMoistAir OutdoorAir { get; set; }

    /// <summary>現在の日時を設定・取得する</summary>
    DateTime CurrentDateTime { get; set; }

    /// <summary>タイムステップを設定・取得する</summary>
    double TimeStep { get; set; }

    /// <summary>冷温水往温度を予測する</summary>
    /// <param name="chilledWaterFlowRate">冷水流量[kg/s]</param>
    /// <param name="hotWaterFlowRate">温水流量[kg/s]</param>
    void ForecastSupplyWaterTemperature(double chilledWaterFlowRate, double hotWaterFlowRate);

    /// <summary>状態を確定する</summary>
    void FixState();

    /// <summary>熱源サブシステムを停止させる</summary>
    void ShutOff();

    /// <summary>冷水供給が過負荷か否か</summary>
    bool IsOverLoad_C { get; }

    /// <summary>温水供給が過負荷か否か</summary>
    bool IsOverLoad_H { get; }

    /// <summary>温水還温度[C]を設定・取得する</summary>
    double HotWaterReturnTemperature { get; set; }

    /// <summary>温水往温度設定値[C]を設定・取得する</summary>
    double HotWaterSupplyTemperatureSetpoint { get; set; }

    /// <summary>温水往温度[C]を取得する</summary>
    double HotWaterSupplyTemperature { get; }

    /// <summary>温水流量[kg/s]を取得する</summary>
    double HotWaterFlowRate { get; }

    /// <summary>温水上限流量[kg/s]を取得する</summary>
    double MaxHotWaterFlowRate { get; }

    /// <summary>温水下限流量比[-]を取得する</summary>
    double MinHotWaterFlowRatio { get; }

    /// <summary>冷水還温度[C]を設定・取得する</summary>
    double ChilledWaterReturnTemperature { get; set; }

    /// <summary>冷水往温度設定値[C]を設定・取得する</summary>
    double ChilledWaterSupplyTemperatureSetpoint { get; set; }

    /// <summary>冷水往温度[C]を取得する</summary>
    double ChilledWaterSupplyTemperature { get; }

    /// <summary>冷水流量[kg/s]を設定する</summary>
    double ChilledWaterFlowRate { get; }

    /// <summary>冷水上限流量[kg/s]を取得する</summary>
    double MaxChilledWaterFlowRate { get; }

    /// <summary>冷水下限流量比[-]を取得する</summary>
    double MinChilledWaterFlowRatio { get; }

  }
}
