﻿using System;

namespace Popolo.Numerics
{
  /// <summary></summary>
  public static class FourierTransform
  {

    /// <summary></summary>
    /// <param name="x"></param>
    /// <param name="xi"></param>
    public static void FFT(double[] x, double[] xi)
    {
      //配列を2の階乗に調整
      int len2 = (int)Math.Ceiling(Math.Log(x.Length, 2));
      int len = (int)Math.Pow(2, len2);
      double[] y = new double[len];
      double[] yi = new double[len];
      x.CopyTo(y, 0);
      xi.CopyTo(yi, 0);

      //ビット反転処理
      int jj = 0;
      for (int i = 0; i < len; i++)
      {
        if (i < jj)
        {
          swap(ref y, i, jj);
          swap(ref yi, i, jj);
        }
        int m = len >> 1;
        while (1 <= m && m <= jj)
        {
          jj -= m;
          m >>= 1;
        }
        jj += m;
      }

      //Danielson-Lanczos
      int nj = 1;
      double pk = Math.PI;
      for (int i = 0; i < len2; i++)
      {
        double w = 1d;
        double wi = 0d;
        double w1 = 0;
        double w1i = pk;
        exp(ref w1, ref w1i);
        for (int j = 0; j < nj; j++)
        {
          for (int k0 = j; k0 < len; k0 += (2 * nj))
          {
            int k1 = k0 + nj;
            double wg = w;
            double wgi = wi;
            multi(ref wg, ref wgi, y[k1], yi[k1]);
            y[k1] = y[k0] - wg;
            y[k0] = y[k0] + wg;
            yi[k1] = yi[k0] - wgi;
            yi[k0] = yi[k0] + wgi;
          }
          multi(ref w, ref wi, w1, w1i);
        }
        nj *= 2;
        pk /= 2d;
      }
    }

    private static void exp(ref double x, ref double xi)
    {
      double ex = Math.Exp(x);
      x = ex * Math.Cos(xi);
      xi = ex * Math.Sin(xi);
    }

    private static void multi(ref double x, ref double xi, double y, double yi)
    {
      x = x * y - xi * yi;
      y = x * yi + y * xi;
    }

    private static void swap(ref double[] x, int a, int b)
    {
      double c = x[a];
      x[a] = x[b];
      x[b] = c;
    }

    /// <summary></summary>
    /// <param name="h"></param>
    public static void INV(double[] h) { }

  }
}
