﻿/* AirGapLayer.cs
 * 
 * Copyright (C) 2015 E.Togashi
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

using System;

using Popolo.ThermophysicalProperty;

namespace Popolo.ThermalLoad
{
  /// <summary>空気層</summary>
  [Serializable]
  public class AirGapLayer : WallLayer
  {

    /// <summary>密閉されているか否か</summary>
    public bool IsSealed { get; private set; }

    /// <summary>インスタンスを初期化する</summary>
    /// <param name="name">名称</param>
    /// <param name="isSealed">密閉されているか否か</param>
    /// <param name="thickness">壁層の厚み[m]</param>
    public AirGapLayer(string name, bool isSealed, double thickness)
    {
      //年平均として常温20C/60%程度の値を採用
      ThermalConductivity = MoistAir.GetThermalConductivity(20);
      VolSpecificHeat = MoistAir.GetSpecificHeat(0.01) * 1.2;

      IsVariableProperties = false;
      Name = name;
      Thickness = thickness;
      IsSealed = isSealed;
      if (isSealed) HeatConductance = 1 / 0.15;
      else HeatConductance = 1 / 0.07;
      HeatCapacity_B = HeatCapacity_F = 0.5 * VolSpecificHeat * Thickness * 1000;
    }

  }
}
