﻿using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Diagnostics;

using Popolo.ThermophysicalProperty;
using Popolo.Numerics;
using Popolo.Numerics.MatrixOperation;
using Popolo.HVAC.AirConditioner;
using Popolo.HVAC.HeatExchanger;
using Popolo.HVAC.HeatSource;
using Popolo.HVAC.ThermalStorage;
using Popolo.HVAC.SolarEnergy;
using Popolo.Weather;
using Popolo.HumanBody;
using Popolo.HVAC.Circuit;
using Popolo.HVAC.Circuit.ControllableFlowSolver;
using Popolo.Electric;
using Popolo.ThermalLoad;
using Popolo.HVAC.MultiplePackagedHeatPump;
using Popolo.HVAC.SubSystem;
using Popolo.HVAC;
using Popolo.BuildingOccupant;
using Popolo.MachineLearning;

using System.Runtime.Serialization.Formatters.Binary;

namespace SampleProgram
{
  class Program
  {

    static void Main(string[] args)
    {
      SHASE_HVACSystemTest("test");
    }

    #region 機械学習テスト

    private static void multiLayerPerceptronTest1()
    {
      //学習データ読み込み
      List<double[]> inputs = new List<double[]>();
      List<double[]> answers = new List<double[]>();
      using (StreamReader sReader = new StreamReader("nnInOut.csv"))
      {
        string buff1;
        while ((buff1 = sReader.ReadLine()) != null)
        {
          string[] buff2 = buff1.Split(',');
          double[] sgIn = new double[buff2.Length - 1];
          double[] sgOut = new double[1];
          for (int i = 0; i < buff2.Length - 1; i++) sgIn[i] = double.Parse(buff2[i]);
          sgOut[0] = double.Parse(buff2[buff2.Length - 1]);
          inputs.Add(sgIn);
          answers.Add(sgOut);
        }
      }

      //学習開始
      MultiLayerPerceptron nNet = new MultiLayerPerceptron(7, 1, 10, 10, 10);
      nNet.DropOutRate = 0;
      while (true)
      {
        double err = nNet.StartLearning(inputs.ToArray(), answers.ToArray(), 0.01, 500, 0);
        Console.WriteLine(err);
        if (err < 0.9) break;
      }

      //出力
      for (int i = 0; i < inputs.Count; i++)
      {
        nNet.ForwardPropagate(inputs[i]);
        Console.WriteLine(i + ": " + answers[i][0].ToString("F3") + ", " +  nNet.GetOutput(0).ToString("F3"));
      }
    }

    private static void multiLayerPerceptronTest2()
    {
      FileStream fs;

      //学習データ読み込み//MNIST数字データセットの学習
      double[][] trainInputs, trainAnswers;
      readMNISTData("mnist_train.csv", out trainInputs, out trainAnswers);

      //NN作成
      MultiLayerPerceptron nNet = new MultiLayerPerceptron(784, 1, 300);

      //NN構造読み込み
      //fs = new FileStream("nNet.bin", FileMode.Open, FileAccess.Read);
      //BinaryFormatter f = new BinaryFormatter();
      //nNet = (MultiLayerPerceptron)f.Deserialize(fs);
      //fs.Close();

      //学習開始
      nNet.DropOutRate = 0;
      for (int i = 0; i < 50; i++)
      {
        double err = nNet.StartLearning(trainInputs, trainAnswers, 1.0, 1, 0);
        Console.WriteLine(i + ": " + err);
      }

      //NN構造書き出し
      fs = new FileStream("nNet.bin", FileMode.Create, FileAccess.Write);
      BinaryFormatter bf = new BinaryFormatter();
      bf.Serialize(fs, nNet);
      fs.Close();

      //出力
      double[][] testInputs, testAnswers;
      readMNISTData("mnist_test.csv", out testInputs, out testAnswers);
      int errNum = 0;
      for (int i = 0; i < testInputs.Length; i++)
      {
        nNet.ForwardPropagate(testInputs[i]);
        if (Math.Round(nNet.GetOutput(0)) != testAnswers[i][0]) errNum++;
      }
      Console.WriteLine("Error Number: " + errNum.ToString() + " / " + testInputs.Length + "   (" + (errNum / testInputs.Length) + "%)");
    }

    private static void readMNISTData
      (string fileName, out double[][] inputs, out double[][] answers)
    {
      List<double[]> inps = new List<double[]>();
      List<double[]> anss = new List<double[]>();
      using (StreamReader sReader = new StreamReader(fileName))
      {
        string buff1;
        while ((buff1 = sReader.ReadLine()) != null)
        {
          string[] buff2 = buff1.Split(',');
          anss.Add(new double[] { 1 / (1 + Math.Exp(-double.Parse(buff2[0]))) });
          double[] buff3 = new double[784];
          for (int i = 1; i < buff2.Length; i++) buff3[i - 1] = 1 / (1 + Math.Exp(-double.Parse(buff2[i])));
          inps.Add(buff3);
        }
      }
      inputs = inps.ToArray();
      answers = anss.ToArray();
    }

    /// <summary>PPD曲線の学習</summary>
    private static void multiLayerPerceptronTest3()
    {
      //学習データ作成
      double[][] inputs = new double[71][];
      double[][] outputs = new double[71][];
      for (int i = 0; i < 71; i++)
      {
        double pmv = -3.5 + 0.1 * i;
        inputs[i] = new double[] { pmv / 3.5 };
        outputs[i] = new double[] { 0.01 * ThermalComfort.GetPPD(pmv) };
      }

      //学習開始
      MultiLayerPerceptron nNet = new MultiLayerPerceptron(1, 1, 8);

      string buff = nNet.ToString();
      nNet = new MultiLayerPerceptron(buff);

      nNet.InitializeParameters(1);
      nNet.DropOutRate = 0;
      double lRate = 1;
      double lastErr = 0;
      while (true)
      {
        double err = nNet.StartLearning(inputs, outputs, lRate, 5, 0);
        Console.WriteLine(err);
        if (err < 0.01) break;
        if (lastErr <= err) lRate *= 0.95;
        lastErr = err;
      }

      //出力
      for (int i = 0; i < 71; i++)
      {
        nNet.ForwardPropagate(inputs[i]);
        Console.WriteLine(i + ": " + outputs[i][0].ToString("F3") + ", " + nNet.GetOutput(0).ToString("F3"));
      }
    }

    #endregion

    #region オフィスワーカーテスト

    private static void officeWorkerTest(int workerNumber, double maleRate, double partRate, uint seed)
    {
      MersenneTwister rnd = new MersenneTwister(seed);
      DateTime dt = new DateTime(1999, 1, 1, 0, 0, 0);
      OfficeTenant.DaysOfWeek holidays = OfficeTenant.DaysOfWeek.Saturday | OfficeTenant.DaysOfWeek.Sunday;
      OfficeTenant.Worker[] workers = new OfficeTenant.Worker[workerNumber];
      int mNum = (int)(workerNumber * maleRate);
      int m20Num = (int)(mNum * 0.08);
      int m30Num = (int)(mNum * 0.18);
      int m40Num = (int)(mNum * 0.24);
      int m50Num = (int)(mNum * 0.22);
      int m60Num = mNum - (m20Num + m30Num + m40Num + m50Num);
      int fNum = workerNumber - mNum;
      int f20Num = (int)(fNum * 0.08);
      int f30Num = (int)(fNum * 0.18);
      int f40Num = (int)(fNum * 0.24);
      int f50Num = (int)(fNum * 0.22);
      int f60Num = fNum - (f20Num + f30Num + f40Num + f50Num);
      int index = 0;
      double oRate = 0.8;

      OfficeTenant tenant = new OfficeTenant(OfficeTenant.CategoryOfIndustry.Construction, 1, holidays, rnd.Next(), 9, 0, 18, 0, 12, 0, 13, 0);

      for (int i = 0; i < m20Num; i++)
      {
        workers[index] = new OfficeTenant.Worker(tenant, true, 25, partRate < rnd.NextDouble(), oRate, rnd);
        index++;
      }
      for (int i = 0; i < m30Num; i++)
      {
        workers[index] = new OfficeTenant.Worker(tenant, true, 35, partRate < rnd.NextDouble(), oRate, rnd);
        index++;
      }
      for (int i = 0; i < m40Num; i++)
      {
        workers[index] = new OfficeTenant.Worker(tenant, true, 45, partRate < rnd.NextDouble(), oRate, rnd);
        index++;
      }
      for (int i = 0; i < m50Num; i++)
      {
        workers[index] = new OfficeTenant.Worker(tenant, true, 55, partRate < rnd.NextDouble(), oRate, rnd);
        index++;
      }
      for (int i = 0; i < m60Num; i++)
      {
        workers[index] = new OfficeTenant.Worker(tenant, true, 65, partRate < rnd.NextDouble(), oRate, rnd);
        index++;
      }
      for (int i = 0; i < f20Num; i++)
      {
        workers[index] = new OfficeTenant.Worker(tenant, false, 25, partRate < rnd.NextDouble(), oRate, rnd);
        index++;
      }
      for (int i = 0; i < f30Num; i++)
      {
        workers[index] = new OfficeTenant.Worker(tenant, false, 35, partRate < rnd.NextDouble(), oRate, rnd);
        index++;
      }
      for (int i = 0; i < f40Num; i++)
      {
        workers[index] = new OfficeTenant.Worker(tenant, false, 45, partRate < rnd.NextDouble(), oRate, rnd);
        index++;
      }
      for (int i = 0; i < f50Num; i++)
      {
        workers[index] = new OfficeTenant.Worker(tenant, false, 55, partRate < rnd.NextDouble(), oRate, rnd);
        index++;
      }
      for (int i = 0; i < f60Num; i++)
      {
        workers[index] = new OfficeTenant.Worker(tenant, false, 65, partRate < rnd.NextDouble(), oRate, rnd);
        index++;
      }

      using (StreamWriter sWriter = new StreamWriter("officeWorkerTest.csv"))
      {
        sWriter.Write(",");
        for (int i = 0; i < 288; i++) sWriter.Write("," + dt.AddMinutes(i * 5).ToShortTimeString());
        sWriter.WriteLine();
        while (dt.Year != 2000)
        {
          if (dt.Hour == 0 && dt.Minute == 0)
          {
            sWriter.Write(dt.ToShortDateString() + "," + dt.DayOfWeek);
            for (int j = 0; j < workers.Length; j++) workers[j].UpdateDailySchedule(dt);
          }
          int stay = 0;
          for (int j = 0; j < workers.Length; j++)
          {
            workers[j].UpdateStatus(dt);
            if (workers[j].StayInOffice) stay++;
          }
          sWriter.Write("," + ((double)stay / workerNumber));
          dt = dt.AddMinutes(5);
          if (dt.Hour == 0 && dt.Minute == 0) sWriter.WriteLine();
        }
      }
    }

    #endregion

    #region 水熱源ヒートポンプテスト

    private static void waterHeatPumpTest1()
    {
      double mcEvpC = 178.3 / 60;
      double mcCndC = 216.7 / 60;
      double mcEvpH = 155.0 / 60;
      double mcCndH = 206.7 / 60;
      double qC = mcEvpC * 5 * 4.186;
      double qH = mcEvpH * 5 * 4.186;
      double[] tcd = new double[] { 20, 30, 40 };
      double[] ths = new double[] { -5, 0, 10, 15, 20, 25 };
      WaterHeatPump whp = new WaterHeatPump(62.4, mcEvpC, mcCndC, 7, 26, 13.3, 72.3, mcCndH, mcEvpH, 45, 12, 18.6);

      using (StreamWriter sWriter = new StreamWriter
        ("waterHeatPumpTest1.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行
        sWriter.Write("負荷率[-]");
        for (int i = 0; i < tcd.Length; i++) sWriter.Write("," + tcd[i] + "C（流量固定：冷却）");
        for (int i = 0; i < tcd.Length; i++) sWriter.Write("," + tcd[i] + "C（流量可変：冷却）");
        for (int i = 0; i < ths.Length; i++) sWriter.Write("," + ths[i] + "C（流量固定：加熱）");
        for (int i = 0; i < ths.Length; i++) sWriter.Write("," + ths[i] + "C（流量可変：加熱）");
        sWriter.WriteLine();
        
        for (int i = 0; i < 20; i++)
        {
          double pl = 0.05 * (i + 1);
          sWriter.Write(pl);

          //冷却運転
          double ti = 7 + 5 * pl;          
          //流量固定
          for (int j = 0; j < tcd.Length; j++)
          {
            whp.CoolWater(mcEvpC, mcCndC, ti, tcd[j]);
            if (whp.IsOverLoad || (whp.CoolingLoad / whp.MaxCoolingCapacity) < 0.5) sWriter.Write(",=na()");
            //else sWriter.Write("," + (qC * pl) / whp.EnergyConsumption);
            else sWriter.Write("," + whp.EnergyConsumption);
          }
          //流量可変
          for (int j = 0; j < tcd.Length; j++)
          {
            whp.CoolWater(mcEvpC, mcCndC * Math.Max(0.5, pl), ti, tcd[j]);
            if (whp.IsOverLoad || (whp.CoolingLoad / whp.MaxCoolingCapacity) < 0.5) sWriter.Write(",=na()");
            //else sWriter.Write("," + (qC * pl) / whp.EnergyConsumption);
            else sWriter.Write("," + whp.EnergyConsumption);
          }

          //加熱運転
          ti = 45 - 5 * pl;
          //流量固定
          for (int j = 0; j < ths.Length; j++)
          {
            whp.HeatWater(mcCndC, mcEvpC, ti, ths[j]);
            if (whp.IsOverLoad || (whp.HeatingLoad / whp.MaxHeatingCapacity) < 0.5) sWriter.Write(",=na()");
            //else sWriter.Write("," + (qH * pl) / whp.EnergyConsumption);
            else sWriter.Write("," + whp.EnergyConsumption);
          }
          //流量可変
          for (int j = 0; j < ths.Length; j++)
          {
            whp.HeatWater(mcCndC, mcEvpC * Math.Max(0.5, pl), ti, ths[j]);
            if (whp.IsOverLoad || (whp.HeatingLoad / whp.MaxHeatingCapacity) < 0.5) sWriter.Write(",=na()");
            //else sWriter.Write("," + (qH * pl) / whp.EnergyConsumption);
            else sWriter.Write("," + whp.EnergyConsumption);
          }

          sWriter.WriteLine();
        }
      }
    }

    private static void waterHeatPumpTest2()
    {
      double MAX_TSCEI = 40;
      double mEvpC = 116d / 60;
      double mCndC = 143d / 60;
      double qC = mEvpC * 5 * 4.186;
      WaterHeatPump whp = new WaterHeatPump
        (qC, mEvpC, mCndC, 17, 32, 9.4, 72.3, 206.7 / 60, 155.0 / 60, 45, 12, 18.6);

      CentrifugalPump pump = new CentrifugalPump
        (400, mCndC / 1000, 399, mCndC / 1000, CentrifugalPump.ControlMethod.MinimumPressure, 0);

      using (StreamWriter sWriter = new StreamWriter
        ("waterHeatPumpTest2.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //地中温度変化
        for (int tGND = 20; tGND < 40; tGND += 5)
        {
          sWriter.Write("地中温度=" + tGND + "C");
          for (int j = 0; j <= 10; j++) { sWriter.Write("," + (0.5 + j * 0.05)); }
          sWriter.WriteLine();
          //負荷率変化
          for (int i = 0; i <= 50; i++)
          {
            double pl = (0.5 + i * 0.01);
            double tEvpi = 17 + 5  * pl;  //100%で22C
            sWriter.Write(pl);
            //流量変化
            for (int j = 0; j <= 10; j++)
            {              
              double mCndRate = 0.5 + j * 0.05; //流量比

              Roots.ErrorFunction eFnc = delegate (double tScei)
              {
                double mc = mCndRate * mCndC;
                whp.CoolWater(mEvpC, mc, tEvpi, tScei);
                double mcc = 4.19 * mc;
                pump.UpdateState(mc * 0.001);
                double eps = 1 - Math.Exp(-12.5 / mcc);
                double qGnd = eps * mcc * (whp.CoolingWaterOutletTemperature - tGND);
                double tScei2 = whp.CoolingWaterOutletTemperature + (pump.GetElectricConsumption() - qGnd) / mcc;
                return tScei2 - tScei;
              };

              if (0 < eFnc(MAX_TSCEI)) sWriter.Write(",=na()");
              else
              {
                double ts = Roots.Bisection(eFnc, tGND, MAX_TSCEI, 1e-5, 1e-5, 30);
                if (whp.IsOverLoad) sWriter.Write(",=na()");
                else
                {
                  double ec = whp.EnergyConsumption + pump.GetElectricConsumption();
                  //sWriter.Write("," + (qC * pl) / ec);
                  sWriter.Write("," + (qC * pl) / whp.EnergyConsumption);
                  //sWriter.Write("," + whp.CoolingWaterOutletTemperature);
                }
              }
            }
            sWriter.WriteLine();
          }
        }
      }
    }

    private static void waterHeatPumpTest3()
    {
      double mcEvpC = 178.3 / 60;
      double mcCndC = 216.7 / 60;
      double mcEvpH = 155.0 / 60;
      double mcCndH = 206.7 / 60;
      double qC = mcEvpC * 5 * 4.186;
      double qH = mcEvpH * 5 * 4.186;
      double[] tcd = new double[] { 25, 27, 29, 31, 33, 35, 37, 39, 41, 43, 45, 47, 49 };
      double[] ths = new double[] { -5, -3, -1, 1, 3, 5, 7, 9, 11, 13, 15, 17, 19, 21 };
      double[] tchSP = new double[] { 5, 15, 25 };
      double[] thwSP = new double[] { 30, 40, 50 };
      double[] mRate = new double[] { 1.0, 0.5 };
      double[] pRate = new double[] { 0.8, 0.5 };
      WaterHeatPump whp = new WaterHeatPump(62.4, mcEvpC, mcCndC, 7, 26, 13.3, 72.3, mcCndH, mcEvpH, 45, 12, 18.6);
      
      using (StreamWriter sWriter = new StreamWriter
        ("waterHeatPumpTest3.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行
        sWriter.Write("冷却水温度[C]");
        for (int i = 0; i < tchSP.Length; i++) sWriter.Write("," + tchSP[i] + "C（負荷率80%-冷却水流量100%）");
        for (int i = 0; i < tchSP.Length; i++) sWriter.Write("," + tchSP[i] + "C（負荷率80%-冷却水流量50%）");
        for (int i = 0; i < tchSP.Length; i++) sWriter.Write("," + tchSP[i] + "C（負荷率50%-冷却水流量100%）");
        for (int i = 0; i < tchSP.Length; i++) sWriter.Write("," + tchSP[i] + "C（負荷率50%-冷却水流量50%）");
        sWriter.WriteLine();
        //冷却水入口温度変更
        for (int i = 0; i < tcd.Length; i++)
        {
          sWriter.Write(tcd[i]);
          //冷水流量変更
          for (int iSpy = 0; iSpy < pRate.Length; iSpy++)
          {
            //冷却流量変更
            for (int iSce = 0; iSce < mRate.Length; iSce++)
            {
              //冷水出口温度設定値変更
              for (int j = 0; j < tchSP.Length; j++)
              {
                double tchIn = tchSP[j] + pRate[iSpy] * qC / (4.186 * mcEvpC * mRate[iSpy]);
                whp.ChilledWaterSetPoint = tchSP[j];
                whp.CoolWater(mcEvpC * mRate[iSpy], mcCndC * mRate[iSce], tchIn, tcd[i]);
                if (whp.IsOverLoad) sWriter.Write(",=na()");
                else sWriter.Write("," + whp.EnergyConsumption);
              }
            }
          }
          sWriter.WriteLine();
        }

        sWriter.WriteLine();
        //タイトル行
        sWriter.Write("熱源水温度[C]");
        for (int i = 0; i < tchSP.Length; i++) sWriter.Write("," + tchSP[i] + "C（負荷率80%-熱源水流量100%）");
        for (int i = 0; i < tchSP.Length; i++) sWriter.Write("," + tchSP[i] + "C（負荷率80%-熱源水流量50%）");
        for (int i = 0; i < tchSP.Length; i++) sWriter.Write("," + tchSP[i] + "C（負荷率50%-熱源水流量100%）");
        for (int i = 0; i < tchSP.Length; i++) sWriter.Write("," + tchSP[i] + "C（負荷率50%-熱源水流量50%）");
        sWriter.WriteLine();
        //冷却水入口温度変更
        for (int i = 0; i < ths.Length; i++)
        {
          sWriter.Write(ths[i]);
          //冷水流量変更
          for (int iSpy = 0; iSpy < pRate.Length; iSpy++)
          {
            //冷却流量変更
            for (int iSce = 0; iSce < mRate.Length; iSce++)
            {
              //冷水出口温度設定値変更
              for (int j = 0; j < thwSP.Length; j++)
              {
                double thwIn = thwSP[j] - pRate[iSpy] * qH / (4.186 * mcCndH * mRate[iSpy]);
                whp.HotWaterSetPoint = thwSP[j];
                whp.HeatWater(mcCndH * mRate[iSpy], mcEvpH * mRate[iSce], thwIn, ths[i]);
                //if (whp.IsOverLoad || (whp.CoolingLoad / whp.MaxCoolingCapacity) < 0.5) sWriter.Write(",=na()");
                if (whp.IsOverLoad) sWriter.Write(",=na()");
                else sWriter.Write("," + whp.EnergyConsumption);
              }
            }
          }
          sWriter.WriteLine();
        }
      }
    }

    #endregion

    #region 地中熱テスト

    private static void groundHeatSourceTest1()
    {
      //土壌を作成
      GroundHeatSource ghs = new GroundHeatSource(5, 20, 0.2, 1, 1, 5, 40, 23, 1, 2300000);
      ghs.InitializeTemperature(20);
      ghs.TimeStep = 3600;

      double[] dbt, hrt, rad;
      bool[] fcf;
      RandomWeather wRnd = new RandomWeather(0, RandomWeather.Location.Tokyo);
      wRnd.MakeWeather(5, out dbt, out hrt, out rad, out fcf);
      Sun sun = new Sun(35.7, 139.8, 135);
      DateTime dTime = new DateTime(1999, 1, 1, 0, 0, 0);
      using (StreamWriter sWriter = new StreamWriter
        ("groundHeatSourceTest1.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        for (int i = 0; i < dbt.Length; i++)
        {
          //相当温度を計算・設定
          sun.Update(dTime);
          sun.SeparateGlobalHorizontalRadiation(rad[i], Sun.SeparationMethod.Erbs);
          ghs.SolAirTemperature = dbt[i] + 0.8 * sun.GlobalHorizontalRadiation / 23.0;

          //土壌温度を更新
          ghs.Update();

          //月初めに書き出し
          if (dTime.Day == 1 && dTime.Hour == 0)
          {
            Console.WriteLine(dTime.ToShortDateString());

            sWriter.Write(dTime.ToShortDateString());
            for (int j = 0; j < ghs.VerticalSplitNumber; j++) sWriter.Write("," + ghs.GetTemperature(0, j));
            sWriter.WriteLine();
          }
          dTime = dTime.AddHours(1);
        }
      }
    }

    private static void groundHeatSourceTest2()
    {
      //土壌を作成
      GroundHeatSource ghs = new GroundHeatSource(5, 150, 0.0875, 118, 2, 15, 31, 23, 1.53, 3030000);
      ghs.InitializeTemperature(19);
      ghs.TimeStep = 3600;
      ghs.SetLength(0, 0.01);
      ghs.SetLength(1, 0.02);
      ghs.SetLength(2, 0.03);
      ghs.SetLength(3, 0.05);
      ghs.SetLength(4, 0.10);
      ghs.SetLength(5, 0.15);
      ghs.SetLength(6, 0.20);
      ghs.SetLength(7, 0.20);
      ghs.SetLength(8, 0.30);
      ghs.SetLength(9, 0.30);
      ghs.SetLength(10, 0.50);
      ghs.SetLength(11, 0.50);
      ghs.SetLength(12, 0.50);
      ghs.SetLength(13, 1.00);
      ghs.SetLength(14, 1.14);
      ghs.SetDepth(0, 2);
      ghs.SetDepth(1, 3);
      for (int i = 2; i < ghs.VerticalSplitNumber; i++) ghs.SetDepth(i, 5);

      double[] dbt, hrt, rad;
      bool[] fcf;
      RandomWeather wRnd = new RandomWeather(0, RandomWeather.Location.Fukuoka);
      wRnd.MakeWeather( 1, out dbt, out hrt, out rad, out fcf);
      Sun sun = new Sun(33.6, 130.4, 135);
      DateTime dTime = new DateTime(1999, 1, 1, 0, 0, 0);
      using (StreamWriter sWriter = new StreamWriter
        ("groundHeatSourceTest2.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        for (int i = 0; i < dbt.Length; i++)
        {
          if(dTime.Hour == 0) Console.WriteLine(dTime.ToShortDateString());

          //相当温度を計算・設定
          sun.Update(dTime);
          sun.SeparateGlobalHorizontalRadiation(rad[i], Sun.SeparationMethod.Erbs);
          ghs.SolAirTemperature = dbt[i] + 0.8 * sun.GlobalHorizontalRadiation / 23.0;

          //サーマルレスポンス試験
          if (dTime.Year==1999 && dTime.Month == 4 && dTime.Day == 3 && dTime.Hour == 0)
            for (int j = 1; j < 25; j++) ghs.SetHeatFlow(j, 100);
          else if (dTime.Year == 1999 && dTime.Month == 4 && dTime.Day == 6 && dTime.Hour == 0)
            for (int j = 1; j < 25; j++) ghs.SetHeatFlow(j, 0);
          else if (dTime.Year == 1999 && dTime.Month == 4 && dTime.Day == 10 && dTime.Hour == 0)
            return;

          //土壌温度を更新
          ghs.Update();

          //書き出し
          if (dTime.Year == 1999 && dTime.Month == 4)
          {
            sWriter.Write(dTime.ToShortDateString() + " " + dTime.ToShortTimeString());
            for (int j = 0; j < ghs.VerticalSplitNumber; j++) sWriter.Write("," + ghs.GetTemperature(0, j));
            sWriter.WriteLine();
          }
          dTime = dTime.AddHours(1);
        }
      }
    }

    private static void groundHeatSourceTest3()
    {
      //土壌を作成
      GroundHeatSource ghs = new GroundHeatSource(2, 1, 1, 1, 0, 5, 2, 20, 99999, 3030000);
      ghs.InitializeTemperature(20);
      ghs.TimeStep = 60;

      /*ghs.SetLength(0, 0.01);
      ghs.SetLength(1, 0.01);
      ghs.SetLength(2, 0.08);
      ghs.SetLength(3, 0.10);
      ghs.SetLength(4, 0.10);
      ghs.SetLength(5, 0.10);
      ghs.SetLength(6, 0.10);
      ghs.SetLength(7, 0.10);
      ghs.SetLength(8, 0.10);
      ghs.SetLength(9, 0.10);
      ghs.SetLength(10, 0.10);
      ghs.SetLength(11, 1.10);*/
      //ghs.SetLength(3, 0.00010);

      /*ghs.SetLength(0, 0.1000);
      ghs.SetLength(1, 0.1000);
      ghs.SetLength(2, 0.6990);
      ghs.SetLength(3, 0.0010);
      ghs.SetDepth(0, 0.9990);
      ghs.SetDepth(1, 0.0005);
      ghs.SetDepth(2, 0.0005);*/
      ghs.SetDepth(0, 0.9);
      ghs.SetDepth(1, 0.1);
      ghs.SolAirTemperature = 30;
      Console.WriteLine
        ((ghs.SolAirTemperature - 20) * ghs.HeatTransferCoefficient 
        * (ghs.GroundRadius * ghs.GroundRadius - ghs.PileRadius * ghs.PileRadius) * Math.PI * 0.0036 + " MJ");

      DateTime dTime = new DateTime(1999, 1, 1, 0, 0, 0);

      //100W/m2で100時間加熱=100W/m2×1m×100h*2*3.14=62800Wh    *0.0036= 226.8MJ
      //for (int i = 0; i < ghs.VerticalSplitNumber; i++) ghs.SetHeatFlow(i, 100);
      double buff = ghs.GetHeatStorage(20);
      Console.WriteLine(ghs.GetHeatStorage(20));
      for (int i = 0; i < 60; i++)
      {
        ghs.Update();
      }
      Console.WriteLine(ghs.GetHeatStorage(20));
      //全地中温度が同じになるまで計算
      ghs.HeatTransferCoefficient = 0;
      for (int i = 0; i < ghs.VerticalSplitNumber; i++) ghs.SetHeatFlow(i, 0);
      int iter = 0;
      while (true)
      {
        Console.WriteLine(ghs.GetHeatStorage(20) - buff);

        ghs.Update();
        double t00 = ghs.GetTemperature(0, 0);
        double maxErr = 0;
        for (int i = 0; i < ghs.RadialSplitNumber; i++)
          for (int j = 0; j < ghs.VerticalSplitNumber; j++)
            maxErr = Math.Max(maxErr, Math.Abs(ghs.GetTemperature(i, j) - t00));
        if (maxErr < 1e-5) break;
        iter++;
        //Console.WriteLine(iter + " : " + maxErr.ToString("F6"));
      }
      Console.WriteLine(ghs.GetTemperature(0, 0) + "C");
    }

    #endregion

    #region 熱源サブシステムテスト

    private static void HeatSourceSubsystemTest1()
    {
      AirHeatSourceModularChillersSystem ahSystem;
      DirectFiredAbsorptionChillerSystem arSystem;
      HeatSourceSystemModel hsSystem;
      SHASE_SimulationTest.MakeHeatSourceSystem(out hsSystem, out ahSystem, out arSystem);
      ImmutableAirHeatSourceModularChillers ahpChiller = ahSystem.AirHeatSourceModularChillers;
      ImmutableDirectFiredAbsorptionChiller arChiller = arSystem.DirectFiredAbsorptionChiller;

      using (StreamWriter sWriter = new StreamWriter
        ("HeatSourceSubsystemTest1.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行
        sWriter.WriteLine("時刻,負荷,AHP電力,AHP冷水ポンプ電力,AHP温水ポンプ電力,直焚電力,直焚ガス,"
          + "冷却塔電力,直焚冷水ポンプ電力,直焚温水ポンプ電力,冷却水ポンプ電力,冷水往温度,温水往温度");

        sWriter.WriteLine("冷却運転テスト");
        hsSystem.OutdoorAir = new MoistAir(34.4, 0.0194);
        hsSystem.SetOperatingMode(0, HeatSourceSystemModel.OperatingMode.Cooling);
        hsSystem.SetOperatingMode(1, HeatSourceSystemModel.OperatingMode.Cooling);
        for (int i = 0; i <= 10; i++)
        {
          double load = (527 + 300 + 300) * (0.1 * (10 - i));
          hsSystem.ForecastSupplyWaterTemperature(load / (5 * 4.186), 12, 0, 40);
          int ahpNum = ahSystem.OperatingChillerNumber;
          sWriter.WriteLine(load +
              ", " + (ahpChiller.ElectricConsumption * ahpChiller.OperatingNumber * ahpNum) +
              ", " + (ahSystem.ChilledWaterPump.GetElectricConsumption() * ahpNum) +
              ", " + (ahSystem.HotWaterPump.GetElectricConsumption() * ahpNum) +
              ", " + arChiller.ElectricConsumption + ", " + (arChiller.FuelConsumption * 3600) +
              ", " + arSystem.CoolingTower.ElectricConsumption +
              ", " + arSystem.ChilledWaterPump.GetElectricConsumption() +
              ", " + arSystem.HotWaterPump.GetElectricConsumption() +
              ", " + arSystem.CoolingWaterPump.GetElectricConsumption());
        }

        sWriter.WriteLine("加熱運転テスト");
        hsSystem.OutdoorAir = new MoistAir(2.0, 0.0014);
        hsSystem.SetOperatingMode(0, HeatSourceSystemModel.OperatingMode.Heating);
        hsSystem.SetOperatingMode(1, HeatSourceSystemModel.OperatingMode.Heating);
        for (int i = 0; i <= 10; i++)
        {
          double load = (346 + 300 + 300) * (0.1 * (10 - i));
          hsSystem.ForecastSupplyWaterTemperature(0, 12, load / (5 * 4.186), 40);
          int ahpNum = ahSystem.OperatingChillerNumber;
          sWriter.WriteLine(load +
              ", " + (ahpChiller.ElectricConsumption * ahpChiller.OperatingNumber * ahpNum) +
              ", " + (ahSystem.ChilledWaterPump.GetElectricConsumption() * ahpNum) +
              ", " + (ahSystem.HotWaterPump.GetElectricConsumption() * ahpNum) +
              ", " + arChiller.ElectricConsumption + ", " + (arChiller.FuelConsumption * 3600) +
              ", " + arSystem.CoolingTower.ElectricConsumption +
              ", " + arSystem.ChilledWaterPump.GetElectricConsumption() +
              ", " + arSystem.HotWaterPump.GetElectricConsumption() +
              ", " + arSystem.CoolingWaterPump.GetElectricConsumption());
        }
      }
    }

    private static void HeatSourceSubsystemTest2()
    {
      double[] dLoads = new double[]
      { 16336, 14358, 11126, 2690, 4998, 19979, 35228, 39168, 25232, 2894, 5027, 13463 };
      double[] sumLRates = new double[] { 0, 0, 0, 0, 0, 0, 0,
        1.79, 9.57, 9.17, 8.97, 9.27, 9.37, 9.27, 8.97, 10.69, 8.97, 9.27, 3.89, 0.40, 0.40, 0, 0, 0 };
      double[] winLRates = new double[] { 0, 0, 0, 0, 0, 0,
        0.30, 16.99, 12.29, 8.09, 10.29, 10.49, 10.29, 8.39, 8.19, 9.09, 5.59, 0, 0, 0, 0, 0, 0, 0 };
      double[] dbTemp = new double[] { 6.3, 5.9, 10.2, 14.8, 20.5, 21.6, 26.1, 27.0, 21.8, 18.2, 12.8, 8.3 };
      double[] rHumid = new double[] { 52.8, 48.6, 62.0, 57.9, 67.0, 73.4, 75.2, 72.6, 70.3, 63.6, 58.9, 54.1 };

      AirHeatSourceModularChillersSystem ahSystem;
      DirectFiredAbsorptionChillerSystem arSystem;
      HeatSourceSystemModel hsSystem;
      SHASE_SimulationTest.MakeHeatSourceSystem(out hsSystem, out ahSystem, out arSystem);
      ImmutableAirHeatSourceModularChillers ahpChiller = ahSystem.AirHeatSourceModularChillers;
      ImmutableDirectFiredAbsorptionChiller arChiller = arSystem.DirectFiredAbsorptionChiller;

      using (StreamWriter sWriter = new StreamWriter
        ("HeatSourceSubsystemTest2.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行
        sWriter.WriteLine("時刻,負荷,AHP電力,AHP冷水ポンプ電力,AHP温水ポンプ電力,直焚電力,直焚ガス,"
          + "冷却塔電力,直焚冷水ポンプ電力,直焚温水ポンプ電力,冷却水ポンプ電力,冷水往温度,温水往温度");

        for (int i = 0; i < 12; i++)
        {
          sWriter.WriteLine((i + 1) + "月");
          //運転モード設定
          bool isSummer = (4 <= i && i <= 9);
          HeatSourceSystemModel.OperatingMode mode;
          if (isSummer) mode = HeatSourceSystemModel.OperatingMode.Cooling;
          else mode = HeatSourceSystemModel.OperatingMode.Heating;
          hsSystem.SetOperatingMode(0, mode);
          hsSystem.SetOperatingMode(1, mode);

          double aHumid =
            MoistAir.GetHumidityRatioFromDryBulbTemperatureAndRelativeHumidity(dbTemp[i], rHumid[i], 101.325);
          hsSystem.OutdoorAir = new MoistAir(dbTemp[i], aHumid);

          for (int j = 0; j < 24; j++)
          {
            double load;
            if (isSummer)
            {
              load = dLoads[i] * sumLRates[j] / 360d;  // MJ/h→kWに変換
              hsSystem.ForecastSupplyWaterTemperature(load / (5 * 4.186), 12, 0, 40);
            }
            else
            {
              load = dLoads[i] * winLRates[j] / 360d;  // MJ/h→kWに変換
              hsSystem.ForecastSupplyWaterTemperature(0, 12, load / (5 * 4.186), 40);
            }

            int ahpNum = ahSystem.OperatingChillerNumber;
            sWriter.WriteLine(j + ":00," + load + 
              ", " + (ahpChiller.ElectricConsumption * ahpChiller.OperatingNumber * ahpNum) + 
              ", " + (ahSystem.ChilledWaterPump.GetElectricConsumption() * ahpNum) + 
              ", " + (ahSystem.HotWaterPump.GetElectricConsumption() * ahpNum) + 
              ", " + arChiller.ElectricConsumption + ", " + (arChiller.FuelConsumption * 3600) + 
              ", " + arSystem.CoolingTower.ElectricConsumption +
              ", " + arSystem.ChilledWaterPump.GetElectricConsumption() + 
              ", " + arSystem.HotWaterPump.GetElectricConsumption() + 
              ", " + arSystem.CoolingWaterPump.GetElectricConsumption() + 
              ", " + hsSystem.ChilledWaterSupplyTemperature + ", " + hsSystem.HotWaterSupplyTemperature);
          }
        }
      }
    }

    private static void HeatSourceSubsystemTest3()
    {
      //時系列負荷
      double[] hLoads = new double[]
      { 0, 0, 0, 0, 0, 0, 0, 76, 407, 390, 381, 394, 398, 394, 381, 455, 381, 394, 165, 17, 17, 0, 0, 0 };

      //ターボ冷凍機の定格冷水・冷却水量[kg/s]
      const double NCH_FLOW = 500d / (12 - 7) / 4.186;
      const double NCD_FLOW = 1670d / 60;

      //ターボ冷凍機によるサブシステムの計算
      //個別機器のインスタンスを作成
      SimpleCentrifugalChiller chiller = new SimpleCentrifugalChiller(500d / 6d, 0.2, 12, 7, 37, NCH_FLOW, false);
      CentrifugalPump chPmp = new CentrifugalPump
        (150, 0.001 * NCH_FLOW, 140, 0.001 * NCH_FLOW, CentrifugalPump.ControlMethod.ConstantPressureWithInverter, 50);
      CentrifugalPump cdPmp = new CentrifugalPump
        (150, 0.001 * NCD_FLOW, 140, 0.001 * NCD_FLOW, CentrifugalPump.ControlMethod.ConstantPressureWithInverter, 50);
      CoolingTower cTower = new CoolingTower(37, 32, 27, NCD_FLOW, CoolingTower.AirFlowDirection.CrossFlow, false);
      //サブシステムを作成
      CentrifugalChillerSystem crSystem = new CentrifugalChillerSystem(chiller, chPmp, cdPmp, cTower, 1, 1);
      //熱源システムを作成
      HeatSourceSystemModel hsSystem = new HeatSourceSystemModel(new IHeatSourceSubSystem[] { crSystem });
      hsSystem.SetOperatingMode(0, HeatSourceSystemModel.OperatingMode.Cooling);
      hsSystem.SetChillingOperationSequence(0, 1);
      hsSystem.ChilledWaterSupplyTemperatureSetpoint = 7;
      hsSystem.OutdoorAir = new MoistAir(35, 0.0195);
      hsSystem.TimeStep = 3600;

      //24hの計算実行
      Console.WriteLine("冷熱供給,ターボ,冷水ポンプ,冷却水ポンプ,冷却塔");
      for (int i = 0; i < hLoads.Length; i++)
      {
        hsSystem.ForecastSupplyWaterTemperature(hLoads[i] / (4.186 * 5), 12, 0, 40);
        hsSystem.FixState();
        Console.WriteLine(hLoads[i].ToString("F0") + ", " +
          chiller.ElectricConsumption.ToString("F2") + ", " + chPmp.GetElectricConsumption().ToString("F2") + ", " +
          cdPmp.GetElectricConsumption().ToString("F2") + ", " + cTower.ElectricConsumption.ToString("F2"));
      }

      //蓄熱槽によるサブシステムの計算
      //個別機器のインスタンスを作成（冷凍機・冷水ポンプ・冷却水ポンプ・冷却塔は使い回す）
      PlateHeatExchanger pHex = new PlateHeatExchanger(500, 6, NCH_FLOW, 7, NCH_FLOW);
      MultipleStratifiedWaterTank wTank = new MultipleStratifiedWaterTank(10, 10 * 10, 0.8, 9.5, 20);
      wTank.HeatLossCoefficient = 0.001 * (0.037 / 0.05) * (10 * 10 * 6);
      CentrifugalPump chgPmp = new CentrifugalPump
        (150, 0.001 * NCH_FLOW, 140, 0.001 * NCH_FLOW, CentrifugalPump.ControlMethod.ConstantPressureWithBypass, 50);
      CentrifugalPump disPmp = new CentrifugalPump
        (150, 0.001 * NCH_FLOW, 140, 0.001 * NCH_FLOW, CentrifugalPump.ControlMethod.MinimumPressure, 50);
      //サブシステムを作成
      MultipleStratifiedWaterTankSystem wtSystem =
        new MultipleStratifiedWaterTankSystem(wTank, pHex, chiller, chPmp, cdPmp, chgPmp, disPmp, cTower, 1, 1);
      wtSystem.StorageTemperature = 5.0;
      //熱源システムを作成
      hsSystem = new HeatSourceSystemModel(new IHeatSourceSubSystem[] { wtSystem });
      hsSystem.SetOperatingMode(0, HeatSourceSystemModel.OperatingMode.Cooling);
      hsSystem.SetChillingOperationSequence(0, 1);
      hsSystem.ChilledWaterSupplyTemperatureSetpoint = 7;
      hsSystem.OutdoorAir = new MoistAir(35, 0.0195);
      hsSystem.TimeStep = 3600;

      //24hの計算を周期定常になるまで繰り返す
      Console.WriteLine("冷熱供給,ターボ,冷水ポンプ,冷却水ポンプ,冷却塔,蓄熱ポンプ,放熱ポンプ,冷熱製造,水槽温度");
      bool lastCalc = false;
      double lastST = 100;
      while (!lastCalc)
      {
        lastCalc = (Math.Abs(lastST - wTank.GetTemperature(10)) < 0.1);
        lastST = wTank.GetTemperature(10);
        for (int i = 0; i < hLoads.Length; i++)
        {
          if (i < 9 || 22 < i) wtSystem.Charging = true;
          else wtSystem.Charging = false;
          hsSystem.ForecastSupplyWaterTemperature(hLoads[i] / (4.186 * 5), 12, 0, 40);
          hsSystem.FixState();
          if (lastCalc)
          {
            Console.Write(hLoads[i].ToString("F0") + ", " +
              chiller.ElectricConsumption.ToString("F2") + ", " +
              chPmp.GetElectricConsumption().ToString("F2") + ", " +
              cdPmp.GetElectricConsumption().ToString("F2") + ", " +
              cTower.ElectricConsumption.ToString("F2") + ", " +
              chgPmp.GetElectricConsumption().ToString("F2") + ", " +
              disPmp.GetElectricConsumption().ToString("F2") + ", " +
              chiller.CoolingLoad.ToString("F1"));
            for (int j = 1; j < wTank.LayerNumber; j += 2)
              Console.Write(", " + wTank.GetTemperature(j).ToString("F2"));
            Console.WriteLine();
          }
        }
      }
    }

    private static void HeatSourceSubsystemTest4()
    {
      //ターボ冷凍機の定格冷水・冷却水量[kg/s]
      const double NCH_FLOW = 500d / (12 - 7) / 4.186;
      const double NCD_FLOW = 1670d / 60;

      //ターボ冷凍機によるサブシステムの計算
      //個別機器のインスタンスを作成
      SimpleCentrifugalChiller chiller = new SimpleCentrifugalChiller(500d / 6d, 0.2, 12, 7, 37, NCH_FLOW, false);
      CentrifugalPump chPmp = new CentrifugalPump
        (150, 1e-3 * NCH_FLOW, 140, 1e-3 * NCH_FLOW, CentrifugalPump.ControlMethod.ConstantPressureWithInverter, 50);
      CentrifugalPump cdPmp = new CentrifugalPump
        (150, 1e-3 * NCD_FLOW, 140, 1e-3 * NCD_FLOW, CentrifugalPump.ControlMethod.MinimumPressure, 50);
      CoolingTower cTower = new CoolingTower(37, 32, 27, NCD_FLOW, CoolingTower.AirFlowDirection.CrossFlow, true);
      //サブシステムを作成
      CentrifugalChillerSystem crSystem = new CentrifugalChillerSystem(chiller, chPmp, cdPmp, cTower, 1, 1);
      crSystem.ControlCoolingWaterTemperature = true;
      crSystem.ControlCoolingWaterFlowRate = true;
      crSystem.Mode = HeatSourceSystemModel.OperatingMode.Cooling;
      MoistAir oa = new MoistAir(24, 0.0125);
      crSystem.OutdoorAir = oa;

      double pLoad = 0.6;
      MultiMinimization.MinimizeFunction mFnc = delegate (IVector vec, int iteration)
      {
        //エネルギー消費量の計算
        crSystem.CoolingWaterTemperatureSetpoint = vec[0];
        crSystem.CoolingWaterFlowSetpoint = vec[1] * cTower.MaxWaterFlowRate;
        crSystem.ForecastSupplyWaterTemperature(500 * pLoad / (5 * 4.186), 0);
        double ecsmp = crSystem.Chiller.ElectricConsumption
        + crSystem.CoolingTower.ElectricConsumption + cdPmp.GetElectricConsumption();

        //ペナルティの計算
        double pSum = Math.Max(0, 12 - vec[0]) + Math.Max(0, vec[0] - 32);
        pSum += 10 * (Math.Max(0, 0.5 - vec[1]) + Math.Max(0, vec[1] - 1.0));

        return ecsmp + pSum * (1 + 0.5 * iteration);
      };

      IVector vecX = new Vector(2);
      using (StreamWriter sWriter = new StreamWriter
        ("HeatSourceSubsystemTest4.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //網羅的に探索
        sWriter.WriteLine(",50%,55%,60%,65%,70%,75%,80%,85%,90%,95%,100%");
        for (int i = 20; i <= 32; i++)
        {
          sWriter.Write(i + "C");
          for (int j = 0; j < 11; j++)
          {
            vecX[0] = i;
            vecX[1] = 0.5 + 0.05 * j;
            double ec = mFnc(vecX, 1);
            if (crSystem.IsOverLoad_C) sWriter.Write(",-");
            else sWriter.Write("," + ec);
          }
          sWriter.WriteLine();
        }

        //準ニュートン法で探索
        sWriter.WriteLine("準ニュートン法 探索結果");
        int iter;
        vecX[0] = 32; vecX[1] = 1.0;
        MultiMinimization.QuasiNewton(ref vecX, mFnc, 50, 1e-4, 1e-4, 1e-4, out iter);
        sWriter.WriteLine("温度設定," + vecX[0] + ", 流量比, " + vecX[1]);

        //負荷率と外気湿球温度を変化させた場合の最適値を計算
        sWriter.WriteLine("負荷率,湿球温度,消費電力（無対策）,消費電力（最小）,最適冷却水温度,最適流量比");
        for (int i = 0; i < 6; i++)
        {
          pLoad = 0.5 + i * 0.1;
          for (int j = 0; j < 11; j++)
          {
            oa.WetbulbTemperature = 16 + j;
            sWriter.Write(pLoad + "," + oa.WetbulbTemperature);

            vecX[0] = 32; vecX[1] = 1.0;
            double ec = mFnc(vecX, 1);
            sWriter.Write("," + ec);
            
            MultiMinimization.QuasiNewton(ref vecX, mFnc, 50, 1e-4, 1e-4, 1e-4, out iter);
            double min = mFnc(vecX, 1);
            sWriter.WriteLine("," + min + "," + vecX[0] + "," + vecX[1]);
          }
        }
      }
    }

    private static void HeatSourceSubsystemTest5()
    {
      double mcEvpC = 178.3 / 60;
      double mcCndC = 216.7 / 60;
      double mcEvpH = 155.0 / 60;
      double mcCndH = 206.7 / 60;
      double qC = mcEvpC * 5 * 4.186;
      double qH = mcEvpH * 5 * 4.186;
      double[] tcd = new double[] { 20, 30, 40 };
      double[] ths = new double[] { -5, 0, 10, 15, 20, 25 };

      WaterHeatPump whp = new WaterHeatPump(62.4, mcEvpC, mcCndC, 7, 26, 13.3, 72.3, mcCndH, mcEvpH, 45, 12, 18.6);
      CentrifugalPump gPmp = new CentrifugalPump
        (150, 1e-3 * mcCndC, 140, 1e-3 * mcCndC, CentrifugalPump.ControlMethod.ConstantPressureWithInverter, 50);
      CentrifugalPump chPmp = new CentrifugalPump
        (150, 1e-3 * mcEvpC, 140, 1e-3 * mcEvpC, CentrifugalPump.ControlMethod.ConstantPressureWithInverter, 50);
      SimpleGroundHeatExchanger gHex = new SimpleGroundHeatExchanger(mcCndC, 4.186, 0.75, SimpleGroundHeatExchanger.Type.Vertical);
      //土壌物性調整
      gHex.NearGroundHeatConductance *= 5;
      gHex.NearGroundHeatCapacity *= 5;

      //GSHPサブシステムを作成
      GroundHeatSourceHeatPumpSystem gshpSystem = new GroundHeatSourceHeatPumpSystem(whp, gHex, gPmp, chPmp);

      //熱源システムを作成
      HeatSourceSystemModel hsSystem = new HeatSourceSystemModel(new IHeatSourceSubSystem[] { gshpSystem });
      hsSystem.TimeStep = 3600;
      hsSystem.SetChillingOperationSequence(0, 1);
      hsSystem.SetHeatingOperationSequence(0, 1);

      Console.WriteLine("熱源水往温度, 熱源水還温度, 近傍土壌温度, 遠方土壌温度, WHP消費エネルギー");
      //8hの冷却運転
      hsSystem.SetOperatingMode(0, HeatSourceSystemModel.OperatingMode.Cooling);
      hsSystem.ChilledWaterSupplyTemperatureSetpoint = 7;
      for (int i = 0; i < 8; i++)
      {
        hsSystem.ForecastSupplyWaterTemperature(0.8 * mcEvpC, 12, 0, 40);
        hsSystem.FixState();
        Console.WriteLine(
          whp.CoolingWaterOutletTemperature.ToString("F3") + ", " + 
          whp.CoolingWaterInletTemperature.ToString("F3") + ", " +
          gHex.NearGroundTemperature.ToString("F3") + ", " + 
          gHex.DistantGroundTemperature.ToString("F3") + ", " + 
          whp.EnergyConsumption.ToString("F3"));
      }
      //16h回復
      for (int i = 0; i < 10; i++)
      {
        hsSystem.ForecastSupplyWaterTemperature(0, 12, 0, 40);
        hsSystem.FixState();
        Console.WriteLine(
          whp.CoolingWaterOutletTemperature.ToString("F3") + ", " +
          whp.CoolingWaterInletTemperature.ToString("F3") + ", " +
          gHex.NearGroundTemperature.ToString("F3") + ", " +
          gHex.DistantGroundTemperature.ToString("F3") + ", " +
          whp.EnergyConsumption.ToString("F3"));
      }
      //8hの加熱運転
      hsSystem.SetOperatingMode(0, HeatSourceSystemModel.OperatingMode.Heating);
      hsSystem.HotWaterSupplyTemperatureSetpoint = 45;
      for (int i = 0; i < 8; i++)
      {
        hsSystem.ForecastSupplyWaterTemperature(0, 12, 0.8 * mcCndH, 40);
        hsSystem.FixState();
        Console.WriteLine(
          whp.HeatSourceWaterOutletTemperature.ToString("F3") + ", " +
          whp.HeatSourceWaterInletTemperature.ToString("F3") + ", " +
          gHex.NearGroundTemperature.ToString("F3") + ", " +
          gHex.DistantGroundTemperature.ToString("F3") + ", " +
          whp.EnergyConsumption.ToString("F3"));
      }
      //16h回復
      for (int i = 0; i < 10; i++)
      {
        hsSystem.ForecastSupplyWaterTemperature(0, 12, 0, 40);
        hsSystem.FixState();
        Console.WriteLine(
          whp.CoolingWaterOutletTemperature.ToString("F3") + ", " +
          whp.CoolingWaterInletTemperature.ToString("F3") + ", " +
          gHex.NearGroundTemperature.ToString("F3") + ", " +
          gHex.DistantGroundTemperature.ToString("F3") + ", " +
          whp.EnergyConsumption.ToString("F3"));
      }
    }

    #endregion

    #region 空調機テスト

    private static void AirHandlingUnitVAVTest()
    {
      //給気・還気・外気量[m3/s]
      double qsa = 7476d / 3600;
      double qra = 6946d / 3600;
      double qoa = 1513d / 3600;

      //冷水・温水コイル作成
      CrossFinHeatExchanger cCoil = new CrossFinHeatExchanger
        (0.82, 0.910, 6, 24, qsa * 1.2, 27.46, 0.01206, 95, 127d / 60, 127d / 60, 7,
        CrossFinHeatExchanger.WaterFlowType.HalfFlow, 49.6, true);
      CrossFinHeatExchanger hCoil = new CrossFinHeatExchanger
        (0.82, 0.910, 4, 24, qsa * 1.2, 17.46, 0.00554, 95, 105d / 60, 105d / 60, 50,
        CrossFinHeatExchanger.WaterFlowType.HalfFlow, 46.9, true);

      //給気・還気ファン作成
      CentrifugalFan saFan = new CentrifugalFan(0.8, qsa, 0.8, qsa, 3, true);
      CentrifugalFan raFan = new CentrifugalFan(0.3, qra, 0.3, qra, 3, true);
      saFan.MinimumRotationRatio = raFan.MinimumRotationRatio = 0.2;

      //全熱交換器作成
      RotaryRegenerator regenerator = new RotaryRegenerator
        (0.34, qoa * 3600, (qoa + qra - qsa) * 3600, true, 34.4, 0.0194, 26, 0.0105);

      //AHU作成
      AirHandlingUnit ahu = new AirHandlingUnit
        (cCoil, hCoil, AirHandlingUnit.HumidifierType.DropPervaporation, saFan, raFan, regenerator);
      ahu.SetOutdoorAirFlowRange(qoa * 1.2, qsa * 1.2);
      ahu.SetAirFlowRate(qra, qsa * 1.2);
      ahu.MinimizeAirFlow = true;
      ahu.UpperTemperatureLimit = 40;
      ahu.LowerTemperatureLimit = 10;

      //運転状態設定
      const double CNV = 1.2 / 3600d; //m3/h→kg/s 換算係数
      bool[] off = new bool[] { false, false, false };
      double[] zTemp = new double[] { 22, 24, 26 };
      double[] zHumid = new double[] { 0.008, 0.008, 0.008 };
      double[] zHLoad = new double[3];
      double cf = 6946d / 7476d;
      double[] maxSA = new double[] { 4151d * CNV, 1782d * CNV, 1543d * CNV };
      double[] maxRA = new double[] { maxSA[0] * cf, maxSA[1] * cf, maxSA[2] * cf };
      double[] minSA = new double[3];
      for (int i = 0; i < minSA.Length; i++) minSA[i] = maxSA[i] * 0.4;

      //冷温水入口温度設定
      ahu.ChilledWaterInletTemperature = 7;
      ahu.HotWaterInletTemperature = 50;

      Console.WriteLine("風量1,風量2,風量3,給気量,給気温度,熱処理,消費電力");
      //冷却運転テスト
      Console.WriteLine("--冷却運転--------------------------------");
      ahu.OATemperature = 34.4;
      ahu.OAHumidityRatio = 0.0194;
      bool suc;
      for (int i = 0; i < 8; i++)
      {
        zHLoad[0] = -16 * (1 - 0.1 * i) * 1000;
        zHLoad[1] = -7 * (1 - 0.1 * i) * 1000;
        zHLoad[2] = -6 * (1 - 0.1 * i) * 1000;
        double[] af = ahu.OptimizeVAV(true, 0, off, zTemp, zHumid, zHLoad, minSA, maxSA, maxRA, out suc);
        Console.WriteLine(
          (af[0] / CNV).ToString("F0") + "," + (af[1] / CNV).ToString("F0") + "," + 
          (af[2] / CNV).ToString("F0") + "," + (ahu.SAFlowRate / CNV).ToString("F0") + "," +
          ahu.SATemperature.ToString("F1") + "," + ahu.CoolingCoil.HeatTransfer.ToString("F1") + "," + 
          ahu.SupplyAirFan.GetElectricConsumption().ToString("F2"));
      }
      //加熱運転テスト
      Console.WriteLine("--加熱運転--------------------------------");
      ahu.OATemperature = 2.0;
      ahu.OAHumidityRatio = 0.0014;
      for (int i = 0; i < 8; i++)
      {
        zHLoad[0] = 12.1 * (1 - 0.1 * i) * 1000;
        zHLoad[1] = 5.3 * (1 - 0.1 * i) * 1000;
        zHLoad[2] = 4.6 * (1 - 0.1 * i) * 1000;
        double[] af = ahu.OptimizeVAV(false, 0.0105, off, zTemp, zHumid, zHLoad, minSA, maxSA, maxRA, out suc);
        Console.WriteLine(
          (af[0] / CNV).ToString("F0") + "," + (af[1] / CNV).ToString("F0") + "," +
          (af[2] / CNV).ToString("F0") + "," + (ahu.SAFlowRate / CNV).ToString("F0") + "," +
          ahu.SATemperature.ToString("F1") + "," + ahu.HeatingCoil.HeatTransfer.ToString("F1") + "," +
          ahu.SupplyAirFan.GetElectricConsumption().ToString("F2"));
      }
      //外気冷房テスト
      Console.WriteLine("--外気冷房--------------------------------");
      ahu.OATemperature = 10.0;
      ahu.OAHumidityRatio = 0.006;
      ahu.OutdoorAirCooling = AirHandlingUnit.OutdoorAirCoolingControl.DrybulbTemperature;
      for (int i = 0; i < 8; i++)
      {
        zHLoad[0] = -16 * (1 - 0.1 * i) * 1000;
        zHLoad[1] = -7 * (1 - 0.1 * i) * 1000;
        zHLoad[2] = -6 * (1 - 0.1 * i) * 1000;
        double[] af = ahu.OptimizeVAV(true, 0, off, zTemp, zHumid, zHLoad, minSA, maxSA, maxRA, out suc);
        Console.WriteLine(
          (af[0] / CNV).ToString("F0") + "," + (af[1] / CNV).ToString("F0") + "," +
          (af[2] / CNV).ToString("F0") + "," + (ahu.SAFlowRate / CNV).ToString("F0") + "," +
          ahu.SATemperature.ToString("F1") + "," + ahu.CoolingCoil.HeatTransfer.ToString("F1") + "," +
          ahu.SupplyAirFan.GetElectricConsumption().ToString("F2"));
      }
    }

    private static void AirHandlingUnitTest()
    {
      //給気・還気・外気量
      double msa = 7476d / 3600 * 1.2;
      double mra = 6946d / 3600 * 1.2;
      double moa = 1513d / 3600 * 1.2;

      //冷水・温水コイル作成
      CrossFinHeatExchanger cCoil = new CrossFinHeatExchanger
        (0.82, 0.910, 6, 24, msa, 27.46, 0.01206, 95, 127d / 60, 127d / 60, 7,
        CrossFinHeatExchanger.WaterFlowType.HalfFlow, 49.6, true);
      CrossFinHeatExchanger hCoil = new CrossFinHeatExchanger
        (0.82, 0.910, 4, 24, msa, 17.46, 0.00554, 95, 105d / 60, 105d / 60, 50,
        CrossFinHeatExchanger.WaterFlowType.HalfFlow, 46.9, true);

      //給気・還気ファン作成
      CentrifugalFan saFan = new CentrifugalFan(0.4, msa / 1.2, 0.4, msa / 1.2, 3, true);
      CentrifugalFan raFan = new CentrifugalFan(0.2, mra / 1.2, 0.2, mra / 1.2, 3, true);

      //全熱交換器作成
      RotaryRegenerator regenerator = new RotaryRegenerator
        (0.34, moa * 3600 / 1.2, (moa + mra - msa) * 3600 / 1.2, true,
        34.4, 0.0194, 26, 0.0105);

      //AHU作成
      AirHandlingUnit ahu = new AirHandlingUnit
        (cCoil, hCoil, AirHandlingUnit.HumidifierType.DropPervaporation,
        saFan, raFan, regenerator);
      ahu.SetOutdoorAirFlowRange(moa, msa);
      ahu.SetAirFlowRate(mra, msa);

      //冷温水入口温度設定
      ahu.ChilledWaterInletTemperature = 7;
      ahu.HotWaterInletTemperature = 43;

      //還気温湿度設定
      ahu.RATemperature = 26.0;
      ahu.RAHumidityRatio = 0.0105;

      //外気条件リスト
      double[] tOA = new double[30];
      double[] wOA = new double[30];
      double MAX_TOA = tOA[0] = 50;
      double MIN_TOA = tOA[10] = -10;
      double MAX_WOA = wOA[0] = 0.025;
      double MIN_WOA = wOA[10] = 0.003;
      for (int i = 1; i < 10; i++)
      {
        tOA[i] = tOA[20 - i] = MAX_TOA - (MAX_TOA - MIN_TOA) / 10 * i;
        wOA[i] = wOA[30 - i] = MAX_WOA - (MAX_WOA - MIN_WOA) / 10 * i;
      }
      for (int i = 0; i < 10; i++)
      {
        tOA[20 + i] = MAX_TOA;
        wOA[11 + i] = MIN_WOA;
      }

      using (StreamWriter sWriter = new StreamWriter
        ("ahuTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.Write("外気温度,外気湿度");
        for (int i = 0; i < 6; i++) sWriter.Write(
            ",冷水流量,冷水出温,冷水処理熱,温水流量,温水出温,温水処理熱," + 
            "外気量,水消費量,全熱交回収,外気冷房,給気温度,給気湿度");
        sWriter.WriteLine();

        for (int i = 0; i < tOA.Length; i++)
        {
          sWriter.Write(tOA[i] + ", " + wOA[i]);
          ahu.OATemperature = tOA[i];
          ahu.OAHumidityRatio = wOA[i];

          ahu.OutdoorAirCooling = AirHandlingUnit.OutdoorAirCoolingControl.None;
          ahu.BypassRegenerator = true;
          ahu.CoolAir(15, 0);
          outputAHUState(sWriter, ahu);

          ahu.OutdoorAirCooling = AirHandlingUnit.OutdoorAirCoolingControl.None;
          ahu.BypassRegenerator = false;
          ahu.CoolAir(15, 0);
          outputAHUState(sWriter, ahu);

          ahu.OutdoorAirCooling = AirHandlingUnit.OutdoorAirCoolingControl.DrybulbTemperature;
          ahu.BypassRegenerator = true;
          ahu.CoolAir(15, 0);
          outputAHUState(sWriter, ahu);

          ahu.OutdoorAirCooling = AirHandlingUnit.OutdoorAirCoolingControl.DrybulbTemperature;
          ahu.BypassRegenerator = false;
          ahu.CoolAir(15, 0);
          outputAHUState(sWriter, ahu);
          
          ahu.BypassRegenerator = true;
          ahu.HeatAir(35, 0.010);
          outputAHUState(sWriter, ahu);

          ahu.BypassRegenerator = false;
          ahu.HeatAir(35, 0.010);
          outputAHUState(sWriter, ahu);

          sWriter.WriteLine();
        }
      }
    }

    private static void outputAHUState(StreamWriter sWriter, AirHandlingUnit ahu)
    {
      ImmutableCrossFinHeatExchanger cCoil = ahu.CoolingCoil;
      ImmutableCrossFinHeatExchanger hCoil = ahu.HeatingCoil;
      double recov;
      if (ahu.Regenerator != null) recov = ahu.Regenerator.GetHeatRecovery();
      else recov = 0;
      sWriter.Write(", " +
        cCoil.WaterFlowRate + ", " + cCoil.OutletWaterTemperature + ", " + cCoil.HeatTransfer + ", " +
        hCoil.WaterFlowRate + ", " + hCoil.OutletWaterTemperature + ", " + hCoil.HeatTransfer + ", " +
        ahu.OAFlowRate + ", " + ahu.WaterConsumption + ", " + recov + ", " +
        ahu.GetOutdoorCoolingHeat() + ", " + ahu.SATemperature + ", " + ahu.SAHumidityRatio);
    }

    #endregion

    #region SHASEシミュレーション評価法テスト

    private static void SHASE_HeatLoadTest()
    {
      //気象データ読み込み
      double[] dbt, hrt, dnr, dhr, ncr;
      SHASE_SimulationTest.LoadWeatherData("3639999.has", out dbt, out hrt, out dnr, out dhr, out ncr);

      //建物モデル作成
      BuildingThermalModel building = SHASE_SimulationTest.MakeBuildingThermalModel();
      Sun sun = new Sun(Sun.City.Tokyo);

      using (StreamWriter sWriter = new StreamWriter("output.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行書き出し
        sWriter.Write(",,外気乾球温度,外気絶対湿度,法線面直達日射,水平面全天日射,夜間放射");
        for (int j = 0; j < building.MultiRoom.Length; j++)
        {
          ImmutableMultiRooms mRM = building.MultiRoom[j];
          for (int k = 0; k < mRM.ZoneNumber; k++)
          {
            string nm = mRM.Zones[k].Name;
            sWriter.Write(", " + nm + ":室温," + nm + ":絶対湿度," + nm + ":顕熱負荷," + nm + ":潜熱負荷");
          }
        }
        sWriter.WriteLine();

        //12月を助走計算期間とする
        DateTime dt = new DateTime(2006, 12, 1, 0, 0, 0);
        for (int i = 0; i < 31 * 24; i++)
        {
          //気象条件更新
          sun.SetGlobalHorizontalRadiation(dhr[8016 + i], dnr[8016 + i]);
          sun.Update(dt.AddMinutes(30)); //過去一時間のデータのため30分シフト
          building.UpdateOutdoorCondition(dt, sun, dbt[8016 + i], hrt[8016 + i], ncr[8016 + i]);

          //熱平衡を更新
          SHASE_SimulationTest.SetHVACControl(building);
          building.ForecastHeatTransfer();
          building.ForecastWaterTransfer();
          building.FixState();
          dt = dt.AddHours(1);
        }

        //8760時間の計算実行
        dt = new DateTime(2006, 1, 1, 0, 0, 0);
        for (int i = 0; i < 8760; i++)
        {
          //気象条件更新
          sun.SetGlobalHorizontalRadiation(dhr[i], dnr[i]);
          sun.Update(dt.AddMinutes(30)); //過去一時間のデータのため30分シフト
          building.UpdateOutdoorCondition(dt, sun, dbt[i], hrt[i], ncr[i]);

          //熱平衡を更新
          SHASE_SimulationTest.SetHVACControl(building);
          building.ForecastHeatTransfer();
          building.ForecastWaterTransfer();
          building.FixState();

          //書き出し
          sWriter.Write(dt.ToShortDateString() + "," + dt.ToShortTimeString());
          sWriter.Write("," + dbt[i] + "," + hrt[i] + "," + dnr[i] + "," + dhr[i] + "," + ncr[i]);
          for (int j = 0; j < building.MultiRoom.Length; j++)
          {
            ImmutableMultiRooms mRM = building.MultiRoom[j];
            for (int k = 0; k < mRM.ZoneNumber; k++)
            {
              ImmutableZone zn = mRM.Zones[k];
              sWriter.Write
                (", " + zn.Temperature + ", " + zn.HumidityRatio + ", " + zn.HeatSupply + ", " + zn.WaterSupply);
            }
          }
          sWriter.WriteLine();

          if (dt.Hour == 0) Console.WriteLine(dt.ToShortDateString());
          dt = dt.AddHours(1);
        }
      }
    }

    private static void SHASE_AHUTest(bool isCAVSystem)
    {
      //気象データ読み込み
      double[] dbt, hrt, dnr, dhr, ncr;
      SHASE_SimulationTest.LoadWeatherData("3639999.has", out dbt, out hrt, out dnr, out dhr, out ncr);

      //建物モデル作成
      BuildingThermalModel bModel;
      AHUSystem ahuSystem;
      SHASE_SimulationTest.MakeAHUSystem(out bModel, out ahuSystem, isCAVSystem);
      Sun sun = new Sun(Sun.City.Tokyo);

      using (StreamWriter sWriter = new StreamWriter("output.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行書き出し
        sWriter.Write(",,外気乾球温度,外気絶対湿度,法線面直達日射,水平面全天日射,夜間放射");
        for (int j = 0; j < bModel.MultiRoom.Length; j++)
        {
          for (int k = 0; k < bModel.MultiRoom[j].ZoneNumber; k++)
          {
            ImmutableZone zn = bModel.MultiRoom[j].Zones[k];
            sWriter.Write(
              ", " + zn.Name + ":室温" + ", " + zn.Name + ":絶対湿度" + 
              ", " + zn.Name + ":平均放射温度" + ", " + zn.Name + ":PMV");
          }
        }
        ImmutableAirHandlingUnit[] ahus = ahuSystem.AHUs;
        for (int j = 0; j < ahus.Length; j++) sWriter.Write(",AHU" + j + ":冷熱処理");
        for (int j = 0; j < ahus.Length; j++) sWriter.Write(",AHU" + j + ":温熱処理");
        for (int j = 0; j < ahus.Length; j++) sWriter.Write(",AHU" + j + ":加湿量");
        for (int j = 0; j < ahus.Length; j++) sWriter.Write(",AHU" + j + ":給気ファン動力");
        for (int j = 0; j < ahus.Length; j++) sWriter.Write(",AHU" + j + ":還気ファン動力");
        sWriter.WriteLine(",冷水流量,冷水還温度,冷熱負荷,温水流量,温水還温度,温熱負荷");

        //12月を助走計算期間とする
        DateTime dt = new DateTime(2006, 12, 1, 0, 0, 0);
        for (int i = 0; i < 31 * 24; i++)
        {
          //気象条件更新
          sun.SetGlobalHorizontalRadiation(dhr[8016 + i], dnr[8016 + i]);
          sun.Update(dt.AddMinutes(30)); //過去一時間のデータのため30分シフト
          bModel.UpdateOutdoorCondition(dt, sun, dbt[8016 + i], hrt[8016 + i], ncr[8016 + i]);

          //熱平衡を更新
          SHASE_SimulationTest.ControlAHUSystem(bModel, ahuSystem);
          ahuSystem.ForecastReturnWaterTemperature(7, 50);
          bModel.FixState();
          dt = dt.AddHours(1);
        }

        //8760時間の計算実行
        dt = new DateTime(2006, 1, 1, 0, 0, 0);
        for (int i = 0; i < 8760; i++)
        {
          //気象条件更新
          sun.SetGlobalHorizontalRadiation(dhr[i], dnr[i]);
          sun.Update(dt.AddMinutes(30)); //過去一時間のデータのため30分シフト
          bModel.UpdateOutdoorCondition(dt, sun, dbt[i], hrt[i], ncr[i]);
          ahuSystem.OutdoorAir = new MoistAir(dbt[i], hrt[i]);
          
          //空調制御//熱平衡を確定
          SHASE_SimulationTest.ControlAHUSystem(bModel, ahuSystem);
          ahuSystem.ForecastReturnWaterTemperature(7, 50);
          bModel.FixState();
          
          //書き出し
          sWriter.Write(dt.ToShortDateString() + "," + dt.ToShortTimeString());
          sWriter.Write("," + dbt[i] + "," + hrt[i] + "," + dnr[i] + "," + dhr[i] + "," + ncr[i]);
          //着量を設定
          double clo = 0.7; //中間期
          if (SHASE_SimulationTest.DO_COOLBIZ)
          {
            if (6 <= dt.Month && dt.Month <= 9) clo = 0.5;  //夏季着衣量
            else if (dt.Month == 12 || dt.Month <= 3) clo = 0.92;  //冬季着衣量
          }
          for (int j = 0; j < bModel.MultiRoom.Length; j++)
          {
            for (int k = 0; k < bModel.MultiRoom[j].ZoneNumber; k++)
            {
              //PMV計算
              ImmutableZone zn = bModel.MultiRoom[j].Zones[k];
              double tRad = zn.GetMeanSurfaceTemperature();
              double rHmd = MoistAir.GetRelativeHumidityFromDryBulbTemperatureAndHumidityRatio
                (zn.Temperature, zn.HumidityRatio, 101.325);
              double pmv = ThermalComfort.GetPMV(zn.Temperature, tRad, rHmd, 0.2, clo, 1.2, 0); //オフィス作業相当
              if (6 <= dt.Month && dt.Month <= 9 && SHASE_SimulationTest.DO_COOLBIZ)
                pmv = ThermalComfort.GetPMV(zn.Temperature, tRad, rHmd, 0.55, clo, 1.2, 0); //オフィス作業相当//CLBZ
              sWriter.Write(", " + zn.Temperature + ", " + zn.HumidityRatio + ", " + tRad + ", " + pmv);
            }
          }

          //冷水温水流量・還温度・負荷を計算
          for (int j = 0; j < ahus.Length; j++) sWriter.Write("," + ahus[j].CoolingCoil.HeatTransfer);
          for (int j = 0; j < ahus.Length; j++) sWriter.Write("," + ahus[j].HeatingCoil.HeatTransfer);
          for (int j = 0; j < ahus.Length; j++) sWriter.Write("," + ahus[j].WaterConsumption);
          for (int j = 0; j < ahus.Length; j++) sWriter.Write("," + ahus[j].SupplyAirFan.GetElectricConsumption());
          for (int j = 0; j < ahus.Length; j++) sWriter.Write("," + ahus[j].ReturnAirFan.GetElectricConsumption());
          double tco, tho, mcc, mhc, qc, qh;
          tco = tho = mcc = mhc = qc = qh = 0;
          for (int j = 0; j < ahus.Length; j++)
          {
            mcc += ahus[j].CoolingCoil.WaterFlowRate;
            mhc += ahus[j].HeatingCoil.WaterFlowRate;
            tco += ahus[j].CoolingCoil.WaterFlowRate * ahus[j].CoolingCoil.OutletWaterTemperature;
            tho += ahus[j].HeatingCoil.WaterFlowRate * ahus[j].HeatingCoil.OutletWaterTemperature;
            qc += ahus[j].CoolingCoil.HeatTransfer;
            qh += ahus[j].HeatingCoil.HeatTransfer;
          }
          if (mcc == 0) tco = 7;
          else tco /= mcc;
          if (mhc == 0) tho = 50;
          else tho /= mhc;
          sWriter.WriteLine("," + mcc + "," + tco + "," + qc + "," + mhc + "," + tho + "," + qh);

          if (dt.Hour == 0) Console.WriteLine(dt.ToShortDateString());
          dt = dt.AddHours(1);
        }
      }
    }

    private static void SHASE_HVACSystemTest()
    {
      SHASE_SimulationTest.IS_HIGH_INSULATION = false;  //高断熱仕様フラグ
      SHASE_SimulationTest.USE_CO2CNTRL = false;        //CO2制御フラグ
      SHASE_SimulationTest.USE_OA_COOLING = false;      //外気冷房フラグ
      SHASE_SimulationTest.USE_REGENERATOR = false;     //全熱交換器フラグ
      SHASE_SimulationTest.USE_VWV_SYSTEM = false;      //VWV制御フラグ
      SHASE_SimulationTest.IS_HIGHEFF_HSOURCE = false;  //高効率熱源フラグ
      SHASE_SimulationTest.DO_COOLBIZ = false;          //クールビズ実施フラグ
      SHASE_HVACSystemTest("outputA.csv");

      SHASE_SimulationTest.IS_HIGH_INSULATION = true;
      SHASE_HVACSystemTest("outputB.csv");

      SHASE_SimulationTest.USE_CO2CNTRL = true;
      SHASE_HVACSystemTest("outputC.csv");

      SHASE_SimulationTest.USE_OA_COOLING = true;
      SHASE_HVACSystemTest("outputD.csv");

      SHASE_SimulationTest.USE_REGENERATOR = true;
      SHASE_HVACSystemTest("outputE.csv");

      SHASE_SimulationTest.USE_VWV_SYSTEM = true;
      SHASE_HVACSystemTest("outputF.csv");

      SHASE_SimulationTest.IS_HIGHEFF_HSOURCE = true;
      SHASE_HVACSystemTest("outputG.csv");

      SHASE_SimulationTest.DO_COOLBIZ = true;
      SHASE_HVACSystemTest("outputH.csv");
    }

    private static void SHASE_HVACSystemTest(string outputFile)
    {
      //建物モデル作成
      BuildingThermalModel bModel;
      AHUSystem ahuSystem;
      SHASE_SimulationTest.MakeAHUSystem(out bModel, out ahuSystem, false); //ここでVAV切り替え
      Sun sun = new Sun(Sun.City.Tokyo);

      //熱源モデル作成
      HeatSourceSystemModel hss;
      AirHeatSourceModularChillersSystem ahSystem;
      DirectFiredAbsorptionChillerSystem arSystem;
      SHASE_SimulationTest.MakeHeatSourceSystem(out hss, out ahSystem, out arSystem);

      //HVACモデル作成
      HVACSystemModel hvacSystem = new HVACSystemModel
        (bModel, new IAirConditioningSystemModel[] { ahuSystem }, hss);
      hvacSystem.ChilledWaterSupplyTemperatureSetpoint = 7; //CASE JE220-222変更箇所
      hvacSystem.HotWaterSupplyTemperatureSetpoint = 50;    //CASE JE220-222変更箇所
      hvacSystem.SetACFactor(0, 6); //2F-7F

      //シリアライズテスト//不要の場合にはコメントアウト////////////////////////////////////////
      FileStream fs = new FileStream("data.bin", FileMode.Create, FileAccess.Write);
      BinaryFormatter bf = new BinaryFormatter();
      bf.Serialize(fs, hvacSystem);
      fs.Close();

      fs = new FileStream("data.bin", FileMode.Open, FileAccess.Read);
      BinaryFormatter f = new BinaryFormatter();
      hvacSystem = (HVACSystemModel)f.Deserialize(fs);
      fs.Close();

      bModel = (BuildingThermalModel)hvacSystem.BuildingThermalModel;
      ahuSystem = (AHUSystem)hvacSystem.AirConditioningSystemModel[0];
      hss = (HeatSourceSystemModel)hvacSystem.HeatSourceSystemModel;
      //////////////////////////////////////////////////////////////////////////////////////////*/

      //気象データ読み込み
      double[] dbt, hrt, dnr, dhr, ncr;
      SHASE_SimulationTest.LoadWeatherData("3639999.has", out dbt, out hrt, out dnr, out dhr, out ncr);
      using (StreamWriter sWriter = new StreamWriter(outputFile, false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行書き出し
        //外界条件
        sWriter.Write(",,外気乾球温度,外気絶対湿度,法線面直達日射,水平面全天日射,夜間放射");
        //一次側
        sWriter.Write(", 冷水往温度, 冷水還温度, 温水往温度, 温水還温度");
        sWriter.Write(", AHP電力, AHP冷水ポンプ電力, AHP温水ポンプ電力, AHP冷却, AHP加熱, AHP台数");
        sWriter.Write(", ARガス, AR電力, AR冷水ポンプ電力, AR温水ポンプ電力");
        sWriter.Write(", AR冷却水ポンプ電力, AR冷却塔電力, AR冷却, AR加熱");
        sWriter.Write(", 冷水二次ポンプ電力, 温水二次ポンプ電力");
        sWriter.Write(", 二次側冷水流量, 二次側温水流量, 冷水バイパス流量, 温水バイパス流量");
        //二次側
        for (int j = 0; j < bModel.MultiRoom.Length; j++)
        {
          for (int k = 0; k < bModel.MultiRoom[j].ZoneNumber; k++)
          {
            string nm = bModel.MultiRoom[j].Zones[k].Name;
            sWriter.Write(", " + nm + ":室温, " + nm + ":絶対湿度, " + nm + ":平均放射温度," + nm + ":PMV");
          }
        }
        ImmutableAirHandlingUnit[] ahus = ahuSystem.AHUs;
        for (int j = 0; j < ahus.Length; j++)
        {
          string sb = ",AHU" + j;
          sWriter.Write(sb + ":冷却" + sb + ":加熱" + sb + ":加湿" + sb + ":SAファン" + sb + ":RAファン");
        }
        sWriter.WriteLine();

        //12月を助走計算期間とする
        DateTime dt = new DateTime(2006, 12, 1, 0, 0, 0);
        for (int i = 0; i < 31 * 24; i++)
        {
          //気象条件更新
          sun.SetGlobalHorizontalRadiation(dhr[8016 + i], dnr[8016 + i]);
          sun.Update(dt.AddMinutes(30)); //過去一時間のデータのため30分シフト
          hvacSystem.UpdateOutdoorCondition(dt, sun, dbt[8016 + i], hrt[8016 + i], ncr[8016 + i]);

          //熱平衡を更新
          SHASE_SimulationTest.ControlAHUSystem(bModel, ahuSystem);
          SHASE_SimulationTest.ControlHeatSourceSystem(hss);
          hvacSystem.Update();
          dt = dt.AddHours(1);
        }

        //8760時間の計算実行
        dt = new DateTime(2006, 1, 1, 0, 0, 0);
        for (int i = 0; i < 8760; i++)
        {
          //気象条件更新
          sun.SetGlobalHorizontalRadiation(dhr[i], dnr[i]);
          sun.Update(dt.AddMinutes(30)); //過去一時間のデータのため30分シフト
          hvacSystem.UpdateOutdoorCondition(dt, sun, dbt[i], hrt[i], ncr[i]);

          //状態更新
          SHASE_SimulationTest.ControlAHUSystem(bModel, ahuSystem);
          SHASE_SimulationTest.ControlHeatSourceSystem(hss);
          hvacSystem.Update();

          //書き出し
          //外界条件
          sWriter.Write(dt.ToShortDateString() + "," + dt.ToShortTimeString());
          sWriter.Write("," + dbt[i] + "," + hrt[i] + "," + dnr[i] + "," + dhr[i] + "," + ncr[i]);
          //一次側
          sWriter.Write(
            "," + hvacSystem.ChilledWaterSupplyTemperature +
            "," + hvacSystem.ChilledWaterReturnTemperature + 
            "," + hvacSystem.HotWaterSupplyTemperature +
            "," + hvacSystem.HotWaterReturnTemperature);
          ImmutableAirHeatSourceModularChillers ahp = ahSystem.AirHeatSourceModularChillers;
          sWriter.Write(
            "," + (ahp.ElectricConsumption * ahp.OperatingNumber) +
            "," + (ahSystem.ChilledWaterPump.GetElectricConsumption() + 
            "," + ahSystem.HotWaterPump.GetElectricConsumption()) + 
            "," + ahp.CoolingLoad + "," + ahp.HeatingLoad + "," + ahSystem.OperatingChillerNumber);
          ImmutableDirectFiredAbsorptionChiller ar = arSystem.DirectFiredAbsorptionChiller;
          sWriter.Write(
            "," + ar.FuelConsumption + "," + ar.ElectricConsumption + 
            "," + (arSystem.ChilledWaterPump.GetElectricConsumption() +
            "," + arSystem.HotWaterPump.GetElectricConsumption()) + 
            "," + arSystem.CoolingWaterPump.GetElectricConsumption() + 
            "," + arSystem.CoolingTower.ElectricConsumption + 
            "," + ar.CoolingLoad + "," + ar.HeatingLoad);
          ImmutablePumpSystem ps2c = hss.ChilledWaterPumpSystem;
          ImmutablePumpSystem ps2h = hss.HotWaterPumpSystem;
          sWriter.Write(
            "," + ps2c.GetElectricConsumption() + "," + ps2h.GetElectricConsumption() +
            "," + (ps2c.TotalFlowRate * 1000) + "," + (ps2h.TotalFlowRate * 1000) +
            "," + hss.ChilledWaterBypassFlowRate + "," + hss.HotWaterBypassFlowRate);
          //二次側
          double clo = 0.7; //中間期着衣量
          if (SHASE_SimulationTest.DO_COOLBIZ)
          {
            if (6 <= dt.Month && dt.Month <= 9) clo = 0.5;  //夏季着衣量
            else if (dt.Month == 12 || dt.Month <= 3) clo = 0.92;  //冬季着衣量
          }
          for (int j = 0; j < bModel.MultiRoom.Length; j++)
          {
            for (int k = 0; k < bModel.MultiRoom[j].ZoneNumber; k++)
            {
              ImmutableZone zn = bModel.MultiRoom[j].Zones[k];
              double tRad = zn.GetMeanSurfaceTemperature();
              double rHmd = MoistAir.GetRelativeHumidityFromDryBulbTemperatureAndHumidityRatio
                (zn.Temperature, zn.HumidityRatio, 101.325);
              double pmv = ThermalComfort.GetPMV(zn.Temperature, tRad, rHmd, 0.2, clo, 1.2, 0);
              if (6 <= dt.Month && dt.Month <= 9 && SHASE_SimulationTest.DO_COOLBIZ)
                pmv = ThermalComfort.GetPMV(zn.Temperature, tRad, rHmd, 0.55, clo, 1.2, 0); //採涼アイテム
              sWriter.Write(", " + zn.Temperature + ", " + zn.HumidityRatio + ", " + tRad + ", " + pmv);
            }
          }
          for (int j = 0; j < ahus.Length; j++)
            sWriter.Write(
              "," + ahus[j].CoolingCoil.HeatTransfer + "," + (-ahus[j].HeatingCoil.HeatTransfer) + 
              "," + ahus[j].WaterConsumption + "," + ahus[j].SupplyAirFan.GetElectricConsumption() +
              "," + ahus[j].ReturnAirFan.GetElectricConsumption());

          //SHASE委員会_小野さん対応******************************************************************************
          bool isCooling = (6 <= dt.Month && dt.Month <= 9);
          double[] sh = new double[4];
          double[] lh = new double[4];
          ImmutableCrossFinHeatExchanger[] coil = new ImmutableCrossFinHeatExchanger[4];
          for (int j = 0; j < 4; j++)
          {            
            if (isCooling) coil[j] = ahus[j].CoolingCoil;
            else coil[j] = ahus[j].HeatingCoil;
            sh[j] = (coil[j].InletAirTemperature - ahus[j].SATemperature)
              * MoistAir.GetSpecificHeat(coil[j].InletAirHumidityRatio) * ahus[j].SupplyAirFan.VolumetricFlowRate * 1.2;
            lh[j] = (coil[j].InletAirHumidityRatio - ahus[j].SAHumidityRatio)
              * MoistAir.LatentHeatOfVaporization * ahus[j].SupplyAirFan.VolumetricFlowRate * 1.2;
          }          
          sWriter.Write(
            "," + sh[1] + "," + lh[1] + "," + ahus[1].SupplyAirFan.VolumetricFlowRate * 3600 +
            "," + (ahus[1].RAFlowRate - ahus[1].EAFlowRate) / 1.2 * 3600 + "," + ahus[1].OAFlowRate / 1.2 * 3600 +
            "," + ahus[1].OATemperature + "," + ahus[1].RATemperature + "," + coil[1].InletAirTemperature + "," + coil[1].OutletAirTemperature + "," + ahus[1].SATemperature +
            "," + ahus[1].OAHumidityRatio + "," + ahus[1].RAHumidityRatio +"," + coil[1].InletAirHumidityRatio + "," + coil[1].OutletAirHumidityRatio + "," + ahus[1].SAHumidityRatio);
          sWriter.Write("," + sh[0] + "," + sh[1] + "," + sh[2] + "," + sh[3] + "," + lh[0] + "," + lh[1] + "," + lh[2] + "," + lh[3]);

          //sWriter.Write("," + ps2c.Pump.VolumetricFlowRate * 1000 + "," + ps2c.Pump.Pressure + "," + ps2c.Pump.RotationRatio + "," + ps2c.Pump.GetElectricConsumption());
          //sWriter.Write("," + ps2h.Pump.VolumetricFlowRate * 1000 + "," + ps2h.Pump.Pressure + "," + ps2h.Pump.RotationRatio + "," + ps2h.Pump.GetElectricConsumption());
          //SHASE委員会_小野さん対応******************************************************************************
          sWriter.WriteLine();

          if (dt.Hour == 0) Console.WriteLine(dt.ToShortDateString());
          dt = dt.AddHours(1);
        }
      }
    }

    #endregion

    #region 熱負荷計算テスト

    /// <summary>周期定常熱負荷計算テスト</summary>
    private static void periodicUnsteadyStateTest()
    {
      double CAP_CL = -2000;  //冷房能力
      double CAP_HT = 2000;   //暖房能力
      double[] DBTSET = new double[] { 26, 22 };          //設定温度
      double[] HRTSET = new double[] { 0.0105, 0.0066 };  //設定湿度

      //気象データ
      double[][] dbt = new double[2][];
      double[][] hrt = new double[2][];
      double[][] rad = new double[2][];
      dbt[0] = new double[] { 24.9, 24.7, 23.8, 24.2, 24.2, 25, 25, 24.4, 24.1, 23.7, 24.6, 25, 25.3, 25.2, 24.9, 24.9, 25.3, 25.9, 25.8, 25.1, 24.2, 23.5, 23.6, 23.5 };
      dbt[1] = new double[] { 4.1, 4.2, 4.6, 5, 4.4, 3.8, 4.8, 4.4, 4.9, 6.5, 7.7, 8.1, 9, 10.1, 10.7, 10.2, 10.1, 9.8, 8.6, 7.9, 7.6, 7.1, 5.4, 4.1 };
      hrt[0] = new double[] { 12.9, 12.8, 13.9, 14.6, 14.7, 14.6, 13.5, 13.7, 14.8, 15.4, 16.1, 15.5, 15.6, 15.6, 16, 16.5, 16.6, 16.4, 16.8, 16, 16, 16.1, 16.2, 16.6 };
      hrt[1] = new double[] { 4.2, 4, 4, 3.6, 4, 3.7, 3.9, 3.9, 3.5, 3.2, 3.4, 3.5, 3.3, 3.2, 3, 3.1, 3.1, 2.8, 2.8, 3, 3.5, 3.1, 3, 3.1 };
      rad[0] = new double[] { 0, 0, 0, 0, 0, 0, 93, 288, 465, 629, 781, 860, 870, 827, 725, 598, 403, 217, 49, 0, 0, 0, 0, 0 };
      rad[1] = new double[] { 0, 0, 0, 0, 0, 0, 0, 1, 146, 318, 438, 506, 532, 467, 391, 232, 83, 0, 0, 0, 0, 0, 0, 0 };

      //建物データを作成
      BuildingThermalModel bMdl = makeSunSpaceBuildingModel();

      //収束判定配列
      double[][][] temp = new double[2][][];
      double[][][] load = new double[2][][];
      for (int i = 0; i < temp.Length; i++)
      {
        temp[i] = new double[2][];
        load[i] = new double[2][];
        for (int j = 0; j < temp[i].Length; j++)
        {
          temp[i][j] = new double[24];
          load[i][j] = new double[24];
        }
      }

      Sun sun = new Sun(Sun.City.Tokyo);
      DateTime dTime;
      for (int ssn = 0; ssn < 2; ssn++) //ssn=0で夏季、ssn=1で冬季の計算
      {
        if (ssn == 0) dTime = new DateTime(2001, 7, 20, 0, 0, 0);
        else dTime = new DateTime(2001, 1, 20, 0, 0, 0);
        double err = 0;
        while (true)
        {
          int hr = dTime.Hour;
          //日射は過去1時間の積算データのため、太陽位置を30分ずらす
          sun.Update(dTime.AddMinutes(30));
          sun.SeparateGlobalHorizontalRadiation(rad[ssn][hr], Sun.SeparationMethod.Erbs);
          bMdl.UpdateOutdoorCondition(dTime, sun, dbt[ssn][hr], hrt[ssn][hr], 0);

          if (8 < dTime.Hour && dTime.Hour < 18)
          {
            //空調時間帯
            bMdl.ControlDrybulbTemperature(0, 0, DBTSET[ssn]);
            bMdl.ControlDrybulbTemperature(0, 1, DBTSET[ssn]);
            bMdl.ControlHumidityRatio(0, 0, HRTSET[ssn]);
            bMdl.ControlHumidityRatio(0, 1, HRTSET[ssn]);
          }
          else
          {
            //非空調時間帯（自然室温）
            bMdl.ControlHeatSupply(0, 0, 0);
            bMdl.ControlHeatSupply(0, 1, 0);
            bMdl.ControlWaterSupply(0, 0, 0);
            bMdl.ControlWaterSupply(0, 1, 0);
          }
          //熱平衡予測
          bMdl.ForecastHeatTransfer();
          bMdl.ForecastWaterTransfer();
          //過負荷の場合には最大容量で成り行き計算
          for (int i = 0; i < 2; i++)
          {
            double hs = bMdl.MultiRoom[0].Zones[i].HeatSupply;
            if (hs < CAP_CL) bMdl.ControlHeatSupply(0, i, CAP_CL);
            else if (CAP_HT < hs) bMdl.ControlHeatSupply(0, i, CAP_HT);
          }
          //熱平衡を確定
          bMdl.ForecastHeatTransfer();
          bMdl.ForecastWaterTransfer();
          bMdl.FixState();

          //収束誤差
          ImmutableZone[] zn = bMdl.MultiRoom[0].Zones;
          for (int i = 0; i < zn.Length; i++)
          {
            err += Math.Abs(temp[ssn][i][dTime.Hour] - zn[i].Temperature);
            err += Math.Abs(load[ssn][i][dTime.Hour] - zn[i].HeatSupply);
            temp[ssn][i][dTime.Hour] = zn[i].Temperature;
            load[ssn][i][dTime.Hour] = zn[i].HeatSupply;
          }
          //収束判定
          if (dTime.Hour == 23)
          {
            dTime = dTime.AddHours(-23);
            if (err < 0.0001) break;
            else err = 0;
          }
          else dTime = dTime.AddHours(1);
        }
      }

      //出力処理
      using (StreamWriter sWriter = new StreamWriter
          ("heatLoadTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.WriteLine
          ("時刻,Z0_DB,Z0_HLS,Z1_DB,Z1_HLS,Z0_DB,Z0_HLS,Z1_DB,Z1_HLS");

        for (int i = 0; i < 24; i++)
        {
          sWriter.Write(i);
          for (int ssn = 0; ssn < 2; ssn++)
          {
            sWriter.Write("," + load[ssn][0][i] + "," + load[ssn][1][i]
                 + "," + temp[ssn][0][i] + "," + temp[ssn][1][i]);
          }
          sWriter.WriteLine();
        }        
      }
    }

    private static BuildingThermalModel makeSunSpaceBuildingModel()
    {
      //傾斜面を作成
      Incline incN = new Incline(Incline.Orientation.N, 0.5 * Math.PI);
      Incline incE = new Incline(Incline.Orientation.E, 0.5 * Math.PI);
      Incline incW = new Incline(Incline.Orientation.W, 0.5 * Math.PI);
      Incline incS = new Incline(Incline.Orientation.S, 0.5 * Math.PI);
      Incline incH = new Incline(Incline.Orientation.N, 0);

      //壁構成を作成
      WallLayer[] exWL = new WallLayer[3];  //外壁
      exWL[0] = new WallLayer("コンクリートブロック", 0.51, 1400, 0.1);
      exWL[1] = new WallLayer("断熱材", 0.04, 14, 0.0615);
      exWL[2] = new WallLayer("木質系サイディング", 0.14, 477, 0.009);
      WallLayer[] flWL = new WallLayer[2];  //床
      flWL[0] = new WallLayer("コンクリート", 1.13, 1400, 0.08);
      flWL[1] = new WallLayer("断熱材（無限大）", 0.00001, 0.00001, 1.0);
      WallLayer[] rfWL = new WallLayer[3];  //屋根
      rfWL[0] = new WallLayer("プラスターボード", 0.16, 798, 0.01);
      rfWL[1] = new WallLayer("断熱材", 0.04, 10, 0.1118);
      rfWL[2] = new WallLayer("木質系屋根", 0.14, 477, 0.019);
      WallLayer[] inWL = new WallLayer[1];  //内壁
      inWL[0] = new WallLayer("コンクリートブロック", 0.51, 1400, 0.2);

      //壁を作成
      Wall[] walls = new Wall[11];
      walls[0] = new Wall(2 * 2.7, exWL);
      walls[1] = new Wall(8 * 2.7 - 6 * 2, exWL);
      walls[2] = new Wall(2 * 2.7, exWL);
      walls[3] = new Wall(2 * 8, rfWL);
      walls[4] = new Wall(2 * 8, flWL);
      walls[5] = new Wall(6 * 2.7, exWL);
      walls[6] = new Wall(8 * 2.7, exWL);
      walls[7] = new Wall(6 * 2.7, exWL);
      walls[8] = new Wall(6 * 8, rfWL);
      walls[9] = new Wall(6 * 8, flWL);
      walls[10] = new Wall(8 * 2.7, inWL);
      for (int i = 0; i < walls.Length; i++)
      {
        walls[i].LongWaveEmissivityF = walls[i].LongWaveEmissivityB = 0.9;
        walls[i].ShortWaveAbsorptanceF = walls[i].ShortWaveAbsorptanceB = 0.8;
      }

      //窓を作成
      Window[] windows = new Window[1];
      windows[0] = new Window(6 * 2, new double[] { 0.7, 0.7 }, new double[] { 0.04, 0.04 }, incS);

      //ゾーンを作成
      Zone[] zones = new Zone[2];
      zones[0] = new Zone("SunSpace", 2 * 8 * 2.7 * 1.2);
      zones[1] = new Zone("BackSpace", 6 * 8 * 2.7 * 1.2);
      //0.2回/hの漏気
      zones[0].VentilationRate = zones[0].AirMass / 3600d * 0.2;
      zones[1].VentilationRate = zones[1].AirMass / 3600d * 0.2;

      //MultiRoomsを作成
      MultiRooms mRoom = new MultiRooms(2, zones, walls, windows);

      //ゾーン設定
      mRoom.AddZone(0, 0);
      mRoom.AddZone(1, 1);
      //壁設定
      mRoom.AddWall(0, 0, true); mRoom.SetOutsideWall(0, false, incW);
      mRoom.AddWall(0, 1, true); mRoom.SetOutsideWall(1, false, incS);
      mRoom.AddWall(0, 2, true); mRoom.SetOutsideWall(2, false, incE);
      mRoom.AddWall(0, 3, true); mRoom.SetOutsideWall(3, false, incH);
      mRoom.AddWall(0, 4, true); mRoom.SetOutsideWall(4, false, incH);
      mRoom.AddWall(1, 5, true); mRoom.SetOutsideWall(5, false, incW);
      mRoom.AddWall(1, 6, true); mRoom.SetOutsideWall(6, false, incN);
      mRoom.AddWall(1, 7, true); mRoom.SetOutsideWall(7, false, incE);
      mRoom.AddWall(1, 8, true); mRoom.SetOutsideWall(8, false, incH);
      mRoom.AddWall(1, 9, true); mRoom.SetOutsideWall(9, false, incH);
      mRoom.AddWall(0, 1, 10);
      //窓設定
      mRoom.AddWindow(0, 0);
      //アルベド
      mRoom.Albedo = 0.2;

      //地中温度は20Cで固定
      mRoom.SetGroundTemperature(4, false, 20);
      mRoom.SetGroundTemperature(9, false, 20);

      return new BuildingThermalModel(new MultiRooms[] { mRoom });
    }

    private static void heatLoadTest()
    {
      const bool HEAT_WATER_SIMAL = false;

      //ゾーンリストの作成/////////////////////////
      Zone[] zones = new Zone[4];
      zones[0] = new Zone("西ペリメータ", 2 * 10 * 3 * 1.2);
      zones[1] = new Zone("西インテリア", 3 * 10 * 3 * 1.2);
      zones[2] = new Zone("東インテリア", 3 * 10 * 3 * 1.2);
      zones[3] = new Zone("東ペリメータ", 2 * 10 * 3 * 1.2);
      SimpleHeatGain hg = new SimpleHeatGain(0, 0, 0);
      //zones[1].AddHeatGain(hg);
      //for (int i = 0; i < zones.Length; i++) zones[i].AddHeatGain(hg);

      //壁リストの作成/////////////////////////////
      WallLayer[] layers = new WallLayer[2];
      layers[0] = new WallLayer("コンクリート", 1.4, 1934, 0.00044, 0.780, 700, 0.4, 0.03);
      layers[1] = new WallLayer("コンクリート", 1.4, 1934, 0.00044, 0.780, 700, 0.4, 0.03);

      Wall[] walls = new Wall[17];
      for (int i = 0; i < walls.Length; i++) walls[i] = new Wall(1, layers, HEAT_WATER_SIMAL);

      walls[0].Area = walls[3].Area = walls[8].Area = walls[11].Area = 2 * 3;
      walls[1].Area = walls[2].Area = walls[9].Area = walls[10].Area = 3 * 3;
      walls[4].Area = walls[7].Area = walls[12].Area = walls[15].Area = 2 * 10;
      walls[5].Area = walls[6].Area = walls[13].Area = walls[14].Area = 2 * 10;
      walls[16].Area = 10 * 3;

      Incline incN = new Incline(Incline.Orientation.N, 0.5 * Math.PI);
      Incline incE = new Incline(Incline.Orientation.E, 0.5 * Math.PI);
      Incline incW = new Incline(Incline.Orientation.W, 0.5 * Math.PI);
      Incline incS = new Incline(Incline.Orientation.S, 0.5 * Math.PI);
      Incline incH = new Incline(Incline.Orientation.N, 0);
      Incline incG = new Incline(Incline.Orientation.N, Math.PI);

      for (int i = 0; i < walls.Length; i++)
      {
        walls[i].ConvectiveCoefficientF = 15d;
        walls[i].ShortWaveAbsorptanceF = 0.7;
        walls[i].LongWaveEmissivityF = 0.9;
        walls[i].ConvectiveCoefficientB = 5d;
        walls[i].ShortWaveAbsorptanceB = 0.7;
        walls[i].LongWaveEmissivityB = 0.9;
        walls[i].Initialize(24);
      }
      walls[16].ConvectiveCoefficientF
        = walls[16].ConvectiveCoefficientB = 5d;

      //窓リストの作成/////////////////////////////
      Window[] windows = new Window[0];
      //windows[0] = new Window(10 * 3, new double[] { 0.7, 0.7 }, new double[] { 0.15, 0.15 }, incW);
      //windows[1] = new Window(10 * 3, new double[] { 0.7, 0.7 }, new double[] { 0.15, 0.15 }, incE);

      //多数室の作成とモデル構築///////////////////
      MultiRooms mRoom = new MultiRooms(2, zones, walls, windows);

      //室にゾーンを追加
      mRoom.AddZone(0, 0);
      mRoom.AddZone(0, 1);
      mRoom.AddZone(1, 2);
      mRoom.AddZone(1, 3);
      //ゾーン間換気の設定
      zones[0].VentilationRate = zones[0].AirMass / 3600d * 0.2;
      mRoom.SetCrossVentilation(0, 1, 0.5 * (zones[0].AirMass + zones[1].AirMass) / 3600d * 0.2);
      mRoom.SetCrossVentilation(1, 2, 0.5 * (zones[0].AirMass + zones[1].AirMass) / 3600d * 0.2);
      mRoom.SetCrossVentilation(2, 3, 0.5 * (zones[2].AirMass + zones[3].AirMass) / 3600d * 0.2);

      //DEBUG
      zones[0].HeatCapacity = zones[0].AirMass * 1006 * 9;

      //屋外表面を設定
      for (int i = 0; i < 4; i++) mRoom.SetOutsideWall(i, true, incS);
      for (int i = 4; i < 8; i++) mRoom.SetOutsideWall(i, true, incG);
      for (int i = 8; i < 12; i++) mRoom.SetOutsideWall(i, true, incN);
      for (int i = 12; i < 16; i++) mRoom.SetOutsideWall(i, true, incH);

      //ゾーンに窓を追加
      //mRoom.AddWindow(0, 0);
      //mRoom.AddWindow(3, 1);

      //ゾーンに壁を追加
      mRoom.AddWall(0, 0, false);
      mRoom.AddWall(0, 4, false);
      mRoom.AddWall(0, 8, false);
      mRoom.AddWall(0, 12, false);
      mRoom.AddWall(1, 1, false);
      mRoom.AddWall(1, 5, false);
      mRoom.AddWall(1, 9, false);
      mRoom.AddWall(1, 13, false);
      mRoom.AddWall(1, 16, true);
      mRoom.AddWall(2, 2, false);
      mRoom.AddWall(2, 6, false);
      mRoom.AddWall(2, 10, false);
      mRoom.AddWall(2, 14, false);
      mRoom.AddWall(2, 16, false);
      mRoom.AddWall(3, 3, false);
      mRoom.AddWall(3, 7, false);
      mRoom.AddWall(3, 11, false);
      mRoom.AddWall(3, 15, false);

      BuildingThermalModel bModel = new BuildingThermalModel(new MultiRooms[] { mRoom });

      //屋外条件///////////////////////////////////
      DateTime dTime = new DateTime(2001, 7, 20, 9, 0, 0);
      Sun sun = new Sun(Sun.City.Tokyo);
      sun.Update(dTime);
      //sun.SetGlobalHorizontalRadiation(0, 500);
      sun.SetGlobalHorizontalRadiation(0, 0);

      //更新処理
      //bModel.UpdateOutdoorCondition(dTime, sun, 30, 0.02, 100);
      bModel.UpdateOutdoorCondition(dTime, sun, 30, 0.015, 0);
      bModel.TimeStep = 3600;
      for (int i = 0; i < 96; i++)
      {
        Console.WriteLine(
          zones[0].Temperature.ToString("F2") + ", " +
          zones[1].Temperature.ToString("F2") + ", " +
          zones[2].Temperature.ToString("F2") + ", " +
          zones[3].Temperature.ToString("F2") + ", " +
          zones[0].HumidityRatio.ToString("F3") + ", " +
          zones[1].HumidityRatio.ToString("F3") + ", " +
          zones[2].HumidityRatio.ToString("F3") + ", " +
          zones[3].HumidityRatio.ToString("F3"));
        bModel.ForecastHeatTransfer();
        bModel.FixState();
      }
    }

    #endregion

    #region 壁体熱流テスト

    /// <summary>壁体熱流テスト</summary>
    private static void wallTest1()
    {
      WallLayer[] layers = new WallLayer[6];
      layers[0] = new WallLayer("フローリング", 0.120, 520, 0.012);
      layers[1] = new WallLayer("合板", 0.160, 720, 0.009);
      layers[2] = new WallLayer("ポリスチレンフォーム", 0.035, 80, 0.020);
      layers[3] = new WallLayer("合板", 0.160, 720, 0.009);
      layers[4] = new AirGapLayer("非密閉空気層", false, 0.05);
      layers[5] = new WallLayer("合板", 0.160, 720, 0.009);
      Wall wall = new Wall(5, layers);

      wall.TimeStep = 600;
      wall.Initialize(16);
      wall.SolAirTemperatureF = 30;
      wall.SolAirTemperatureB = 16;
      wall.ConvectiveCoefficientF = wall.ConvectiveCoefficientB = 4.8;
      wall.RadiativeCoefficientF = wall.RadiativeCoefficientB = 4.5;

      for (int i = 0; i <= 24; i++)
      {
        Console.Write((i * wall.TimeStep).ToString("F0"));
        for (int j = 0; j < wall.Temperatures.Length; j++)
          Console.Write("," + wall.Temperatures[j].ToString("F2"));
        Console.WriteLine();

        /*//シリアライズテスト//不要の場合にはコメントアウト////////////////////////////////////////
        FileStream fs = new FileStream("data.bin", FileMode.Create, FileAccess.Write);
        BinaryFormatter bf = new BinaryFormatter();
        bf.Serialize(fs, wall);
        fs.Close();

        fs = new FileStream("data.bin", FileMode.Open, FileAccess.Read);
        BinaryFormatter f = new BinaryFormatter();
        wall = (Wall)f.Deserialize(fs);
        fs.Close();
        //////////////////////////////////////////////////////////////////////////////////////////*/

        wall.Update();
      }
    }

    /// <summary>壁体熱流テスト:潜熱蓄熱材</summary>
    private static void wallTest2()
    {
      WallLayer[] layers = new WallLayer[6];
      layers[0] = new WallLayer("フローリング", 0.120, 520, 0.012);
      layers[1] = new PCMWallLayer("PCM", 19, 23, 0.02,
        new WallLayer("固体", 0.190, 5000, 0.02),
        new WallLayer("平衡", 0.205, 21000, 0.02),
        new WallLayer("液体", 0.220, 3000, 0.02));
      layers[2] = new WallLayer("ポリスチレンフォーム", 0.035, 80, 0.020);
      layers[3] = new WallLayer("合板", 0.160, 720, 0.009);
      layers[4] = new AirGapLayer("非密閉空気層", false, 0.05);
      layers[5] = new WallLayer("合板", 0.160, 720, 0.009);
      Wall wall = new Wall(5, layers);

      wall.TimeStep = 600;
      wall.Initialize(16);
      wall.ConvectiveCoefficientF = wall.ConvectiveCoefficientB = 4.8;
      wall.RadiativeCoefficientF = wall.RadiativeCoefficientB = 4.5;

      wall.SolAirTemperatureF = 30;
      wall.SolAirTemperatureB = 16;

      for (int i = 0; i <= 144; i++)
      {
        Console.Write((i * wall.TimeStep).ToString("F0"));
        for (int j = 0; j < wall.Temperatures.Length; j++)
          Console.Write("," + wall.Temperatures[j].ToString("F2"));
        Console.WriteLine();
        wall.Update();
      }
    }

    /// <summary>壁体熱流テスト:床冷暖房</summary>
    private static void wallTest3()
    {
      WallLayer[] layers = new WallLayer[6];
      layers[0] = new WallLayer("フローリング", 0.120, 520, 0.012);
      layers[1] = new WallLayer("合板", 0.160, 720, 0.009);
      layers[2] = new WallLayer("ポリスチレンフォーム", 0.035, 80, 0.020);
      layers[3] = new WallLayer("合板", 0.160, 720, 0.009);
      layers[4] = new AirGapLayer("非密閉空気層", false, 0.05);
      layers[5] = new WallLayer("合板", 0.160, 720, 0.009);
      Wall wall = new Wall(5, layers);

      wall.TimeStep = 600;
      wall.Initialize(16);
      wall.ConvectiveCoefficientF = wall.ConvectiveCoefficientB = 4.8;
      wall.RadiativeCoefficientF = wall.RadiativeCoefficientB = 4.5;

      wall.SolAirTemperatureF = 30;
      wall.SolAirTemperatureB = 16;

      wall.AddPipe(1, 0.05, 200, 40, 0.004, 0.0046, 0.47);
      wall.SetInletWater(1, 0.014, 20);

      for (int i = 0; i <= 24; i++)
      {
        Console.Write((i * wall.TimeStep).ToString("F0"));
        for (int j = 0; j < wall.Temperatures.Length; j++)
          Console.Write("," + wall.Temperatures[j].ToString("F2"));
        Console.WriteLine("," + wall.GetHeatTransferFromPipe(1).ToString("F2")
          + "," + wall.GetOutletWaterTemperature(1).ToString("F2"));
        wall.Update();
      }
    }

    /// <summary>壁体熱流テスト:熱水分同時移動</summary>
    /// <remarks>松本衛:博士論文pp.8-10より</remarks>
    private static void wallTest4()
    {
      WallLayer[] layers = new WallLayer[3];
      for (int i = 0; i < layers.Length; i++)
        layers[i] = new WallLayer
          ("木繊維板", 0.1116, 585, 0.000004694, 0.788, 3080, 1.715, 0.006);

      Wall wallA = new Wall(1, layers, true);
      Wall wallB = new Wall(1, layers, false);

      wallA.TimeStep = wallB.TimeStep = 60;
      wallA.Initialize(20, 0.008);
      wallB.Initialize(20);
      wallA.ConvectiveCoefficientF = wallB.ConvectiveCoefficientF = 4.8;
      wallA.ConvectiveCoefficientB = wallB.ConvectiveCoefficientB = 0;
      wallA.RadiativeCoefficientF = wallB.RadiativeCoefficientF =
        wallA.RadiativeCoefficientB = wallB.RadiativeCoefficientB = 0.0;

      wallA.SolAirTemperatureF = wallB.SolAirTemperatureF = 21;
      wallA.SolAirTemperatureB = wallB.SolAirTemperatureB = 20;
      wallA.HumidityRatioF = wallB.HumidityRatioF = 0.008;
      wallA.HumidityRatioB = wallB.HumidityRatioB = 0.008;
      for (int i = 0; i < 240; i++)
      {
        Console.WriteLine((i * 60) + ", " +
          wallA.Temperatures[0].ToString("F3") + ", " +
          wallB.Temperatures[0].ToString("F3") + ", " +
          wallA.Humidities[0].ToString("F6"));
        wallA.Update();
        wallB.Update();
      }
    }

    /// <summary>床熱流テスト:床・天井チャンバ</summary>
    private static void floorTest1()
    {
      WallLayer[] layers = new WallLayer[6];
      layers[0] = new WallLayer("フローリング", 0.120, 520, 0.012);
      layers[1] = new WallLayer("合板", 0.160, 720, 0.009);
      layers[2] = new WallLayer("ポリスチレンフォーム", 0.035, 80, 0.020);
      layers[3] = new WallLayer("合板", 0.160, 720, 0.009);
      layers[4] = new HorizontalAirChamber("床下チャンバ", 0.05);
      layers[5] = new WallLayer("合板", 0.160, 720, 0.009);
      Wall wall = new Wall(5, layers);

      HorizontalAirChamber chmb = wall.Layers[4] as HorizontalAirChamber;

      wall.TimeStep = 600;
      wall.Initialize(16);
      wall.SolAirTemperatureF = 16;
      wall.SolAirTemperatureB = 40;
      wall.ConvectiveCoefficientF = wall.ConvectiveCoefficientB = 4.8;
      wall.RadiativeCoefficientF = wall.RadiativeCoefficientB = 4.5;

      for (int i = 0; i <= 24; i++)
      {
        Console.Write((i * wall.TimeStep).ToString("F0"));
        Console.Write(", " + 
          wall.Temperatures[4].ToString("F2") + ", " +
          wall.Temperatures[5].ToString("F2") + ", " +
          chmb.ConvectiveHeatTransferCoefficient.ToString("F3") + ", " + 
          chmb.RadiativeHeatTransferCoefficient.ToString("F3") + ", " +
          chmb.HeatConductance.ToString("F3"));
        Console.WriteLine();
        wall.Update();

        wall.SolAirTemperatureB--;  //床下温度を下げていく
      }
    }

    #endregion

    #region 窓テスト

    private static void windowTest()
    {
      Incline inc = new Incline(0.0, 0.5 * Math.PI);
      Window[] win = new Window[4];
      for (int i = 0; i < win.Length; i++)
      {
        win[i] = new Window(1,
          new double[] { 0.396, 0.859 }, new double[] { 0.355, 0.077 },
          new double[] { 0.396, 0.859 }, new double[] { 0.427, 0.077 }, inc);
        for (int j = 0; j < win[i].GlazingNumber; j++)
        {
          if(j != win[i].GlazingNumber - 1)
            win[i].SetAirGapResistance(j, 1 / 8d);
          win[i].SetGlassResistance(j, 0.006 / 1d);
        }
        win[i].ConvectiveCoefficientF = 18.5;
        win[i].RadiativeCoefficientF = 4.5;
        win[i].ConvectiveCoefficientB = 4.5;
        win[i].RadiativeCoefficientB = 4.5;
      }

      VenetianBlind[] blinds = new VenetianBlind[3];
      for (int i = 0; i < blinds.Length; i++)
      {
        blinds[i] = new VenetianBlind(25, 22.5, 0, 0, 0.7, 0.7);
        blinds[i].SlatAngle = 30 / 180d * Math.PI;
        blinds[i].Pulldowned = true;
      }
      win[1].SetShadingDevice(2, blinds[0]);
      win[2].SetShadingDevice(1, blinds[1]);
      win[3].SetShadingDevice(0, blinds[2]);

      Sun sun = new Sun(Sun.City.Tokyo);
      DateTime dTime = new DateTime(2001, 7, 20, 7, 0, 0);
      using (StreamWriter sWriter = new StreamWriter
        ("WindowTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.WriteLine
          ("時刻,無透,無反,無吸,内透,内反,内吸,中透,中反,中吸,外透,外反,外吸");

        while (true)
        {
          if (dTime.Hour == 16) break;

          sWriter.Write(dTime.ToShortTimeString());
          sun.Update(dTime);
          for (int i = 0; i < win.Length; i++)
          {
            win[i].UpdateOpticalProperties(sun);
            sWriter.Write(
              "," + win[i].DirectSolarIncidentTransmittance.ToString("F3") +
              "," + win[i].DirectSolarIncidentReflectance.ToString("F3") +
              "," + win[i].DirectSolarIncidentAbsorptance.ToString("F3"));
          }
          sWriter.WriteLine();
          dTime = dTime.AddMinutes(5);
        }
      }  
    }

    #endregion

    #region 日射遮蔽テスト

    private static void sunShadeTest()
    {
      Incline incS = new Incline(Incline.Orientation.S, 0.5 * Math.PI);
      Incline incW = new Incline(Incline.Orientation.W, 0.5 * Math.PI);
      SunShade[] ss = new SunShade[6];
      ss[0] = SunShade.MakeHorizontalSunShade(3.8, 2.7, 0.6, 0.1, 0.1, 0.1, incS);
      ss[1] = SunShade.MakeVerticalSunShade(3.8, 2.7, 0.6, 0.1, 0.1, 0.1, 0.1, incS);
      ss[2] = SunShade.MakeGridSunShade(3.8, 2.7, 0.6, 0.1, 0.1, 0.1, 0.1, incS);
      ss[3] = SunShade.MakeHorizontalSunShade(3.8, 2.7, 0.6, 0.1, 0.1, 0.1, incW);
      ss[4] = SunShade.MakeVerticalSunShade(3.8, 2.7, 0.6, 0.1, 0.1, 0.1, 0.1, incW);
      ss[5] = SunShade.MakeGridSunShade(3.8, 2.7, 0.6, 0.1, 0.1, 0.1, 0.1, incW);

      DateTime dTime = new DateTime(2015, 7, 20, 7, 0, 0);
      Sun sun = new Sun(Sun.City.Tokyo);
      while (true)
      {
        if (dTime.Hour == 19) break;
        Console.Write(dTime.ToShortTimeString());
        sun.Update(dTime);

        for (int i = 0; i < ss.Length; i++) Console.Write(", " + ss[i].GetShadowRate(sun).ToString("F3"));
        Console.WriteLine();
        dTime = dTime.AddMinutes(5);
      }
    }

    private static void venetianBlindTest1()
    {
      VenetianBlind[] blinds = new VenetianBlind[5];
      double[] sltRho = new double[] { 0.1, 0.3, 0.5, 0.7, 0.9 };
      for (int i = 0; i < blinds.Length; i++)
      {
        blinds[i] = new VenetianBlind(25, 22.5, 0, 0, sltRho[i], 0.5);
        blinds[i].ProfileAngle = 30 / 180d * Math.PI;
        blinds[i].Pulldowned = true;
      }

      using (StreamWriter sWriter = new StreamWriter
        ("VenetianBlindTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.Write("SlatAngle");
        for (int i = 0; i < 5; i++) sWriter.Write(", " + sltRho[i] + ":DirTau");
        for (int i = 0; i < 5; i++) sWriter.Write(", " + sltRho[i] + ":DirRho");
        for (int i = 0; i < 5; i++) sWriter.Write(", " + sltRho[i] + ":DifTau");
        for (int i = 0; i < 5; i++) sWriter.Write(", " + sltRho[i] + ":DifRho");
        sWriter.WriteLine();

        double[] drTau = new double[blinds.Length];
        double[] drRho = new double[blinds.Length];
        double[] dfTau = new double[blinds.Length];
        double[] dfRho = new double[blinds.Length];
        for (int i = -90; i <= 90; i += 5)
        {
          sWriter.Write(i);
          for (int j = 0; j < blinds.Length; j++)
          {
            blinds[j].SlatAngle = i / 180d * Math.PI;
            blinds[j].ComputeOpticalProperties(false, true, out drTau[j], out drRho[j]);
            blinds[j].ComputeOpticalProperties(true, true, out dfTau[j], out dfRho[j]);
          }

          for (int j = 0; j < 5; j++) sWriter.Write(", " + drTau[j]);
          for (int j = 0; j < 5; j++) sWriter.Write(", " + drRho[j]);
          for (int j = 0; j < 5; j++) sWriter.Write(", " + dfTau[j]);
          for (int j = 0; j < 5; j++) sWriter.Write(", " + dfRho[j]);
          sWriter.WriteLine();
        }
      }
    }

    private static void venetianBlindTest2()
    {
      VenetianBlind blind = new VenetianBlind(25, 22.5, 0.0, 0.0, 0.7, 0.7);
      blind.ProfileAngle = 30 / 180d * Math.PI;
      blind.Pulldowned = true;

      using (StreamWriter sWriter = new StreamWriter
        ("VenetianBlindTest2.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.WriteLine("SlatAngle, upperTrans, lowerTrans, upperDirTrans, lowerDirTrans, directTrans");

        for (int i = -90; i <= 90; i += 5)
        {
          blind.SlatAngle = i / 180d * Math.PI;
          double upDifT, lwDifT, upDrT, lwDirT, drT;
          double trs, rfc;
          blind.ComputeOpticalProperties(true, true, out trs, out rfc);
          blind.ComputeOpticalProperties(false, true, out trs, out rfc);
          blind.ComputeOpticalProperties(out upDifT, out lwDifT, out upDrT, out lwDirT, out drT);
          sWriter.WriteLine(i + "," + upDifT + "," + lwDifT + "," + upDrT + "," + lwDirT + "," + drT);
        }
      }
    }

    #endregion

    #region 吸着式テスト

    private static void adsorptionChillerTest2()
    {
      AdsorptionChiller adr1 = new AdsorptionChiller
      // (21, 14, 11.1 / 3.6, 30, 35, 49.5 / 3.6, 70, 64.5, 30 / 3.6);
      //(21, 14, 11.1 / 3.6, 30, 34.7, 49.5 / 3.6, 60, 55, 30 / 3.6);
        (21, 14, 11.1 / 3.6, 29, 33.7, 49.5 / 3.6, 60, 55, 30 / 3.6);
      adr1.ChilledWaterOutletSetPointTemperature = 0;

      //adr1.Update(21, 11.1 / 3.6, 29, 49.5 / 3.6, 60, 30 / 3.6);

      using (StreamReader sReader = new StreamReader("inputs.csv"))
      using (StreamWriter sWriter = new StreamWriter("outputs.csv"))
      {
        string buff;
        sReader.ReadLine();//タイトル行
        sWriter.WriteLine("Tcdo,Tho,Tcho,Qch,COP,wsad0,wsadt");
        while ((buff = sReader.ReadLine()) != null)
        {
          string[] buff2 = buff.Split(',');
          double tcdi = double.Parse(buff2[0]);
          double thi = double.Parse(buff2[2]);
          double tchi = double.Parse(buff2[4]);
          double mcd = double.Parse(buff2[6]) / 60d;
          double mh = double.Parse(buff2[7]) / 60d;
          double mch = double.Parse(buff2[8]) / 60d;

          adr1.Update(tchi, mch, tcdi, mcd, thi, mh);
          sWriter.WriteLine(
            adr1.CoolingWaterOutletTemperature + "," +
            adr1.HotWaterOutletTemperature + "," +
            adr1.ChilledWaterOutletTemperature + "," +
            adr1.CoolingLoad + "," + adr1.COP + "," + adr1.WaterContent_Desorption + "," + adr1.WaterContent_Adsorption);
        }
      }
    }

    private static void adsorptionChillerTest()
    {
      double mchw = 54d / 60;
      double mcdw = 127d / 60d;
      double mhw = 64.5 / 60;
      double cop = 0.47;
      double qch = 8.8;
      double qh = qch / cop;
      double qcd = qch + qh;
      double tchi = 22;
      double thi = 55;
      double tcdi = 27;
      double tcho = tchi - qch / (4.186 * mchw);
      double tho = thi - qh / (4.186 * mhw);
      double tcdo = tcdi + qcd / (4.186 * mcdw);
      AdsorptionChiller ads = new AdsorptionChiller(tchi, tcho, mchw, tcdi, tcdo, mcdw, thi, tho, mhw);

      //ads.CyclingTimeRate = 3.0;
      ads.Update(tchi, mchw, tcdi, mcdw, thi, mhw);

      ads.Update(tchi, mchw, 27, mcdw, 45, mhw);

      using (StreamWriter sWriter = new StreamWriter
        ("adsorptionChillerTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {

        sWriter.WriteLine("温水入口温度, 冷水流量比[-], COP, 冷凍能力, 吸着温度, 脱着温度, 冷水出口温度, 吸着量（吸着時）, 吸着量（脱着時）");
        for (int thw = 45; thw <= 55; thw += 2)
        {
          for (int i = 40; i <= 100; i+=5)
          {
            double rt = i / 100d;
            ads.Update(22, mchw * rt, 27, mcdw, thw, mhw);
            sWriter.WriteLine(thw + ", " + rt + ", " + ads.COP.ToString("F3") + ", " + ads.CoolingLoad.ToString("F3") + ", " +
              +ads.CoolingWaterOutletTemperature + ", " + ads.HotWaterOutletTemperature + ", " + ads.ChilledWaterOutletTemperature + ", "
              + ads.WaterContent_Adsorption + ", " + ads.WaterContent_Desorption);
          }
        }

        sWriter.WriteLine("温水入口温度, 冷水入口温度, COP, 冷凍能力, 吸着温度, 脱着温度, 冷水出口温度, 吸着量（吸着時）, 吸着量（脱着時）");
        for (int thw = 45; thw <= 55; thw += 2)
        {
          for (int i = 20; i <= 28; i ++)
          {
            ads.Update(i, mchw, 27, mcdw, thw, mhw);
            sWriter.WriteLine(thw + ", " + i + ", " + ads.COP.ToString("F3") + ", " + ads.CoolingLoad.ToString("F3") + ", " +
              +ads.CoolingWaterOutletTemperature + ", " + ads.HotWaterOutletTemperature + ", " + ads.ChilledWaterOutletTemperature + ", "
              + ads.WaterContent_Adsorption + ", " + ads.WaterContent_Desorption);
          }
        }

        sWriter.WriteLine("温水入口温度, 温水流量, COP, 冷凍能力, 吸着温度, 脱着温度, 冷水出口温度, 吸着量（吸着時）, 吸着量（脱着時）");
        for (int thw = 45; thw <= 55; thw += 2)
        {
          for (int i = 40; i <= 100; i+=5)
          {
            double rt = i / 100d;
            ads.Update(22, mchw, 27, mcdw, thw, mhw * rt);
            sWriter.WriteLine(thw + ", " + rt + ", " + ads.COP.ToString("F3") + ", " + ads.CoolingLoad.ToString("F3") + ", " +
              +ads.CoolingWaterOutletTemperature + ", " + ads.HotWaterOutletTemperature + ", " + ads.ChilledWaterOutletTemperature + ", "
              + ads.WaterContent_Adsorption + ", " + ads.WaterContent_Desorption);
          }
        }

        sWriter.WriteLine("冷却水入口温度, 温水入口温度, COP, 冷凍能力, 吸着温度, 脱着温度, 冷水出口温度, 吸着量（吸着時）, 吸着量（脱着時）");
        for (int i = 24; i <= 33; i+=3)
        {
          for (int thw = 45; thw <= 60; thw ++)
          {
            ads.Update(22, mchw, i, mcdw, thw, mhw);
            sWriter.WriteLine(i + ", " + thw + ", " + ads.COP.ToString("F3") + ", " + ads.CoolingLoad.ToString("F3") + ", " +
              +ads.CoolingWaterOutletTemperature + ", " + ads.HotWaterOutletTemperature + ", " + ads.ChilledWaterOutletTemperature + ", "
              + ads.WaterContent_Adsorption + ", " + ads.WaterContent_Desorption);
          }
        }

        sWriter.WriteLine("温水入口温度, 冷却水流量, COP, 冷凍能力, 吸着温度, 脱着温度, 冷水出口温度, 吸着量（吸着時）, 吸着量（脱着時）");
        for (int thw = 45; thw <= 55; thw += 2)
        {
          for (int i = 40; i <= 100; i+=5)
          {
            double rt = i / 100d;
            ads.Update(22, mchw, 27, mcdw * rt, thw, mhw);
            sWriter.WriteLine(thw + ", " + rt + ", " + ads.COP.ToString("F3") + ", " + ads.CoolingLoad.ToString("F3") + ", " +
              +ads.CoolingWaterOutletTemperature + ", " + ads.HotWaterOutletTemperature + ", " + ads.ChilledWaterOutletTemperature + ", "
              + ads.WaterContent_Adsorption + ", " + ads.WaterContent_Desorption);
          }
        }

        sWriter.WriteLine("温水入口温度, 冷却水入口温度, COP, 冷凍能力, 吸着温度, 脱着温度, 冷水出口温度, 吸着量（吸着時）, 吸着量（脱着時）");
        for (int thw = 55; thw <= 65; thw += 5)
        {
          for (int i = 24; i <= 32; i++)
          {
            ads.Update(22, mchw, i, mcdw, thw, mhw);
            sWriter.WriteLine(thw + ", " + i + ", " + ads.COP.ToString("F3") + ", " + ads.CoolingLoad.ToString("F3") + ", " +
              +ads.CoolingWaterOutletTemperature + ", " + ads.HotWaterOutletTemperature + ", " + ads.ChilledWaterOutletTemperature + ", "
              + ads.WaterContent_Adsorption + ", " + ads.WaterContent_Desorption);
          }
        }

        sWriter.WriteLine("温水入口温度, サイクル周期比率, COP, 冷凍能力, 吸着温度, 脱着温度, 冷水出口温度, 吸着量（吸着時）, 吸着量（脱着時）");
        for (int thw = 45; thw <= 55; thw += 2)
        {
          for (int i = 2; i <= 10; i++)
          {
            ads.CyclingTimeRate = i * 0.5;
            ads.Update(22, mchw, 27, mcdw, thw, mhw);
            sWriter.WriteLine(thw + ", " + ads.CyclingTimeRate + ", " + ads.COP.ToString("F3") + ", " + ads.CoolingLoad.ToString("F3") + ", " +
              +ads.CoolingWaterOutletTemperature + ", " + ads.HotWaterOutletTemperature + ", " + ads.ChilledWaterOutletTemperature + ", "
              + ads.WaterContent_Adsorption + ", " + ads.WaterContent_Desorption);
          }
        }
      }
    }

    #endregion

    #region 回路網テスト

    private static void PipeFlowTest()
    {
      //レイノルズ数[-]
      double[] rn = new double[6 * 9];
      for (int i = 0; i < 6; i++)
        for (int j = 0; j < 9; j++)
          rn[i * 9 + j] = (j + 1) * 100 * Math.Pow(10, i);

      //相対粗度[-]
      double[] rf = new double[] 
      { 1e-6, 5e-6, 1e-5, 5e-5, 1e-4, 2e-4, 4e-4, 6e-4, 8e-4,
        1e-3, 2e-3, 4e-3, 6e-3, 8e-3, 0.01, 0.015, 0.02, 0.03, 0.04, 0.05 };

      using (StreamWriter sWriter = 
        new StreamWriter("PipeFlowTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        for (int i = 0; i < rf.Length; i++) sWriter.Write("," + rf[i]);
        sWriter.WriteLine();
        for (int i = 0; i < rn.Length; i++)
        {
          sWriter.Write(rn[i]);
          for (int j = 0; j < rf.Length; j++)
          {
            double fc = Conduit.GetFrictionFactor(rn[i], rf[j]);
            sWriter.Write("," + fc);
          }
          sWriter.WriteLine();
        }
      }
    }

    private static void CircuitNetworkTest1()
    {
      CircuitNetwork cnetUStrm, cnetDStrm;
      makePumpNetwork1(out cnetUStrm, out cnetDStrm);
      CircuitNode[] nodesUStrm = cnetUStrm.Nodes;
      CircuitNode[] nodesDStrm = cnetDStrm.Nodes;

      //吐出圧一定制御////////////////////////
      //上流側の計算
      cnetUStrm.SetBasePressure(nodesUStrm[0], 250);
      cnetUStrm.Solve();
      //下流側の計算
      cnetDStrm.SetBasePressure(nodesDStrm[0], 0);
      cnetDStrm.Solve();
      //出力
      using (StreamWriter sWriter = new StreamWriter
        ("CircuitNetworkTest1.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.WriteLine("節点, 01, 02, 05, 08, 11, 03, 06, 09, 12, 00, 04, 07, 10, 13");
        sWriter.Write("吐出圧一定制御:圧力[kPa]");
        for (int i = 0; i < nodesUStrm.Length; i++) sWriter.Write("," + nodesUStrm[i].Pressure);
        for (int i = 0; i < nodesDStrm.Length; i++) sWriter.Write("," + nodesDStrm[i].Pressure);
        sWriter.WriteLine();
      }

      //末端差圧一定制御////////////////////////
      //下流側の計算
      cnetDStrm.SetBasePressure(nodesDStrm[0], 0);
      cnetDStrm.Solve();
      //上流側の計算
      cnetUStrm.SetBasePressure(nodesUStrm[4], nodesDStrm[4].Pressure + 160);
      cnetUStrm.Solve();
      //出力
      using (StreamWriter sWriter = new StreamWriter
        ("CircuitNetworkTest1.csv", true, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.Write("末端差圧一定制御:圧力[kPa]");
        for (int i = 0; i < nodesUStrm.Length; i++) sWriter.Write("," + nodesUStrm[i].Pressure);
        for (int i = 0; i < nodesDStrm.Length; i++) sWriter.Write("," + nodesDStrm[i].Pressure);
      }
    }

    private static void CircuitNetworkTest2()
    {
      CircuitNetwork cnetUStrm, cnetDStrm, cnetDDC;
      makePumpNetwork1(out cnetUStrm, out cnetDStrm);
      makePumpNetwork2(out cnetDDC);      
      CentrifugalPump pump = new CentrifugalPump
        (260, 0.03, 250, 0.03, CentrifugalPump.ControlMethod.ConstantPressureWithInverter, 40);
      PumpSystem ps = new PumpSystem(pump, 250, 0.09, 40, 3);
      double[] flows = new double[4];
      
      using (StreamWriter sWriter = new StreamWriter
        ("CircuitNetworkTest2.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.WriteLine("負荷率, ポンプ揚程[kPa], 消費電力[kW]");
        sWriter.WriteLine("負荷率均等低減");
        for (int i = 0; i <= 30; i++)
        {
          //負荷率を均等に低減
          double pl = 1.0 - 0.03 * i;
          sWriter.Write(pl);
          ps.TotalFlowRate = pl * 0.09;
          for (int j = 0; j < flows.Length; j++) flows[j] = pl * 0.0225;
          CircuitNetworkTest2_DDCCntrl(cnetUStrm, cnetDStrm, cnetDDC, flows);
          ps.PressureSetpoint = cnetDDC.Nodes[1].Pressure;
          ps.UpdateState();
          sWriter.WriteLine(", " + cnetDDC.Nodes[1].Pressure + ", " + ps.GetElectricConsumption());
        }
        sWriter.WriteLine("負荷率不均等低減1");
        for (int i = 0; i <= 30; i++)
        {
          //手前側のAHUから負荷を低減
          double pl = 4 * 0.03 * i;
          sWriter.Write(1 - pl / 4);
          ps.TotalFlowRate = (1 - pl / 4) * 0.09;
          for (int j = 0; j < 4; j++)
          {
            flows[j] = Math.Max(0.1, 1 - pl);
            pl = pl - (1 - flows[j]);
            flows[j] *= 0.0225;
          }
          CircuitNetworkTest2_DDCCntrl(cnetUStrm, cnetDStrm, cnetDDC, flows);
          ps.PressureSetpoint = cnetDDC.Nodes[1].Pressure;
          ps.UpdateState();
          sWriter.WriteLine(", " + cnetDDC.Nodes[1].Pressure + ", " + ps.GetElectricConsumption());
        }
        sWriter.WriteLine("負荷率不均等低減2");
        for (int i = 0; i <= 30; i++)
        {
          //末端側のAHUから負荷を低減
          double pl = 4 * 0.03 * i;
          sWriter.Write(1 - pl / 4);
          ps.TotalFlowRate = (1 - pl / 4) * 0.09;
          for (int j = 3; 0 <= j; j--)
          {
            flows[j] = Math.Max(0.1, 1 - pl);
            pl = pl - (1 - flows[j]);
            flows[j] *= 0.0225;
          }
          CircuitNetworkTest2_DDCCntrl(cnetUStrm, cnetDStrm, cnetDDC, flows);
          ps.PressureSetpoint = cnetDDC.Nodes[1].Pressure;
          ps.UpdateState();
          sWriter.WriteLine(", " + cnetDDC.Nodes[1].Pressure + ", " + ps.GetElectricConsumption());
        }
      }
    }

    private static void CircuitNetworkTest2_DDCCntrl
      (CircuitNetwork cnetUStrm, CircuitNetwork cnetDStrm, CircuitNetwork cnetDDC, double[] flows)
    {
      CircuitNode[] ndUStrm = cnetUStrm.Nodes;
      CircuitNode[] ndDStrm = cnetDStrm.Nodes;
      CircuitNode[] ndDDC = cnetDDC.Nodes;
      CircuitNode[] ndBND_CNST = new CircuitNode[]
      { ndUStrm[5], ndUStrm[6], ndUStrm[7], ndUStrm[8], ndDStrm[1], ndDStrm[2], ndDStrm[3], ndDStrm[4] };
      CircuitNode[] ndBND_DDC = new CircuitNode[]
      { ndDDC[3], ndDDC[6], ndDDC[9], ndDDC[12], ndDDC[4], ndDDC[7], ndDDC[10], ndDDC[13] };
      Regulator reg = new Regulator(340, 100, 0.5);

      //AHUの流量を設定
      double sum = 0;
      for (int i = 0; i < 4; i++)
      {
        sum += flows[i];
        ndBND_CNST[i].Inflow = ndBND_DDC[i].Inflow = -flows[i];
        ndBND_CNST[i + 4].Inflow = ndBND_DDC[i + 4].Inflow = flows[i];
      }
      ndUStrm[0].Inflow = ndDDC[1].Inflow = sum;
      ndDStrm[0].Inflow = ndDDC[0].Inflow = -sum;

      //吐出圧一定制御で計算
      cnetUStrm.SetBasePressure(ndUStrm[0], 250);
      cnetDStrm.SetBasePressure(ndDStrm[0], 0);
      cnetUStrm.Solve();
      cnetDStrm.Solve();

      //二方弁開度を計算//最大負荷系統を特定
      int index = 0;
      double max = 0;
      for (int i = 0; i < 4; i++)
      {
        reg.UpdateLift(ndBND_CNST[i].Pressure - ndBND_CNST[i + 4].Pressure);
        if (max < reg.Lift)
        {
          index = i;
          max = reg.Lift;
        }
      }

      //最大負荷系統に開度100%の二方弁を設定して計算
      reg.Lift = 1.0;
      cnetDDC.ConnectNode(reg, ndBND_DDC[index], ndBND_DDC[index + 4]);
      ndBND_DDC[index].Inflow = ndBND_DDC[index + 4].Inflow = 0;
      cnetDDC.SetBasePressure(ndDDC[0], 0);
      cnetDDC.Solve();
      cnetDDC.RemoveBranch(reg);
    }

    private static void makePumpNetwork1
      (out CircuitNetwork cnetUStrm, out CircuitNetwork cnetDStrm)
    {
      double lcf = 1.5; //局部抵抗係数

      //上流型回路
      cnetUStrm = new CircuitNetwork();
      WaterPipe ch01_02 = new WaterPipe(30 * lcf, 0.150, WaterPipe.Material.CarbonSteel);
      WaterPipe ch02_05 = new WaterPipe(5 * lcf, 0.100, WaterPipe.Material.CarbonSteel);
      WaterPipe ch01_08 = new WaterPipe(70 * lcf, 0.150, WaterPipe.Material.CarbonSteel);
      WaterPipe ch08_11 = new WaterPipe(5 * lcf, 0.100, WaterPipe.Material.CarbonSteel);
      SimpleCircuitBranch ch02_03_ahu1 = new SimpleCircuitBranch(0.0225, 150);
      SimpleCircuitBranch ch05_06_ahu2 = new SimpleCircuitBranch(0.0225, 150);
      SimpleCircuitBranch ch08_09_ahu3 = new SimpleCircuitBranch(0.0225, 150);
      SimpleCircuitBranch ch11_12_ahu4 = new SimpleCircuitBranch(0.0225, 150);
      CircuitNode[] nodesUStrm = new CircuitNode[9]; //01, 02, 05, 08, 11, 03, 06, 09, 12の順
      for (int i = 0; i < nodesUStrm.Length; i++) nodesUStrm[i] = cnetUStrm.AddNode();
      cnetUStrm.ConnectNode(ch01_02, nodesUStrm[0], nodesUStrm[1]);
      cnetUStrm.ConnectNode(ch02_05, nodesUStrm[1], nodesUStrm[2]);
      cnetUStrm.ConnectNode(ch01_08, nodesUStrm[0], nodesUStrm[3]);
      cnetUStrm.ConnectNode(ch08_11, nodesUStrm[3], nodesUStrm[4]);
      cnetUStrm.ConnectNode(ch02_03_ahu1, nodesUStrm[1], nodesUStrm[5]);
      cnetUStrm.ConnectNode(ch05_06_ahu2, nodesUStrm[2], nodesUStrm[6]);
      cnetUStrm.ConnectNode(ch08_09_ahu3, nodesUStrm[3], nodesUStrm[7]);
      cnetUStrm.ConnectNode(ch11_12_ahu4, nodesUStrm[4], nodesUStrm[8]);
      //境界条件, 初期値設定     
      nodesUStrm[0].Inflow = 0.0225 * 4;  //流入量
      for (int i = 5; i < 9; i++) nodesUStrm[i].Inflow = -0.0225; //流出量
      for (int i = 0; i < nodesUStrm.Length; i++) nodesUStrm[i].Pressure = 0;

      //下流側回路
      cnetDStrm = new CircuitNetwork();
      WaterPipe ch04_00 = new WaterPipe(30 * lcf, 0.150, WaterPipe.Material.CarbonSteel);
      WaterPipe ch07_04 = new WaterPipe(5 * lcf, 0.100, WaterPipe.Material.CarbonSteel);
      WaterPipe ch10_00 = new WaterPipe(70 * lcf, 0.150, WaterPipe.Material.CarbonSteel);
      WaterPipe ch13_10 = new WaterPipe(5 * lcf, 0.100, WaterPipe.Material.CarbonSteel);
      CircuitNode[] nodesDStrm = new CircuitNode[5]; //00, 04, 07, 10, 13の順
      for (int i = 0; i < nodesDStrm.Length; i++) nodesDStrm[i] = cnetDStrm.AddNode();
      cnetDStrm.ConnectNode(ch04_00, nodesDStrm[1], nodesDStrm[0]);
      cnetDStrm.ConnectNode(ch07_04, nodesDStrm[2], nodesDStrm[1]);
      cnetDStrm.ConnectNode(ch10_00, nodesDStrm[3], nodesDStrm[0]);
      cnetDStrm.ConnectNode(ch13_10, nodesDStrm[4], nodesDStrm[3]);
      //境界条件, 初期値設定  
      for (int i = 1; i < 5; i++) nodesDStrm[i].Inflow = 0.0225; //流出量
      nodesDStrm[0].Inflow = -0.0225 * 4;  //流入量
      for (int i = 0; i < nodesUStrm.Length; i++) nodesUStrm[i].Pressure = 0;
    }

    private static void makePumpNetwork2(out CircuitNetwork cnetDDC)
    {
      double lcf = 1.5; //局部抵抗係数

      cnetDDC = new CircuitNetwork();
      WaterPipe ch01_02_DDC = new WaterPipe(30 * lcf, 0.150, WaterPipe.Material.CarbonSteel);
      WaterPipe ch02_05_DDC = new WaterPipe(5 * lcf, 0.100, WaterPipe.Material.CarbonSteel);
      WaterPipe ch01_08_DDC = new WaterPipe(70 * lcf, 0.150, WaterPipe.Material.CarbonSteel);
      WaterPipe ch08_11_DDC = new WaterPipe(5 * lcf, 0.100, WaterPipe.Material.CarbonSteel);
      WaterPipe ch04_00_DDC = new WaterPipe(30 * lcf, 0.150, WaterPipe.Material.CarbonSteel);
      WaterPipe ch07_04_DDC = new WaterPipe(5 * lcf, 0.100, WaterPipe.Material.CarbonSteel);
      WaterPipe ch10_00_DDC = new WaterPipe(70 * lcf, 0.150, WaterPipe.Material.CarbonSteel);
      WaterPipe ch13_10_DDC = new WaterPipe(5 * lcf, 0.100, WaterPipe.Material.CarbonSteel);
      SimpleCircuitBranch ch02_03_ahu1_DDC = new SimpleCircuitBranch(0.0225, 150);
      SimpleCircuitBranch ch05_06_ahu2_DDC = new SimpleCircuitBranch(0.0225, 150);
      SimpleCircuitBranch ch08_09_ahu3_DDC = new SimpleCircuitBranch(0.0225, 150);
      SimpleCircuitBranch ch11_12_ahu4_DDC = new SimpleCircuitBranch(0.0225, 150);
      CircuitNode[] nodesDDC = new CircuitNode[14];
      for (int i = 0; i < nodesDDC.Length; i++) nodesDDC[i] = cnetDDC.AddNode();
      cnetDDC.ConnectNode(ch01_02_DDC, nodesDDC[1], nodesDDC[2]);
      cnetDDC.ConnectNode(ch02_05_DDC, nodesDDC[2], nodesDDC[5]);
      cnetDDC.ConnectNode(ch01_08_DDC, nodesDDC[1], nodesDDC[8]);
      cnetDDC.ConnectNode(ch08_11_DDC, nodesDDC[8], nodesDDC[11]);
      cnetDDC.ConnectNode(ch04_00_DDC, nodesDDC[4], nodesDDC[0]);
      cnetDDC.ConnectNode(ch07_04_DDC, nodesDDC[7], nodesDDC[4]);
      cnetDDC.ConnectNode(ch10_00_DDC, nodesDDC[10], nodesDDC[0]);
      cnetDDC.ConnectNode(ch13_10_DDC, nodesDDC[13], nodesDDC[10]);
      cnetDDC.ConnectNode(ch02_03_ahu1_DDC, nodesDDC[2], nodesDDC[3]);
      cnetDDC.ConnectNode(ch05_06_ahu2_DDC, nodesDDC[5], nodesDDC[6]);
      cnetDDC.ConnectNode(ch08_09_ahu3_DDC, nodesDDC[8], nodesDDC[9]);
      cnetDDC.ConnectNode(ch11_12_ahu4_DDC, nodesDDC[11], nodesDDC[12]);
      cnetDDC.SetBasePressure(nodesDDC[0], 0);
    }

    #endregion

    #region 回路網テスト2（制御可能回路）

    private static void testControllableFlow()
    {
      ControllableParallelFlow[] floorPFlows = new ControllableParallelFlow[6];
      ControllableSeriesFlow[][] ahus = new ControllableSeriesFlow[6][];
      for (int i = 0; i < floorPFlows.Length; i++) ahus[i] = new ControllableSeriesFlow[4];
      ahus[0][0] = new ControllableSeriesFlow(1.121e6, 2.354e7);
      ahus[0][1] = new ControllableSeriesFlow(1.455e6, 3.055e7);
      ahus[0][2] = new ControllableSeriesFlow(2.324e6, 4.880e7);
      ahus[0][3] = new ControllableSeriesFlow(1.681e6, 3.530e7);
      ahus[1][0] = new ControllableSeriesFlow(1.121e6, 2.130e7);
      ahus[1][1] = new ControllableSeriesFlow(1.455e6, 2.764e7);
      ahus[1][2] = new ControllableSeriesFlow(2.324e6, 4.416e7);
      ahus[1][3] = new ControllableSeriesFlow(1.681e6, 3.193e7);
      ahus[2][0] = new ControllableSeriesFlow(1.121e6, 1.906e7);
      ahus[2][1] = new ControllableSeriesFlow(1.455e6, 2.473e7);
      ahus[2][2] = new ControllableSeriesFlow(2.324e6, 3.951e7);
      ahus[2][3] = new ControllableSeriesFlow(1.681e6, 2.857e7);
      ahus[3][0] = new ControllableSeriesFlow(1.121e6, 1.682e7);
      ahus[3][1] = new ControllableSeriesFlow(1.455e6, 2.182e7);
      ahus[3][2] = new ControllableSeriesFlow(2.324e6, 3.486e7);
      ahus[3][3] = new ControllableSeriesFlow(1.681e6, 2.521e7);
      ahus[4][0] = new ControllableSeriesFlow(1.121e6, 1.457e7);
      ahus[4][1] = new ControllableSeriesFlow(1.455e6, 1.891e7);
      ahus[4][2] = new ControllableSeriesFlow(2.324e6, 3.021e7);
      ahus[4][3] = new ControllableSeriesFlow(1.681e6, 2.185e7);
      ahus[5][0] = new ControllableSeriesFlow(1.121e6, 1.233e7);
      ahus[5][1] = new ControllableSeriesFlow(1.455e6, 1.600e7);
      ahus[5][2] = new ControllableSeriesFlow(2.324e6, 2.556e7);
      ahus[5][3] = new ControllableSeriesFlow(1.681e6, 1.849e7);
      for (int i = 0; i < floorPFlows.Length; i++)
        floorPFlows[i] = new ControllableParallelFlow(ahus[i]);

      ControllableParallelFlow totalSystem = new ControllableParallelFlow(floorPFlows);
      totalSystem.SupplyResistances[0] = totalSystem.ReturnResistances[0] = 2.440e4;
      totalSystem.SupplyResistances[1] = totalSystem.ReturnResistances[1] = 3.904e3;
      totalSystem.SupplyResistances[2] = totalSystem.ReturnResistances[2] = 6.100e3;
      totalSystem.SupplyResistances[3] = totalSystem.ReturnResistances[3] = 1.085e4;
      totalSystem.SupplyResistances[4] = totalSystem.ReturnResistances[4] = 2.440e4;
      totalSystem.SupplyResistances[5] = totalSystem.ReturnResistances[5] = 9.761e4;

      for (int i = 0; i < floorPFlows.Length; i++)
      {
        ahus[i][0].FlowRateSetPoint = 2.11e-3;
        ahus[i][1].FlowRateSetPoint = 1.85e-3;
        ahus[i][2].FlowRateSetPoint = 1.47e-3;
        ahus[i][3].FlowRateSetPoint = 1.72e-3;
      }
      for (int i = 1; i <= 10; i++)
      {
        double pl = 0.1 * i;
        ahus[5][0].FlowRateSetPoint = ahus[4][0].FlowRateSetPoint = ahus[3][0].FlowRateSetPoint = 2.11e-3 * pl;
        ahus[5][1].FlowRateSetPoint = ahus[4][1].FlowRateSetPoint = ahus[3][1].FlowRateSetPoint = 1.85e-3 * pl;
        ahus[5][2].FlowRateSetPoint = ahus[4][2].FlowRateSetPoint = ahus[3][2].FlowRateSetPoint = 1.47e-3 * pl;
        ahus[5][3].FlowRateSetPoint = ahus[4][3].FlowRateSetPoint = ahus[3][3].FlowRateSetPoint = 1.72e-3 * pl;
        Console.WriteLine(pl + ", " + totalSystem.GetMinimumPressure().ToString("F1"));
      }
      for (int i = 1; i <= 10; i++)
      {
        double pl = 0.1 * i;
        ahus[0][0].FlowRateSetPoint = ahus[1][0].FlowRateSetPoint = ahus[2][0].FlowRateSetPoint = 2.11e-3 * pl;
        ahus[0][1].FlowRateSetPoint = ahus[1][1].FlowRateSetPoint = ahus[2][1].FlowRateSetPoint = 1.85e-3 * pl;
        ahus[0][2].FlowRateSetPoint = ahus[1][2].FlowRateSetPoint = ahus[2][2].FlowRateSetPoint = 1.47e-3 * pl;
        ahus[0][3].FlowRateSetPoint = ahus[1][3].FlowRateSetPoint = ahus[2][3].FlowRateSetPoint = 1.72e-3 * pl;
        Console.WriteLine(pl + ", " + totalSystem.GetMinimumPressure().ToString("F1"));
      }
      for (int i = 1; i <= 10; i++)
      {
        double pl = 0.5 + 0.05 * i;
        for (int j = 0; j < ahus.Length; j++)
        {
          ahus[j][0].FlowRateSetPoint = 2.11e-3 * pl;
          ahus[j][1].FlowRateSetPoint = 1.85e-3 * pl;
          ahus[j][2].FlowRateSetPoint = 1.47e-3 * pl;
          ahus[j][3].FlowRateSetPoint = 1.72e-3 * pl;
        }
        Console.WriteLine(pl + ", " + totalSystem.GetMinimumPressure().ToString("F1"));
      }
      //totalSystem.ControlFlowRate(200);
    }

    #endregion

    #region 日射テスト

    private static void RadiationSeparateTest(bool isCloudy)
    {
      double[] ghRadiation;
      DateTime sTime;
      if (isCloudy)
      {
        //東京都2014/7/20 5-20時の水平面全天日射[W/m2]（曇天日）
        ghRadiation = new double[]
        { 0, 28, 81, 275, 339, 569, 594, 486, 575, 536, 378, 356, 142, 8, 3, 0 };
        sTime = new DateTime(2014, 7, 20, 4, 30, 0);
      }
      else
      {
        //東京都2014/8/6 5-20時の水平面全天日射[W/m2]（晴天日）
        ghRadiation = new double[]
        { 0, 53, 244, 444, 631, 778, 881, 928, 917, 844, 719, 550, 358, 161, 17, 0 };
        sTime = new DateTime(2014, 8, 6, 4, 30, 0);
      }

      //東京地点で初期化
      Sun sun = new Sun(35.7, 139.8, 135);
      using (StreamWriter sWriter = new StreamWriter("sun.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //直散分離手法一覧を取得
        Array mtds = Enum.GetValues(typeof(Sun.SeparationMethod));

        //タイトル行
        sWriter.Write("時刻, 全天日射[W/m2]");
        foreach (Sun.SeparationMethod mtd in mtds) sWriter.Write(", " + mtd.ToString() + ", ");
        sWriter.WriteLine();
        //直散分離計算実行
        for (int i = 0; i < ghRadiation.Length; i++)
        {
          sun.Update(sTime.AddHours(i));
          sWriter.Write(sun.CurrentDateTime.Hour + ", " + ghRadiation[i]);
          foreach (Sun.SeparationMethod mtd in mtds)
          {
            sun.SeparateGlobalHorizontalRadiation(ghRadiation[i], mtd);
            sWriter.Write(", " + sun.DirectNormalRadiation + ", " + sun.DiffuseHorizontalRadiation);
          }
          sWriter.WriteLine();
        }
      }
    }

    private static void SunRiseTest()
    {
      Sun sun = new Sun(Sun.City.Tokyo);
      sun.Update(new DateTime(1981, 1, 2, 0, 0, 0));
      DateTime dt1 = sun.GetSunRiseTime();
      DateTime dt2 = sun.GetSunSetTime();
    }

    private static void InclineTest(bool isSummer)
    {
      DateTime dTime;
      if (isSummer) dTime = new DateTime(2014, 6, 22, 4, 0, 0);
      else dTime = new DateTime(2014, 12, 22, 4, 0, 0);

      //傾斜面を作成
      Incline[] inc = new Incline[5];
      inc[0] = new Incline(Incline.Orientation.W, 0.5 * Math.PI);
      inc[1] = new Incline(Incline.Orientation.E, 0.5 * Math.PI);
      inc[2] = new Incline(Incline.Orientation.N, 0.5 * Math.PI);
      inc[3] = new Incline(Incline.Orientation.S, 0.5 * Math.PI);
      inc[4] = new Incline(Incline.Orientation.S, 0);

      //東京地点で初期化
      Sun sun = new Sun(35.7, 139.8, 135);

      using (StreamWriter sWriter =
          new StreamWriter("Incline.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル用
        sWriter.WriteLine("時刻, 東面, 西面, 北面, 南面, 水平面");

        for (int i = 0; i <= 32; i++)
        {
          sun.Update(dTime.AddMinutes(30 * i));
          double idn = sun.GetDirectNormalRadiation(0.65);
          sWriter.Write(sun.CurrentDateTime.ToShortTimeString());
          for (int j = 0; j < inc.Length; j++)
            sWriter.Write(", " + inc[j].GetDirectSolarRadiationRate(sun) * idn);
          sWriter.WriteLine();
        }
      }
    }

    private static void InclineTest2(bool isSummer)
    {
      DateTime dTime;
      if (isSummer) dTime = new DateTime(2014, 6, 22, 0, 0, 0);
      else dTime = new DateTime(2014, 12, 22, 0, 0, 0);

      //傾斜面を作成
      Incline[] inc = new Incline[5];
      inc[0] = new Incline(Incline.Orientation.W, 0.5 * Math.PI);
      inc[1] = new Incline(Incline.Orientation.E, 0.5 * Math.PI);
      inc[2] = new Incline(Incline.Orientation.N, 0.5 * Math.PI);
      inc[3] = new Incline(Incline.Orientation.S, 0.5 * Math.PI);
      inc[4] = new Incline(Incline.Orientation.S, 0);

      //昭和基地//遊び
      Sun sun = new Sun(-69d + 22d / 3600, 39d + 35d / 60 + 24d / 3600, 39d + 35d / 60 + 24d / 3600);

      using (StreamWriter sWriter =
          new StreamWriter("Incline.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル用
        sWriter.WriteLine("時刻, 東面, 西面, 北面, 南面, 水平面, 太陽高度");

        for (int i = 0; i <= 48; i++)
        {
          sun.Update(dTime.AddMinutes(30 * i));
          double idn = sun.GetDirectNormalRadiation(0.65);
          sWriter.Write(sun.CurrentDateTime.ToShortTimeString());
          for (int j = 0; j < inc.Length; j++)
            sWriter.Write(", " + inc[j].GetDirectSolarRadiationRate(sun) * idn);
          sWriter.Write(", " + sun.Altitude * 180d / Math.PI);
          sWriter.WriteLine();
        }
      }
    }

    #endregion

    #region 気象テスト

    private static void RandomWeatherTest(uint seed)
    {
      int[] days =
        new int[] { 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
      using (StreamWriter sWriter = new StreamWriter
          ("weather.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        for (int i = 0; i < days.Length; i++)
          sWriter.Write("," + (i + 1).ToString("F0") + "月");
        sWriter.WriteLine();

        foreach (RandomWeather.Location loc
          in Enum.GetValues(typeof(RandomWeather.Location)))
        {
          double[] dbt, hrt, rad;
          bool[] fcf;
          RandomWeather wRnd = new RandomWeather(seed, loc);
          wRnd.MakeWeather(1, out dbt, out hrt, out rad, out fcf);
          double[] dbtAve = new double[12];
          double[] rhdAve = new double[12];
          DateTime dt = new DateTime(1999, 1, 1, 0, 0, 0);
          for (int i = 0; i < dbt.Length; i++)
          {
            dbtAve[dt.Month - 1] += dbt[i];
            double rhd =
              MoistAir.GetRelativeHumidityFromDryBulbTemperatureAndHumidityRatio
              (dbt[i], hrt[i] / 1000d, 101.325);
            rhdAve[dt.Month - 1] += rhd;
            dt = dt.AddHours(1);
          }
          sWriter.Write(loc.ToString() + "乾球温度");
          for (int i = 0; i < dbtAve.Length; i++)
            sWriter.Write("," + (dbtAve[i] / (days[i] * 24)).ToString("F2"));
          sWriter.WriteLine();
          sWriter.Write(loc.ToString() + "相対湿度");
          for (int i = 0; i < rhdAve.Length; i++)
            sWriter.Write("," + (rhdAve[i] / (days[i] * 24)).ToString("F2"));
          sWriter.WriteLine();
        }
      }
    }

    private static void RandomWeatherTest2(uint seed)
    {
      double[] dbt, hrt, rad;
      bool[] fcf;
      RandomWeather wRnd = new RandomWeather(seed, RandomWeather.Location.Tokyo);
      wRnd.MakeWeather(20, out dbt, out hrt, out rad, out fcf);

      DateTime dt = new DateTime(2014, 1, 1, 0, 0, 0);
      using (StreamWriter sWriter = new StreamWriter("weather.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.WriteLine("日付, 時刻, 乾球温度, 絶対湿度, 水平面全天日射, 雲量<10");
        for (int i = 0; i < 20 * 8760; i++)
        {
          sWriter.WriteLine(dt.ToShortDateString() + ", " + dt.Hour + ", " +
               dbt[i] + ", " + hrt[i] + ", " + rad[i] + ", " + fcf[i]);
          dt = dt.AddHours(1);
          if (dt.Month == 2 && dt.Day == 29) dt.AddDays(1);
        }
      }
    }

    private static void RandomWeatherTest3(uint seed)
    {
      double[] dbt, hrt, rad;
      bool[] fcf;
      RandomWeather wRnd = new RandomWeather(seed, RandomWeather.Location.Tokyo);
      wRnd.MakeWeather(1, out dbt, out hrt, out rad, out fcf);
      
      using (StreamWriter sWriter = new StreamWriter("weather.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.WriteLine("日付, 時刻, 乾球温度, 絶対湿度, 水平面全天日射, 法線面直達日射, 水平面天空日射, 法線面直達照度, 天空照度, 雲量<10");
        Sun sun = new Sun(Sun.City.Tokyo);
        sun.CalculateIlluminance = true;
        DateTime dt = new DateTime(1999, 1, 1, 0, 0, 0);
        for (int i = 0; i < 8760; i++)
        {
          sun.SeparateGlobalHorizontalRadiation(rad[i], Sun.SeparationMethod.Erbs);
          sWriter.WriteLine(dt.ToShortDateString() + ", " + dt.Hour + ", " 
            + dbt[i] + ", " + hrt[i] + ", " 
            + rad[i] + ", " + sun.DirectNormalRadiation + "," + sun.DiffuseHorizontalRadiation + "," 
            + sun.DirectNormalIlluminance + "," + sun.DiffuseIlluminance + "," + fcf[i]);
          dt = dt.AddHours(1);
          sun.Update(dt);
        }
      }
    }

    private static void ConverterTest1()
    {
      using (StreamReader sReader = new StreamReader("TokyoStandard.has"))
      using (StreamWriter sWriter = new StreamWriter
        ("TokyoStandard.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        string haspData = sReader.ReadToEnd();
        sWriter.Write(WeatherConverter.HASPtoCSV(haspData));
      }
    }

    private static void ConverterTest2()
    {
      using (StreamReader sReader = new StreamReader("TokyoStandard.exa", Encoding.GetEncoding("Shift_JIS")))
      using (StreamWriter sWriter = new StreamWriter
        ("TokyoStandard.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        string exaData = sReader.ReadToEnd();
        int locNumber;
        double lng, lat;
        sWriter.Write(WeatherConverter.EXAtoCSV(exaData, out locNumber, out lat, out lng));
        Console.WriteLine(locNumber + ": " + lat + " , " + lng);
      }
    }

    #endregion

    #region 熱交換テスト

    private static void heatExchangeTest1()
    {
      int tci = 0;
      int tco = 1;
      double[] rFac = new double[] { 4.0, 3.0, 2.0, 1.5, 1.1, 0.8, 0.6, 0.4, 0.2 };
      HeatExchange.FlowType[] fTypes = new HeatExchange.FlowType[] {
        HeatExchange.FlowType.CrossFlow_BothFluidMixed,
        HeatExchange.FlowType.CrossFlow_BothFluidsUnmixed,
        HeatExchange.FlowType.CrossFlow_CminMixed };

      //最小化関数の定義
      using (StreamWriter sWriter =
        new StreamWriter("hexTest1.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        for (int i = 0; i < 9; i++) sWriter.Write("," + rFac[i]);
        sWriter.WriteLine();

        for (int i = 0; i < fTypes.Length; i++)
        {
          sWriter.WriteLine(fTypes[i].ToString());
          for (int j = 0; j <= 100; j++)
          {
            double qq = 0.01 * j;
            sWriter.Write(qq);
            for (int k = 0; k < 9; k++)
            {
              if (qq == 0) sWriter.Write("," + 1);
              else {
                double thi = (tco + tci * (qq - 1)) / qq;
                double tho = thi - rFac[k] * (tco - tci);
                double dt1 = thi - tco;
                double dt2 = tho - tci;
                if (dt1 <= 0 || dt2 <= 0) sWriter.Write("," + 0);
                else
                {
                  double lmtd = (dt1 - dt2) / Math.Log(dt1 / dt2);
                  double tm = HeatExchange.GetMeanTemperatureDifference
                    (thi, tci, tho, tco, fTypes[i]);
                  sWriter.Write("," + tm / lmtd);                  
                }
              }
            }
            sWriter.WriteLine();
          }
        }
      }
    }

    private static void heatExchangeTest2()
    {
      using (StreamWriter sWriter =
          new StreamWriter("hexTest2.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        double[] ntu = new double[] 
        { 0, 0.25, 0.5, 0.75, 1, 1.25, 1.5, 1.75, 2, 2.5, 3, 3.5, 4, 4.5, 5, 6, 7 };
        double[] cmcm = new double[] { 0, 0.25, 0.5, 0.75, 1 };

        sWriter.WriteLine("NTU, 0.00, 0.25, 0.50, 0.75, 1.00");
        foreach (HeatExchange.FlowType ft in Enum.GetValues
          (typeof(HeatExchange.FlowType)))
        {
          sWriter.WriteLine(ft.ToString());
          for (int i = 0; i < ntu.Length; i++)
          {
            sWriter.Write(ntu[i].ToString() + ",");
            for (int j = 0; j < cmcm.Length; j++)
              sWriter.Write(HeatExchange.GetEffectiveness(ntu[i], cmcm[j], ft) + ",");
            sWriter.WriteLine();
          }
        }
      }
    }
    
    private static void heatExchangeTest3()
    {
      double heatTransfer = 500;
      double heatTransferCoefficient = 4;
      double hotInletTemperature = 12;
      double coldInletTemperature = 6;
      //熱容量流量[kW/K]
      double mh = 500 / (12 - 7);
      double mc = 500 / (10 - 6);

      //熱通過有効度の計算
      double epsilon = heatTransfer / Math.Min(mh, mc) /
          (hotInletTemperature - coldInletTemperature);

      //NTUの計算
      double rmc = Math.Min(mh, mc) / Math.Max(mh, mc);
      double ntu = HeatExchange.GetNTU(epsilon, rmc,
          HeatExchange.FlowType.CrossFlow_BothFluidsUnmixed);

      //伝熱面積の計算
      double surfaceArea = ntu / heatTransferCoefficient * Math.Min(mh, mc);
      Console.WriteLine("伝熱面積=" + surfaceArea.ToString("F0") + "m2");
    }

    private static void heatExchangeTest4()
    {
      double surfaceArea = 89;
      double heatTransferCoefficient = 4;
      double hotInletTemperature = 12;
      double coldInletTemperature = 6;
      //熱容量流量[kW/K]
      double mh = 500 / (12 - 7);
      double mc = 500 / (10 - 6);

      //二分法を用いて求根
      Roots.ErrorFunction eFnc = delegate (double heatTransfer)
      {
        //出口温度[C]を計算
        double coldOutletTemperature = coldInletTemperature + heatTransfer / mc;
        double hotOutletTemperature = hotInletTemperature - heatTransfer / mh;
        //平均温度差[K]を計算
        double tm = HeatExchange.GetMeanTemperatureDifference
            (hotInletTemperature, coldInletTemperature, hotOutletTemperature,
            coldOutletTemperature, HeatExchange.FlowType.CrossFlow_BothFluidsUnmixed);
        //誤差を評価
        return tm * surfaceArea * heatTransferCoefficient - heatTransfer;
      };
      double ht1 = Roots.Bisection(eFnc, 1, 500, 0.001, 0.00001, 20);
      Console.WriteLine("熱交換量=" + ht1.ToString("F0") + "kW");

      double rmc = Math.Min(mh, mc) / Math.Max(mh, mc);
      double ntu = 4d * 89d / Math.Min(mh, mc);
      double epsilon = HeatExchange.GetEffectiveness
          (ntu, rmc, HeatExchange.FlowType.CrossFlow_BothFluidsUnmixed);
      double ht2 = epsilon * Math.Min(mh, mc) *
          (hotInletTemperature - coldInletTemperature);
      Console.WriteLine("熱交換量=" + ht2.ToString("F0") + "kW");
    }

    #endregion

    #region プレート熱交換器テスト

    private static void plateHeatExchangerTest()
    {
      PlateHeatExchanger pHex = new PlateHeatExchanger(500, 6, 1792d / 60, 7, 1433d / 60);
      
      Console.WriteLine("冷却テスト");
      pHex.SupplyTemperatureSetpoint = 7;
      for (int trw = 10; trw <= 20; trw += 2)
      {
        for (int i = 0; i <= 20; i++)
        {
          pHex.ControlSupplyTemperature(6, trw, 1433d / 60 * (0.05 * i));
          Console.Write(pHex.HeatSourceFlowRate.ToString("F2") + ", ");
        }
        Console.WriteLine();
      }

      Console.WriteLine("加熱テスト");
      pHex.SupplyTemperatureSetpoint = 45;
      for (int trw = 30; trw <= 40; trw += 2)
      {
        for (int i = 0; i <= 20; i++)
        {
          pHex.ControlSupplyTemperature(50, trw, 1433d / 60 * (0.05 * i));
          Console.Write(pHex.HeatSourceFlowRate.ToString("F2") + ", ");
        }
        Console.WriteLine();
      }
    }

    #endregion

    #region 蒸気物性テスト

    private static void SteamTableTest()
    {
      using (StreamWriter sWriter =
          new StreamWriter("SteamTable.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行
        sWriter.WriteLine("飽和温度[℃], 飽和圧力[kPa], 飽和水比体積[m3/kg]," +
            " 飽和蒸気比体積[m3/kg], 飽和水エンタルピー[kJ/kg], " +
            "飽和蒸気エンタルピー[kJ/kg], 蒸発潜熱[kJ/kg], " +
            "飽和水エントロピー[kJ/kgK], 飽和蒸気エントロピー[kJ/kgK]");

        //蒸気物性の計算
        for (int i = 0; i < 19; i++)
        {
          double ts;
          if (i == 0) ts = 0.01;
          else ts = i * 20;
          double ps = Water.GetSaturationPressure(ts);
          sWriter.WriteLine(ts + "," + ps + ","
              + Water.GetSaturatedLiquidSpecificVolume(ts) + ","
              + Water.GetSaturatedVaporSpecificVolume(ts, ps) + ","
              + Water.GetSaturatedLiquidEnthalpy(ts) + ","
              + Water.GetSaturatedVaporEnthalpy(ts) + ","
              + Water.GetVaporizationLatentHeat(ts) + ","
              + Water.GetSaturatedLiquidEntropy(ts) + ","
              + Water.GetSaturatedVaporEntropy(ts));
        }
      }
    }

    #endregion

    #region 数値計算テスト

    private static void LUDecompositionTest()
    {
      IMatrix matrix = new Matrix(5, 5); //行列
      IVector b = new Vector(5);        //解ベクトル
      int[] perm = new int[5];     //置換ベクトル
      IVector wArray = new Vector(5);   //作業用記憶領域

      //値を代入
      matrix[0, 0] = -28.9; matrix[0, 1] = 8.9; b[0] = -700;
      matrix[1, 0] = 8.9; matrix[1, 1] = -10.3; matrix[1, 2] = 1.4;
      matrix[2, 1] = 1.4; matrix[2, 2] = -15.7; matrix[2, 3] = 14.3;
      matrix[3, 2] = 14.3; matrix[3, 3] = -32.6; matrix[3, 4] = 18.3;
      matrix[4, 3] = 18.3; matrix[4, 4] = -27.3; b[4] = -234;

      LinearAlgebra.LUDecompose(ref matrix, ref perm, ref wArray);
      LinearAlgebra.FAndBSubstitute(matrix, perm, ref b);

      for (int i = 0; i < b.Length; i++)
        Console.WriteLine("t" + i.ToString() + " = " + b[i].ToString("F1"));
    }

    private static void TridiagonalMatrixSolverTest()
    {
      Matrix abc = new Matrix(3, 5);   //係数ベクトル
      IVector x = new Vector(5);         //解ベクトル

      abc[0, 0] = 0; abc[1, 0] = -28.9; abc[2, 0] = 8.9;
      abc[0, 1] = 8.9; abc[1, 1] = -10.3; abc[2, 1] = 1.4;
      abc[0, 2] = 1.4; abc[1, 2] = -15.7; abc[2, 2] = 14.3;
      abc[0, 3] = 14.3; abc[1, 3] = -32.6; abc[2, 3] = 18.3;
      abc[0, 4] = 18.3; abc[1, 4] = -27.3; abc[2, 4] = 0;
      x[0] = -700; x[1] = 0; x[2] = 0; x[3] = 0; x[4] = -234;

      LinearAlgebra.SolveTridiagonalMatrix(abc, ref x);
      for (int i = 0; i < x.Length; i++)
        Console.WriteLine("t" + i.ToString() + " = " + x[i].ToString("F1"));
    }

    private static void RootsTest()
    {
      Stopwatch sw = new Stopwatch();
      double g;
      long millisec;

      sw.Start();
      for (int i = 0; i < 10000; i++) Roots.Bisection(fmw, 0, 100, 0.001, 0.00001, 20);
      g = Roots.Bisection(fmw, 0, 100, 0.001, 0.00001, 20);
      sw.Stop();
      millisec = sw.ElapsedMilliseconds;
      Console.WriteLine("二分法：");
      Console.WriteLine(millisec + "mSec");
      Console.WriteLine("G= " + g.ToString("F3"));

      sw.Reset();
      sw.Start();
      for (int i = 0; i < 10000; i++) Roots.Brent(0, 100, 0.001, fmw);
      g = Roots.Brent(0, 100, 0.001, fmw);
      sw.Stop();
      millisec = sw.ElapsedMilliseconds;
      Console.WriteLine("Brent法：");
      Console.WriteLine(millisec + "mSec");
      Console.WriteLine("G= " + g.ToString("F3"));
    }

    private static void NewtonRaphsonTest()
    {
      const int MAX_ITERATION = 100;      //最大反復回数
      const double DELTA = 0.0001;        //微分値計算用微小値
      const double ERR_TOLERANCE = 0.001; //最大許容誤差

      //mwの初期値は0とする
      double mw = 0;

      //誤差を計算
      double fmw1 = fmw(mw);

      //反復回数を記録
      int iterNumber = 0;

      //誤差が許容誤差未満になるまで反復計算
      while (ERR_TOLERANCE < Math.Abs(fmw1) && iterNumber < MAX_ITERATION)
      {
        //数値微分値の計算
        //mwを微小変動させて誤差を再計算
        double fmw2 = fmw(mw + DELTA);
        double fmwd = (fmw2 - fmw1) / DELTA;

        //微分値を利用してmwを更新
        mw -= fmw1 / fmwd;

        //誤差を再計算
        fmw1 = fmw(mw);
      }
      Console.WriteLine("mw= " + mw.ToString("F3"));
    }

    private static double fmw(double mw)
    {
      //ポンプのPQ特性
      double p1 = mw * (-0.314 + mw * (2.08e-3 + mw * (-4.9e-6 - 1.32e-6 * mw))) + 333;

      //配管の抵抗
      double p2 = mw * (0.567 + 4.66e-2 * mw) + 49.4;

      return p1 - p2;
    }

    private static void NewtonRaphsonTest2()
    {
      //誤差関数を匿名メソッドで定義
      Roots.ErrorFunction eFnc = delegate (double mw)
      {
        //ポンプのPQ特性
        double p1 = mw * (-0.314 + mw * (2.08e-3 + mw * (-4.9e-6 - 1.32e-6 * mw))) + 333;
        //配管の抵抗
        double p2 = mw * (0.567 + 4.66e-2 * mw) + 49.4;
        return p1 - p2;
      };
      //ニュートンラフソン法を適用
      double waterFlowRate = Roots.Newton(eFnc, 0, 0.0001, 0.001, 0.001, 100);

      Console.WriteLine("mw= " + waterFlowRate.ToString("F3"));
    }

    private static void GoldenSectionTest()
    {
      Minimization.MinimizeFunction mFnc = delegate(double wTemp)
      {
        double pct = 3.4773e2 + wTemp * (-6.4390e1 + wTemp * (4.775 + wTemp * 
          (-1.768e-1 + wTemp * (3.2651e-3 + wTemp * (-2.4048e-5)))));
        double ptb = 4.1472e-1 + wTemp * (5.1299e-3 + wTemp * (4.1126e-4));
        return pct * 15 + ptb * 70;
      };
      double min = 20;
      Console.WriteLine(Minimization.GoldenSection(ref min, 32, mFnc).ToString("F1"));
    }

    private static void SplineTest()
    {
      double[] x = new double[25];
      for (int i = 0; i < x.Length; i++) x[i] = i;
      double[] y = new double[] 
      { 0, 0, 0, 0, 0, 0, 0, 42, 224, 215, 210, 217,
        219, 217, 210, 250, 210, 217, 91, 9, 9, 0, 0, 0, 0 };
      double[] c = CubicSpline.GetParameters(x, y);

      double[] x2 = new double[24 * 4];
      for (int i = 0; i < x2.Length; i++) x2[i] = 0.25 * i;
      double[] y2 = CubicSpline.Interpolate(x, y, c, x2);

      for (int i = 0; i < x2.Length; i++)
      {
        y2[i] = Math.Max(0, y2[i]); //負荷データのため0以上とする
        Console.WriteLine(x2[i].ToString("F2") + "," + y2[i].ToString("F2"));
      }
    }

    private static void QRTest()
    {
      IMatrix mA = new Matrix(5, 5);
      mA[0, 0] = 0.6273; mA[0, 1] = 0.7683; mA[0, 2] = 0.5569; mA[0, 3] = 0.5571; mA[0, 4] = 0.3849;
      mA[1, 0] = 0.7683; mA[1, 1] = 0.3716; mA[1, 2] = 0.4683; mA[1, 3] = 0.7887; mA[1, 4] = 0.6153;
      mA[2, 0] = 0.5569; mA[2, 1] = 0.4683; mA[2, 2] = 0.7764; mA[2, 3] = 0.6480; mA[2, 4] = 0.2756;
      mA[3, 0] = 0.5571; mA[3, 1] = 0.7887; mA[3, 2] = 0.6480; mA[3, 3] = 0.7036; mA[3, 4] = 0.3125;
      mA[4, 0] = 0.3849; mA[4, 1] = 0.6153; mA[4, 2] = 0.2756; mA[4, 3] = 0.3125; mA[4, 4] = 0.5668;

      IMatrix mQ = new Matrix(3,3);
      LinearAlgebra.HouseholderTransform(ref mA, out mQ);
      for (int i = 0; i < mA.Rows; i++)
      {
        for (int j = 0; j < mA.Columns; j++)
        {
          Console.Write(mA[i, j].ToString("F4") + " , ");
        }
        Console.WriteLine();
      }
      Console.WriteLine();
      for (int i = 0; i < mQ.Rows; i++)
      {
        for (int j = 0; j < mQ.Columns; j++)
        {
          Console.Write(mQ[i, j].ToString("F4") + " , ");
        }
        Console.WriteLine();
      }
    }

    private static void LeastSquareTest()
    {
      List<string[]> bf2 = new List<string[]>();
      using (StreamReader sReader = new StreamReader("lm.csv"))
      {
        sReader.ReadLine();
        string bf1;
        while ((bf1 = sReader.ReadLine()) != null)
          bf2.Add(bf1.Split(','));
      }

      double[,] x = new double[bf2.Count, bf2[0].Length - 1];
      double[] y = new double[bf2.Count];
      for (int i = 0; i < bf2.Count; i++)
      {
        y[i] = double.Parse(bf2[i][0]);
        for (int j = 1; j < bf2[0].Length; j++)
          x[i, j - 1] = double.Parse(bf2[i][j]);
      }
      double[] a = LinearAlgebra.LeastSquareFit(y, x);

      for (int i = 0; i < a.Length;i++ )
        Console.Write(a[i].ToString("F1") + " , ");
      Console.WriteLine();
    }

    private static void LeastSquareTest2()
    {
      double[,] x = new double[6, 3];
      double[] y = new double[6];
      x[0, 0] = 1.5; x[1, 0] = 2.3; x[2, 0] = 3.8; x[3, 0] = 4.2; x[4, 0] = 5.6; x[5, 0] = 6.3;
      x[0, 1] = 1.0; x[1, 1] = 3.9; x[2, 1] = 8.6; x[3, 1] = 15.25; x[4, 1] = 28.6; x[5, 1] = 32.68;
      x[0, 2] = 1; x[1, 2] = 1; x[2, 2] = 1; x[3, 2] = 1; x[4, 2] = 1; x[5, 2] = 1;
      y[0] = -3.2; y[1] = 2.0; y[2] = 2.2; y[3] = 6.3; y[4] = 5.8; y[5] = 12.5;

      double sig2, aic;
      double[] a = LinearAlgebra.LeastSquareFit(y, x, out sig2, out aic);
      //SIG2=3.6801, AIC=32.845となるはず
      Console.WriteLine("SIG=" + sig2.ToString("F4") + "  AIC=" + aic.ToString("F3"));
    }

    private static void SimplexTest()
    {
      Random rnd = new Random();
      double[] minX = new double[] { -50, -50 };
      double[] maxX = new double[] { 50, 50 };
      bool suc;
      for (int i = 0; i < 100; i++)
      {
        double[] rslt = NMSimplex.GetSolution(fm_Rosenbrock, minX, maxX, out suc);
        Console.WriteLine(fm_Rosenbrock(rslt).ToString("F4") + ", " +
          rslt[0].ToString("F3") + ", " + rslt[1].ToString("F3") + ", " + suc.ToString());
      }
    }

    private static void SimplexTest2()
    {
      Random rnd = new Random();
      double[] minX = new double[] { -50, -50 };
      double[] maxX = new double[] { 50, 50 };
      bool suc;
      for (int i = 0; i < 100; i++)
      {
        double[] rslt = NMSimplex.GetSolution(fm_Rosenbrock, fc_Rosenbrock, minX, maxX, out suc);
        Console.WriteLine(fm_Rosenbrock(rslt).ToString("F4") + ", " +
          rslt[0].ToString("F3") + ", " + rslt[1].ToString("F3") + ", " + suc.ToString());
      }
    }

    private static double fm_Rosenbrock
      (double[] x)
    {
      return 100 * Math.Pow(x[1] - x[0] * x[0], 2) + Math.Pow(1 - x[0], 2);
    }

    private static double fc_Rosenbrock
      (double[] x)
    {
      return x[0] * x[0] + x[1] * x[1] - 1.5;
    }

    private static void LevenbergMarquardtTest()
    {
      LevenbergMarquardt.ErrorFunction mFnc = delegate (IVector inputs, ref IVector outputs)
      {
        double[] x = new double[] { 0.95, 0.85, 0.75, 0.65, 0.55, 0.45, 0.35, 0.25, 0.15, 0.05 };
        double x1 = inputs[0];
        double x2 = inputs[1];

        outputs[0] = x1 * x1 + 2 * x2 * x2;
        outputs[1] = -0.3 * Math.Cos(3d * Math.PI * x1 + 4 * Math.PI * x2) * (Math.Cos(4 * Math.PI * x2)) + 0.3;
      };

      LevenbergMarquardt lm = new LevenbergMarquardt(mFnc, 2, 2);
      IVector vec = new Vector(2);
      vec[0] = 1.2;
      vec[1] = 1.3;
      IVector op = new Vector(2);
      mFnc(vec, ref op);
      lm.Minimize(ref vec);
      Console.WriteLine(vec[0] + " : " + vec[1]);
    }

    private static void MultiMinimizationTest()
    {
      int eqNum = 1;
      MultiMinimization.MinimizeFunction mFnc = delegate (IVector x, int iteration)
      {
        if (eqNum == 0)  //Cragg-Levy:
          return Math.Pow(Math.Exp(x[0]) - x[1], 4) + 100 * Math.Pow(x[1] - x[2], 6)
          + Math.Pow(Math.Tan(x[2] - x[3]), 4) + Math.Pow(x[0], 8) + Math.Pow(x[3] - 1, 2);
        else if (eqNum == 1) //Wood-Colville:
          return 100 * Math.Pow((x[1] - x[0] * x[0]), 2) + Math.Pow(1 - x[0], 2) + 90 * Math.Pow(x[3] - x[2] * x[2], 2)
          + Math.Pow(1 - x[2], 2) + 10.1 * (Math.Pow(x[1] - 1, 2) + Math.Pow(x[3] - 1, 2)) + 19.8 * (x[1] - 1) * (x[3] - 1);
        else //Powell
          return Math.Pow(x[0] + 10 * x[1], 2) + 5 * Math.Pow(x[2] - x[3], 2)
          + Math.Pow(x[1] - 2 * x[2], 4) + 10 * Math.Pow(x[0] - x[3], 4);
      };
      IVector inputs = new Vector(4);
      if (eqNum == 0) { inputs[0] = 0.5; inputs[1] = 2; inputs[2] = 2; inputs[3] = 2; }         //Cragg-Levy
      else if (eqNum == 1) { inputs[0] = -3; inputs[1] = -1; inputs[2] = -3; inputs[3] = -1; }  //Wood-Colville
      else { inputs[0] = -3; inputs[1] = -1; inputs[2] = 0; inputs[3] = 1; }                    //Powell
      int iter;
      //MultiMinimization.QuasiNewton(ref inputs, mFnc, 400, 1e-5, 1e-5, 1e-4, out iter);
      MultiMinimization.Newton(ref inputs, mFnc, 400, 1e-5, 1e-5, 1e-4, out iter);
      double err = mFnc(inputs, 1);
    }

    #endregion

    #region 水物性計算テスト

    /// <summary>水温・直径・水量から配管内対流熱伝達率を計算する</summary>
    /// <param name="waterTemperature">水温[C]</param>
    /// <param name="diameter">直径[m]</param>
    /// <param name="waterFlowRate">水量[L/min]</param>
    /// <returns>対流熱伝達率[W/(m2·K)]</returns>
    public static double GetConvectiveHeatTransferCoefficientOfTube
        (double waterTemperature, double diameter, double waterFlowRate)
    {
      //動粘性係数[m2/s]・熱拡散率[m2/s]・熱伝導率[W/(m·K)]を計算
      double v = Water.GetLiquidDynamicViscosity(waterTemperature);
      double a = Water.GetLiquidThermalDiffusivity(waterTemperature);
      double lambda = Water.GetLiquidThermalConductivity(waterTemperature);

      //配管内流速[m/s]を計算
      double u = (waterFlowRate / 60 / 1000) / (Math.Pow(diameter / 2, 2) * Math.PI);

      //ヌセルト数を計算
      double reNumber = u * diameter / v;
      double prNumber = v / a;
      double nuNumber = 0.023 * Math.Pow(reNumber, 0.8) * Math.Pow(prNumber, 0.4);

      //ヌセルト数から対流熱伝達率を計算
      return nuNumber * lambda / diameter;
    }

    /// <summary>臭化リチウムの物性テスト1</summary>
    public static void LithiumBromideTest1()
    {
      using (StreamWriter sWriter = new StreamWriter("LithiumBromide.csv"))
      {
        for (int i = 0; i < 10; i++)
        {
          //タイトル行
          if (i == 0)
          {
            sWriter.Write("MassFraction,");
            for (int j = 270; j <= 500; j += 10)
            {
              sWriter.Write(j + ",");
            }
            sWriter.WriteLine();
          }

          double massFraction = 0.3 + 0.05 * i;
          sWriter.Write(massFraction + ",");
          for (int j = 270; j <= 500; j += 10)
          {
            double satT = LithiumBromide.GetVaporTemperatureFromLiquidTemperatureAndMassFraction
                (j, massFraction);
            sWriter.Write(satT + ",");
          }
          sWriter.WriteLine();
        }
      }
    }

    /// <summary>臭化リチウムの物性テスト2</summary>
    public static void LithiumBromideTest2()
    {
      using (StreamWriter sWriter = new StreamWriter("LithiumBromide.csv"))
      {
        for (int i = 40; i <= 70; i+=5)
        {
          //タイトル行
          if (i == 40)
          {
            sWriter.Write("MassFraction,");
            for (int j = 15; j <= 165; j += 10)
            {
              sWriter.Write(j + ",");
            }
            sWriter.WriteLine();
          }

          double massFraction = 0.01 * i;
          sWriter.Write(massFraction + ",");
          for (int j = 15; j <= 165; j += 10)
          {
            double enthalpy = LithiumBromide.GetEnthalpyFromLiquidTemperatureAndMassFraction
                (j + 273.15, massFraction);
            sWriter.Write(enthalpy + ",");
          }
          sWriter.WriteLine();
        }
      }
    }

    /// <summary>臭化リチウムの物性テスト3</summary>
    public static void LithiumBromideTest3()
    {
      using (StreamWriter sWriter = new StreamWriter("LithiumBromide.csv"))
      {
        for (int i = 0; i <= 10; i++)
        {
          //タイトル行
          if (i == 0)
          {
            sWriter.Write("MassFraction,");
            for (int j = 270; j <= 440; j += 10)
            {
              sWriter.Write(j + ",");
            }
            sWriter.WriteLine();
          }

          double massFraction = 0.46 + 0.02 * i;
          sWriter.Write(massFraction + ",");
          for (int j = 270; j <= 440; j += 10)
          {
            double satT = LithiumBromide.GetVaporTemperatureFromLiquidTemperatureAndMassFraction
                (j, massFraction);
            sWriter.Write(satT + ",");
          }
          sWriter.WriteLine();
        }
      }
    }

    #endregion

    #region 湿り空気物性テスト

    private static void moistAirTest()
    {
      //標準気圧とする
      const double ATM = 101.325;

      //表計算ソフトでの描画に備え、計算結果をCSV形式で書き出す
      using (StreamWriter sWriter = new StreamWriter("MoistAirTable.csv"))
      {
        //ヘッダ行書き出し
        sWriter.Write("T, SatT, RH10, RH30, RH50, RH70, RH90, ");
        sWriter.Write("H20, H40, H60, H80, H100, ");
        sWriter.WriteLine("WB5, WB10, WB15, WB20, WB25, WB30, WB35");

        //乾球温度は0～50℃で1℃刻みで描画する
        for (int t = 0; t <= 50; t++)
        {
          //飽和絶対湿度[kg/kg]の計算
          double ps = Water.GetSaturationPressure(t);
          double satW = MoistAir.GetHumidityRatioFromWaterVaporPartialPressure(ps, ATM);
          //結果書き出し
          sWriter.Write(t + "," + satW);

          //等相対湿度線を10～90%の範囲で20%刻みで描画する
          for (int i = 0; i < 5; i++)
          {
            //相対湿度[%]
            double rhd = 10 + i * 20;
            double rhdW = MoistAir.GetHumidityRatioFromDryBulbTemperatureAndRelativeHumidity(t, rhd, ATM);
            if ((rhdW < satW) && (0 < rhdW)) sWriter.Write("," + rhdW);
            else sWriter.Write(",");
          }

          //等比エンタルピー線を20～120kJ/kgの範囲で20kJ/kg刻みで描画する
          for (int i = 0; i < 5; i++)
          {
            //比エンタルピー[kJ/kg]
            double ent = 20 + i * 20;
            double entW = MoistAir.GetHumidityRatioFromDryBulbTemperatureAndEnthalpy(t, ent);
            if ((entW < satW) && (0 < entW)) sWriter.Write("," + entW);
            else sWriter.Write(",");
          }

          //等湿球温度線を5～35℃の範囲で5℃刻みで描画する
          for (int i = 0; i < 7; i++)
          {
            //湿球温度[℃]
            double wbt = 5 + i * 5;
            double wbtW = MoistAir.GetHumidityRatioFromDryBulbTemperatureAndWetBulbTemperature(t, wbt, ATM);
            if ((wbtW < satW) && (0 < wbtW)) sWriter.Write("," + wbtW);
            else sWriter.Write(",");
          }
          sWriter.WriteLine();
        }
      }
    }

    private static void moistAirTest2()
    {
      using (StreamWriter sWriter = new StreamWriter("MoistAirTable.csv"))
      {
        sWriter.WriteLine("温度,粘性係数,動粘性係数,熱伝導率,膨張率");
        for (int i = 0; i <= 100; i++)
        {
          sWriter.WriteLine(
              i + ", " +
              MoistAir.GetViscosity(i) + ", " +
              MoistAir.GetDynamicViscosity(i, 0, 101.325) + ", " +
              MoistAir.GetThermalConductivity(i) + ", " +
              MoistAir.GetExpansionCoefficient(i)
              );
        }
      }
    }

    #endregion

    #region 冷媒物性テスト

    public static void RefrigerantTest1()
    {
      using (StreamWriter sWriter = new StreamWriter
        ("RefrigerantTest1.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //冷媒種類はR410A
        Refrigerant r410a = new Refrigerant(Refrigerant.Fluid.R410A);

        //飽和液と飽和蒸気の密度
        double rhoSl, rhoSv;

        //飽和液線と飽和蒸気線の描画
        sWriter.WriteLine ("飽和P[kPa], 飽和液h[kJ/kg], 飽和蒸気h[kJ/kg]");
        //圧力範囲[kPa]
        const double minPressure = 700;
        const double maxPressure = 3900;
        //飽和線の描画点数
        const int plotNumber = 50;
        double delta = (maxPressure - minPressure) / plotNumber;
        for (int i = 0; i <= plotNumber; i++)
        {
          double satTemp;
          double pressure = minPressure + delta * i;
          r410a.GetSaturatedPropertyFromPressure 
            (pressure, out rhoSl, out rhoSv, out satTemp);
          double rhoHl = r410a.GetEnthalpyFromTemperatureAndDensity(satTemp, rhoSl);
          double rhoHv = r410a.GetEnthalpyFromTemperatureAndDensity(satTemp, rhoSv);
          sWriter.WriteLine(pressure + "," + rhoHl + "," + rhoHv);
        }

        sWriter.WriteLine();
        sWriter.WriteLine("冷凍サイクルの計算");

        //冷凍サイクルの計算
        double evapP;    //蒸発圧力[kPa]
        double evapT = 5; //蒸発温度[C]
        r410a.GetSaturatedPropertyFromTemperature 
          (evapT + 273.15, out rhoSl, out rhoSv, out evapP);
        double tCmpIn = evapT + 273.15 + 5;  //圧縮機入口温度[K]（過熱度5C）
        double rhoCmpIn = r410a.GetDensityFromPressureAndTemperature(evapP, tCmpIn);
        double hCmpIn = r410a.GetEnthalpyFromTemperatureAndDensity(tCmpIn, rhoCmpIn);
        double sCmpIn = r410a.GetEntropyFromTemperatureAndDensity(tCmpIn, rhoCmpIn);
        sWriter.WriteLine("圧縮機入口比エンタルピー[kJ/kg], 圧縮機入口圧力[kPa]");
        sWriter.WriteLine(hCmpIn + "," + evapP);

        double condP = 3500; //凝縮圧力[kPa]
        double tCmpOut, rhoCmpOut, hCmpOut, uCmpOut;
        r410a.GetStateFromPressureAndEntropy
          (condP, sCmpIn, out tCmpOut, out rhoCmpOut, out hCmpOut, out uCmpOut);
        sWriter.WriteLine("圧縮機出口比エンタルピー[kJ/kg], 圧縮機出口圧力[kPa]");
        sWriter.WriteLine(hCmpOut + "," + condP);

        double condT; //凝縮温度[K]
        r410a.GetSaturatedPropertyFromPressure(condP, out rhoSl, out rhoSv, out condT);
        double tEvpIn = condT - 10;  //圧縮機入口温度[K]（過冷却度10C）
        double rhoEvpIn = r410a.GetDensityFromPressureAndTemperature (condP, tEvpIn);
        double hEvpIn = r410a.GetEnthalpyFromTemperatureAndDensity(tEvpIn, rhoEvpIn);
        double sEvpIn = r410a.GetEntropyFromTemperatureAndDensity(tEvpIn, rhoEvpIn);
        sWriter.WriteLine("膨張弁入口比エンタルピー[kJ/kg], 膨張弁入口圧力[kPa]");
        sWriter.WriteLine(hEvpIn + "," + condP);

        sWriter.WriteLine("膨張弁出口比エンタルピー[kJ/kg], 膨張弁出口圧力[kPa]");
        sWriter.WriteLine(hEvpIn + "," + evapP);
      }
    }

    public static void RefrigerantTest2()
    {
      //モリエル線図を描画する
      //冷媒種類はR134a
      Refrigerant r134a = new Refrigerant(Refrigerant.Fluid.R134a);

      using (StreamWriter sWriter = new StreamWriter("PHDiagram.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //飽和液と飽和蒸気の密度
        double rhoSl, rhoSv;

        //ヘッダ行
        sWriter.Write
            ("飽和圧力[kPa], 飽和液比エンタルピー[kJ/kg], 飽和蒸気比エンタルピー[kJ/kg],");
        //温度
        for (int i = 0; i <= 100; i += 10) sWriter.Write(i.ToString() + " C,");
        //エントロピー
        for (int i = 170; i <= 200; i += 5) sWriter.Write((i / 100d).ToString() + " kJ/kgK,");
        sWriter.WriteLine();

        //圧力範囲[kPa]
        const double minPressure = 200;
        const double maxPressure = 2000;
        //飽和線の描画点数
        const int plotNumber = 50;
        double delta = (maxPressure - minPressure) / plotNumber;
        for (int i = 0; i <= plotNumber; i++)
        {
          //飽和線の描画
          double satTemp;
          double pressure = minPressure + delta * i;
          r134a.GetSaturatedPropertyFromPressure
              (pressure, out rhoSl, out rhoSv, out satTemp);
          double rhoHl = r134a.GetEnthalpyFromTemperatureAndDensity
              (satTemp, rhoSl);
          double rhoHv = r134a.GetEnthalpyFromTemperatureAndDensity
              (satTemp, rhoSv);
          sWriter.Write(pressure + "," + rhoHl + "," + rhoHv + ",");

          double h, rho, u;
          //等温度線の描画
          for (int j = 0; j <= 100; j += 10)
          {
            //計算範囲外の場合
            if ((j < satTemp - 273.15 - 10))// || (satTemp - 273.15 + 80 < j))
              sWriter.Write("-,");
            else
            {
              double s;
              r134a.GetStateFromPressureAndTemperature
                (pressure, j + 273.15, out s, out rho, out h, out u);
              sWriter.Write(h.ToString("F2") + ",");
            }
          }

          //等比エントロピー線の描画
          for (int j = 170; j <= 200; j += 5)
          {
            //気相域の場合のみ出力
            double satS = r134a.GetEntropyFromTemperatureAndDensity
              (satTemp, rhoSv);
            if (j / 100d < satS) sWriter.Write("-,");
            else
            {
              double t;
              r134a.GetStateFromPressureAndEntropy
                (pressure, j / 100d, out t, out rho, out h, out u);
              sWriter.Write(h.ToString("F2") + ",");
            }
          }
          sWriter.WriteLine();
        }
      }
    }

    #endregion

    #region 冷却塔テスト

    private static void CoolingTowerTest1()
    {
      double twb = MoistAir.GetWetBulbTemperatureFromDryBulbTemperatureAndHumidityRatio(35, 0.0195, 101.325);
      CoolingTower ct = new CoolingTower(37, 32, twb, 43.3, 35.7, CoolingTower.AirFlowDirection.CrossFlow, 7.5, false);

      using (StreamWriter sWriter = new StreamWriter
        ("CoolingTowerTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //入口冷却水温度に対する感度
        sWriter.WriteLine("冷却水温度[C], 除去熱量[kW], 出口水温[C]");
        double wbt = MoistAir.GetWetBulbTemperatureFromDryBulbTemperatureAndHumidityRatio(35, 0.0195, 101.325);
        ct.SetOutdoorAirState(wbt, 0.0195);
        for (int i = 0; i < 10; i++)
        {
          double wit = 37 - i * 0.5;
          ct.Update(wit, false);
          sWriter.WriteLine(wit.ToString("F1") + ", " + ct.HeatRejection.ToString("F1")
            + ", " + ct.OutletWaterTemperature.ToString("F2"));
        }

        //入口空気相対湿度に対する感度
        sWriter.WriteLine("相対湿度[%], 除去熱量[kW], 出口水温[C]");
        for (int i = 0; i < 10; i++)
        {
          double rhd = 55 - 2 * i;
          double hrt = MoistAir.GetHumidityRatioFromDryBulbTemperatureAndRelativeHumidity(35, rhd, 101.325);
          double wbt2 = MoistAir.GetWetBulbTemperatureFromDryBulbTemperatureAndHumidityRatio(35, hrt, 101.325);
          ct.SetOutdoorAirState(wbt2, hrt);
          ct.Update(37, false);
          sWriter.WriteLine(rhd.ToString("F0") + ", " + ct.HeatRejection.ToString("F1")
            + ", " + ct.OutletWaterTemperature.ToString("F2"));
        }

        //冷却水流量に対する感度
        sWriter.WriteLine("冷却水流量比[-], 除去熱量[kW], 出口水温[C]");
        ct.SetOutdoorAirState(wbt, 0.0195);
        for (int i = 0; i < 10; i++)
        {
          double pl = (1 - 0.05 * i);
          ct.WaterFlowRate = 43.3 * pl;
          ct.Update(37, false);
          sWriter.WriteLine(pl.ToString("F2") + ", " + ct.HeatRejection.ToString("F1")
            + ", " + ct.OutletWaterTemperature.ToString("F2"));
        }

        //風量に対する感度
        sWriter.WriteLine("風量比[-], 除去熱量[kW], 出口水温[C]");
        ct.WaterFlowRate = 43.3;
        for (int i = 0; i < 10; i++)
        {
          double pl = (1 - 0.05 * i);
          ct.Update(37, ct.MaxAirFlowRate * pl);
          sWriter.WriteLine(pl.ToString("F2") + ", " + ct.HeatRejection.ToString("F1")
            + ", " + ct.OutletWaterTemperature.ToString("F2"));
        }
      }
    }

    private static void CoolingTowerTest2()
    {
      double twb = MoistAir.GetWetBulbTemperatureFromDryBulbTemperatureAndHumidityRatio(35, 0.0195, 101.325);
      CoolingTower ct_INV = new CoolingTower
        (37, 32, twb, 43.3, 35.7, CoolingTower.AirFlowDirection.CrossFlow, 7.5, true);
      CoolingTower ct_NON = new CoolingTower
        (37, 32, twb, 43.3, 35.7, CoolingTower.AirFlowDirection.CrossFlow, 7.5, false);

      using (StreamWriter sWriter = new StreamWriter
        ("CoolingTowerTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //負荷とファン消費電力・水消費量との関係
        sWriter.WriteLine
          ("負荷率[-], 風量[kg/s], 消費電力(発停), 消費電力(INV), 蒸発量[kg/s], 飛散量[kg/s], ブロー量[kg/s]");
        for (int i = 0; i < 100; i++)
        {
          //負荷率によって冷却水入口温度を調整
          double pLoad = 1 - i * 0.01;
          double wInletTemp = 32 + 5 * pLoad;

          //状態更新処理
          ct_INV.Update(wInletTemp, true); //INV制御
          ct_NON.Update(wInletTemp, true); //発停制御

          //結果出力
          sWriter.WriteLine(pLoad.ToString("F2") + ", " + ct_INV.AirFlowRate.ToString("F2") + ", "
            + ct_NON.ElectricConsumption.ToString("F2") + ", " + ct_INV.ElectricConsumption.ToString("F2") + ", "
            + ct_INV.EvaporationWater.ToString("F3") + ", " + ct_INV.DriftWater.ToString("F3") + ", "
            + ct_INV.BlowDownWater.ToString("F3"));
        }
      }
    }

    private static void CoolingTowerTest3()
    {
      double twb = MoistAir.GetWetBulbTemperatureFromDryBulbTemperatureAndHumidityRatio(35, 0.0195, 101.325);
      CoolingTower ct = new CoolingTower
        (37, 32, twb, 43.3, 35.7, CoolingTower.AirFlowDirection.CrossFlow, 7.5, false);

      using (StreamWriter sWriter = new StreamWriter
        ("CoolingTowerTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行
        sWriter.Write(" ");
        for (int j = -5; j <= 35; j++) sWriter.Write("," + j.ToString("F0"));
        sWriter.WriteLine(" ");

        for (int i = 40; i <= 100; i++)
        {
          sWriter.Write(i.ToString("F0"));
          for (int j = -5; j <= 35; j++)
          {
            //外気条件を更新して成り行き出口状態を計算
            double hrti =
              MoistAir.GetHumidityRatioFromDryBulbTemperatureAndRelativeHumidity(j, i, 101.325);
            double wbti = MoistAir.GetWetBulbTemperatureFromDryBulbTemperatureAndHumidityRatio(j, hrti, 101.325);
            ct.SetOutdoorAirState(wbti, hrti);
            ct.Update(37, false);

            //熱交換量から出口空気状態を計算            
            double enth = MoistAir.GetEnthalpyFromDryBulbTemperatureAndHumidityRatio(j, hrti)
              + ct.HeatRejection / ct.AirFlowRate;
            double hrto = MoistAir.GetHumidityRatioFromEnthalpyAndRelativeHumidity(enth, 100, 101.325);

            //蒸発潜熱と絶対湿度から潜熱交換量を計算
            double lh = (hrto - hrti) * MoistAir.LatentHeatOfVaporization * ct.AirFlowRate;
            double lhr = lh / ct.HeatRejection;

            sWriter.Write("," + lhr.ToString("F3"));
          }
          sWriter.WriteLine();
        }
      }
    }

    private static void CoolingTowerTest4()
    {
      double twb = MoistAir.GetWetBulbTemperatureFromDryBulbTemperatureAndHumidityRatio
        (35, 0.0195, 101.325);
      CoolingTower ct = new CoolingTower
        (37, 32, twb, 43.3, 35.7, CoolingTower.AirFlowDirection.CrossFlow, 7.5, false);
      double wbt = MoistAir.GetWetBulbTemperatureFromDryBulbTemperatureAndHumidityRatio(28, 0.010, 101.325);
      ct.SetOutdoorAirState(wbt, 0.010);

      using (StreamWriter sWriter = new StreamWriter
        ("CoolingTowerTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        for (int i = 0; i <= 24; i++)
        {
          double cdto = 25 + i * 0.5;
          sWriter.Write(cdto);
          ct.OutletWaterSetPointTemperature = cdto;
          for (int j = 60; j <= 100; j+=5)
          {
            double pl = j / 100d;
            double cdti = cdto + 2.5d / pl;
            ct.WaterFlowRate = 43.3 * pl;
            ct.Update(cdti, true);
            double er = ct.ElectricConsumption / ct.NominalPowerConsumption;
            sWriter.Write("," + er.ToString("F3"));
          }
          sWriter.WriteLine();
        }
      }
    }

    private static void CoolingTowerTest5()
    {
      double wbt = 27;
      CoolingTower ct = new CoolingTower
        (37, 32, wbt, 43.3, 35.7, CoolingTower.AirFlowDirection.CrossFlow, 7.5, false);
      ct.SetOutdoorAirState(wbt, 0.010);

      for (int i = 0; i <= 9; i++)
      {
        double fRatio = 1.0 - 0.1 * i;
        ct.WaterFlowRate = 43.3 * fRatio;
        ct.Update(37, false);
        Console.WriteLine(fRatio + " : " + ct.OutletWaterTemperature + " : " + ct.HeatRejection.ToString("F1"));
      }
    }

    #endregion

    #region 集熱器テスト

    private static void SimpleSolarCollectorTest()
    {
      //集熱器インスタンスの作成
      Incline inc = new Incline(Incline.Orientation.S, 30d / 180d * Math.PI);
      SimpleSolarCollector[] scs = new SimpleSolarCollector[2];
      scs[0] = new SimpleSolarCollector(inc, 1, SimpleSolarCollector.HeatReceiver.FlatPlate);
      scs[1] = new SimpleSolarCollector(inc, 1, SimpleSolarCollector.HeatReceiver.VacuumTube);

      //気象データの作成
      double[] dbt, hrt, rad;
      bool[] fair;
      RandomWeather wRnd = new RandomWeather(1, RandomWeather.Location.Tokyo);
      wRnd.MakeWeather(20, out dbt, out hrt, out rad, out fair);
      Sun sun = new Sun(35, 41.2, 0, 139, 45.9, 0, 135, 0, 0);

      //集熱温度
      double[] cTemp = new double[] { 25, 55, 90 };

      //計算,書き出し処理
      using (StreamWriter sWriter = new StreamWriter
        ("SimpleSolarCollector.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行
        sWriter.Write("月, 傾斜面日射量[MJ/月]");
        for (int i = 0; i < 3; i++) sWriter.Write(",平板型" + cTemp[i] + "C");
        for (int i = 0; i < 3; i++) sWriter.Write(",真空ガラス管型" + cTemp[i] + "C");
        sWriter.WriteLine();

        DateTime dt = new DateTime(1999, 1, 1, 0, 0, 0);
        double[,] sum = new double[12, scs.Length * cTemp.Length + 1];
        for (int i = 0; i < 20; i++)
        {
          for (int j = 0; j < 8760; j++)
          {
            //太陽位置を更新して直散分離
            sun.Update(dt);
            sun.SeparateGlobalHorizontalRadiation(rad[8760 * i + j], Sun.SeparationMethod.Erbs);

            //傾斜面日射量を積算
            sum[dt.Month - 1, 0] += (inc.GetDirectSolarRadiationRate(sun) * sun.DirectNormalRadiation
              + inc.ConfigurationFactorToSky * sun.DiffuseHorizontalRadiation) / 1000d;

            //集熱量[Wh]を計算
            for (int k = 0; k < scs.Length; k++)
            {
              for (int m = 0; m < cTemp.Length; m++)
              {
                if (0 != scs[k].GetWaterFlowRate(sun, cTemp[m], 3, dbt[8760 * i + j]))
                  sum[dt.Month - 1, k * cTemp.Length + m + 1] += scs[k].HeatCollection;
              }
            }
            dt = dt.AddHours(1);
          }
          dt = dt.AddYears(-1);
        }
        //書き出し処理
        for (int i = 0; i < 12; i++)
        {
          sWriter.Write(i + 1);
          sWriter.Write("," + sum[i, 0] / 20d * 3.6); // kWh/20年→MJ/月に変換
          for (int j = 1; j < sum.GetLength(1); j++) sWriter.Write("," + sum[i, j] / sum[i, 0]);
          sWriter.WriteLine();
        }
      }
    }

    private static void FlatPlateSolarCollectorTest()
    {
      double isc = 500;

      Console.WriteLine("平均水温[C], 平均水温/日射量[Cm2K/W], 集熱効率[-]");
      Console.WriteLine("*****基準ケース*****");
      for (int twi = 0; twi < 80; twi++)
      {
        double pt, gt, wt, mt, eta;
        double ht = FlatPlateSolarCollector.GetHeatTransfer
          (0, 0, isc, 0, 0.01, twi, 0.01, 0.1, 0.1, 0, 0.02, 0.05, 2.0, 0.02, 0.013, 0.015, 0.001, 20,
          1.0, 0.90, 0.08, 0.93, out pt, out gt, out wt, out mt, out eta);
        Console.WriteLine((mt / isc).ToString("F3") + ", " + eta.ToString("F2"));
      }
      Console.WriteLine("*****外部風速10m/s*****");
      for (int twi = 0; twi < 80; twi++)
      {
        double pt, gt, wt, mt, eta;
        double ht = FlatPlateSolarCollector.GetHeatTransfer
          (0, 0, isc, 0, 0.01, twi, 0.01, 0.1, 0.1, 10, 0.02, 0.05, 2.0, 0.02, 0.013, 0.015, 0.001, 20, 
          1.0, 0.90, 0.08, 0.93, out pt, out gt, out wt, out mt, out eta);
        Console.WriteLine((mt / isc).ToString("F3") + ", " + eta.ToString("F2"));
      }
      Console.WriteLine("*****水量0.005m/s*****");
      for (int twi = 0; twi < 80; twi++)
      {
        double pt, gt, wt, mt, eta;
        double ht = FlatPlateSolarCollector.GetHeatTransfer
          (0, 0, isc, 0, 0.005, twi, 0.01, 0.1, 0.1, 0, 0.02, 0.05, 2.0, 0.02, 0.013, 0.015, 0.001, 20, 
          1.0, 0.90, 0.08, 0.93, out pt, out gt, out wt, out mt, out eta);
        Console.WriteLine((mt / isc).ToString("F3") + ", " + eta.ToString("F2"));
      }
    }

    #endregion

    #region 発電パネルテスト

    private static void PhotovoltaicPanelTest()
    {
      //太陽光発電パネルを作成//定格出力1W,架台設置,アモルファス,設置角10度刻み
      PhotovoltaicPanel[] pvs = new PhotovoltaicPanel[10];
      for (int i = 0; i < pvs.Length; i++)
      {
        pvs[i] = new PhotovoltaicPanel
          (1, PhotovoltaicPanel.MountType.MountMode, PhotovoltaicPanel.MaterialType.Amorphous, i * 10);
      }

      //年間日射データを計算（東京・那覇・札幌）
      double[] dbtT, dbtN, dbtS, hrt, radS, radT, radN;
      bool[] fair;
      RandomWeather wRnd = new RandomWeather(1, RandomWeather.Location.Tokyo);
      wRnd.MakeWeather(20, out dbtT, out hrt, out radT, out fair);
      wRnd = new RandomWeather(1, RandomWeather.Location.Sapporo);
      wRnd.MakeWeather(20, out dbtS, out hrt, out radS, out fair);
      wRnd = new RandomWeather(1, RandomWeather.Location.Naha);
      wRnd.MakeWeather(20, out dbtN, out hrt, out radN, out fair);

      //太陽
      Sun sunT = new Sun(35, 41.2, 0, 139, 45.9, 0, 135, 0, 0);
      Sun sunS = new Sun(43, 3.5, 0, 141, 19.9, 0, 135, 0, 0);
      Sun sunN = new Sun(26, 12.2, 0, 127, 41.3, 0, 135, 0, 0);

      //計算,書き出し処理
      using (StreamWriter sWriter = new StreamWriter
        ("PhotovoltaicPanelTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行
        sWriter.Write("年");
        for (int i = 0; i < 10; i++) sWriter.Write(",東京" + (i * 10) + "度");
        for (int i = 0; i < 10; i++) sWriter.Write(",札幌" + (i * 10) + "度");
        for (int i = 0; i < 10; i++) sWriter.Write(",那覇" + (i * 10) + "度");
        sWriter.WriteLine();

        DateTime dt = new DateTime(1999, 1, 1, 0, 0, 0);
        double[] pSumT = new double[10];
        double[] pSumS = new double[10];
        double[] pSumN = new double[10];
        for (int i = 0; i < 20; i++)
        {
          for (int j = 0; j < pSumT.Length; j++) pSumT[j] = pSumS[j] = pSumN[j] = 0;
          for (int j = 0; j < 8760; j++)
          {
            //太陽位置を更新して直散分離
            sunT.Update(dt);
            sunS.Update(dt);
            sunN.Update(dt);
            sunT.SeparateGlobalHorizontalRadiation(radT[8760 * i + j], Sun.SeparationMethod.Erbs);
            sunS.SeparateGlobalHorizontalRadiation(radS[8760 * i + j], Sun.SeparationMethod.Erbs);
            sunN.SeparateGlobalHorizontalRadiation(radN[8760 * i + j], Sun.SeparationMethod.Erbs);

            //発電量[W]を計算
            for (int k = 0; k < pvs.Length; k++)
            {
              pSumT[k] += pvs[k].GetPower(dbtT[8760 * i + j], 0.1, sunT);
              pSumS[k] += pvs[k].GetPower(dbtS[8760 * i + j], 0.1, sunS);
              pSumN[k] += pvs[k].GetPower(dbtN[8760 * i + j], 0.1, sunN);
            }
            dt = dt.AddHours(1);
          }
          //書き出し処理
          sWriter.Write(i + 1);
          for (int j = 0; j < pvs.Length; j++) sWriter.Write("," + pSumT[j]);
          for (int j = 0; j < pvs.Length; j++) sWriter.Write("," + pSumS[j]);
          for (int j = 0; j < pvs.Length; j++) sWriter.Write("," + pSumN[j]);
          sWriter.WriteLine();
          dt = dt.AddYears(-1);
        }
      }
    }

    #endregion

    #region ボイラテスト

    private static void HotWaterBoilerTest()
    {
      HotWaterBoiler hBoiler = new HotWaterBoiler
        (50, 70, 710d / 60, 83.6 / 3600, 0, 25, 1.15, Boiler.Fuel.Gas13A, 80);

      using (StreamWriter sWriter = new StreamWriter
        ("HotWaterBoilerTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.WriteLine
          ("負荷率, 空気比1.1, 空気比1.2, 空気比1.3, 40->60C, 50->70C, 60->80C");
        for (int i = 0; i < 10; i++)
        {
          double pl = 1 - 0.1 * i;
          sWriter.Write(pl);
          double wFlow = (710d / 60) * pl;

          hBoiler.OutletWaterSetPointTemperature = 70;
          for (int j = 0; j < 3; j++)
          {
            hBoiler.AirRatio = 1.1 + 0.1 * j;
            hBoiler.Update(50, wFlow);
            sWriter.Write("," + hBoiler.COP.ToString("F4"));
          }

          hBoiler.AirRatio = 1.15;
          for (int j = 0; j < 3; j++)
          {
            hBoiler.OutletWaterSetPointTemperature = 60 + j * 10;
            hBoiler.Update(40 + j * 10, wFlow);
            sWriter.Write("," + hBoiler.COP.ToString("F4"));
          }
          sWriter.WriteLine();
        }
      }
    }

    private static void SteamBoilerTest()
    {
      SteamBoiler sBoiler = new SteamBoiler(100, 490, 1500d / 3600, 81.7 / 3600, 0, 25, 1.15, Boiler.Fuel.Gas13A, 80);

      double[] sf = new double[3];
      for(int i=0;i<sf.Length;i++) sf[i] = sBoiler.NominalCapacity
          / (Water.GetSaturatedVaporEnthalpy(Water.GetSaturationTemperature(490 + 200 * i)) - 418.6);

      using (StreamWriter sWriter = new StreamWriter
        ("SteamBoilerTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.WriteLine("負荷率, 空気比1.1, 空気比1.2, 空気比1.3, 490kPa, 690kPa, 890kPa");
        for (int i = 0; i < 10; i++)
        {
          double pl = 1.0 - 0.1 * i;
          sWriter.Write(pl);

          sBoiler.SteamPressure = 490;
          double sFlow = (1500d / 3600) * pl;
          for (int j = 0; j < 3; j++)
          {
            sBoiler.AirRatio = 1.1 + 0.1 * j;
            sBoiler.Update(100, sFlow);
            sWriter.Write("," + sBoiler.COP);
          }

          sBoiler.AirRatio = 1.15;
          for (int j = 0; j < 3; j++)
          {
            sBoiler.SteamPressure = 470 + j * 200;
            sBoiler.Update(100, sf[j] * pl);
            sWriter.Write("," + sBoiler.COP);
          }
          sWriter.WriteLine();
        }
      }
    }

    #endregion

    #region 圧縮式冷凍機テスト

    private static void SimpleCentrifugalChillerTest()
    {
      using (StreamWriter sWriter = new StreamWriter
        ("SimpleCentrifugalChillerTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //定格冷水量[kg/s]
        const double NCH_FLOW = 500d / (12 - 7) / 4.186;
        //定格冷却水量[kg/s]
        const double NCD_FLOW = 1670d / 60;

        //固定速機とINV機のインスタンスを生成
        SimpleCentrifugalChiller cR = new SimpleCentrifugalChiller(500d / 6d, 0.2, 12, 7, 37, NCH_FLOW, false);
        SimpleCentrifugalChiller iR = new SimpleCentrifugalChiller(500d / 6d, 0.2, 12, 7, 37, NCH_FLOW, true);
        cR.IsOperating = iR.IsOperating = true;   

        sWriter.Write("負荷率");
        for (int i = 0; i < 6; i++) sWriter.Write(",固+固" + (32 - 4 * i));
        for (int i = 0; i < 6; i++) sWriter.Write(",INV+固" + (32 - 4 * i));
        for (int i = 0; i < 6; i++) sWriter.Write(",固+変" + (32 - 4 * i));
        for (int i = 0; i < 6; i++) sWriter.Write(",INV+変" + (32 - 4 * i));
        sWriter.WriteLine();
        for (int i = 0; i < 10; i++)
        {
          //負荷率[-]
          double pl = 1.0 - 0.1 * i;
          sWriter.Write(pl);

          //固定速機・冷却水量固定
          for (int j = 0; j < 6; j++)
          {
            cR.Update(32 - 4 * j, 12, NCD_FLOW, NCH_FLOW * pl);
            sWriter.Write(", " + cR.COP.ToString("F2"));
          }
          //INV機・冷却水量固定
          for (int j = 0; j < 6; j++)
          {
            iR.Update(32 - 4 * j, 12, NCD_FLOW, NCH_FLOW * pl);
            sWriter.Write(", " + iR.COP.ToString("F2"));
          }
          //固定速機・冷却水量変動
          for (int j = 0; j < 6; j++)
          {
            cR.Update(32 - 4 * j, 12, NCD_FLOW * pl, NCH_FLOW * pl);
            sWriter.Write(", " + cR.COP.ToString("F2"));
          }
          //INV機・冷却水量変動
          for (int j = 0; j < 6; j++)
          {
            iR.Update(32 - 4 * j, 12, NCD_FLOW * pl, NCH_FLOW * pl);
            sWriter.Write(", " + iR.COP.ToString("F2"));
          }
          sWriter.WriteLine();
        }
      }
    }

    private static void DetailedCentrifugalInverterChillerTest()
    {
      using (StreamWriter sWriter = new StreamWriter
        ("DetailedCentrifugalInverterChillerTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //インスタンスを生成
        DetailedCentrifugalInverterChiller iR =
          new DetailedCentrifugalInverterChiller(178.8, 0.2, 12, 7, 32, 3023d / 60d, 3567d / 60d);
        iR.IsOperating = true;

        const double NCH_FLOW = 3023d / 60d;  //定格冷水量[kg/s]        
        const double NCD_FLOW = 3567d / 60d;  //定格冷却水量[kg/s]

        sWriter.Write("負荷率");
        for (int i = 0; i < 6; i++) sWriter.Write(",INV+固" + (32 - 4 * i));
        for (int i = 0; i < 6; i++) sWriter.Write(",INV+変" + (32 - 4 * i));
        sWriter.WriteLine();
        for (int i = 0; i < 10; i++)
        {
          //負荷率[-]
          double pl = 1.0 - 0.1 * i;
          sWriter.Write(pl);

          //冷却水量固定
          for (int j = 0; j < 6; j++)
          {
            iR.Update(32 - 4 * j, 12, NCD_FLOW, NCH_FLOW * pl);
            sWriter.Write(", " + iR.COP.ToString("F2"));
          }
          //冷却水量変動
          for (int j = 0; j < 6; j++)
          {
            iR.Update(32 - 4 * j, 12, NCD_FLOW * pl, NCH_FLOW * pl);
            sWriter.Write(", " + iR.COP.ToString("F2"));
          }
          sWriter.WriteLine();
        }
      }
    }

    private static void DetailedCentrifugalInverterChillerTest1()
    {
      using (StreamReader sReader = new StreamReader("input.csv"))
      using (StreamWriter sWriter = new StreamWriter
        ("DetailedCentrifugalInverterChillerTest1.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //INV機のインスタンスを生成
        DetailedCentrifugalInverterChiller iR =
          new DetailedCentrifugalInverterChiller(178.8, 0.2, 12, 7, 32, 3023d / 60d, 3567d / 60d);

        string buff;
        while ((buff = sReader.ReadLine()) != null)
        {
          string[] bf = buff.Split(',');
          double mcd = double.Parse(bf[0]) / 60d;
          double mch = double.Parse(bf[2]) / 60d;
          double tcd = double.Parse(bf[1]);
          double tch = double.Parse(bf[3]);
          iR.ChilledWaterOutletSetPointTemperature = tch - 5;
          iR.Update(tcd, tch, mch, mcd);
          sWriter.WriteLine(iR.COP.ToString("F2"));
        }
      }
    }    

    #endregion

    #region 空気熱源ヒートポンプテスト

    private static void AirSourceHeatPumpTest()
    {
      //空気熱源HPのインスタンスを生成
      AirHeatSourceModularChillers ahp = new AirHeatSourceModularChillers
        (150, 7, 430d / 60, 35, 850d / 60 * 1.2, 49.8, 150, 45, 430d / 60, 7, 850d / 60 * 1.2, 50.0, 3, 1.9);
      ahp.MaximizeEfficiency = true;

      //タイトル行
      for (int i = 0; i <= 30; i++) Console.Write(", " + (10 * i).ToString("F0"));
      Console.WriteLine();

      //冷房運転
      Console.WriteLine("Cooling");
      ahp.Mode = AirHeatSourceModularChillers.OperatingMode.Cooling;
      ahp.WaterOutletSetPointTemperature = 7;
      double[] tai = new double[] { 20, 25, 30, 35 };
      for (int i = 0; i < tai.Length; i++)
      {
        Console.Write(tai[i]);
        for (int j = 0; j <= 30; j++)
        {
          double pl = 0.1 * j;
          double mw = 430d * 3 / 60;
          double twi = 7 + (150d * pl) / (4.186 * mw);
          ahp.Update(twi, mw, tai[i]);
          Console.Write(", " + ahp.COP.ToString("F3"));
        }
        Console.WriteLine();
      }

      //暖房運転
      Console.WriteLine("Heating");
      ahp.Mode = AirHeatSourceModularChillers.OperatingMode.Heating;
      ahp.WaterOutletSetPointTemperature = 45;
      tai = new double[] { 20, 15, 10, 7 };
      for (int i = 0; i < tai.Length; i++)
      {
        Console.Write(tai[i]);
        for (int j = 0; j <= 30; j++)
        {
          double pl = 0.1 * j;
          double mw = 430d * 3 / 60;
          double twi = 45 - (150d * pl) / (4.186 * mw);
          ahp.Update(twi, mw, tai[i]);
          Console.Write(", " + ahp.COP.ToString("F3"));
        }
        Console.WriteLine();
      }
    }

    #endregion

    #region 吸収式冷凍機テスト

    private static void HotWaterAbsorptionChillerTest()
    {
      HotWaterAbsorptionChiller ar = new HotWaterAbsorptionChiller
        (12.5, 7, 274.9 / 60, 31, 35, 918d / 60, 88, 83, 432d / 60);

      using (StreamWriter sWriter = new StreamWriter
        ("HotWaterAbsorptionChillerTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.WriteLine("負荷率・冷却水温度・COPの関係");
        sWriter.WriteLine("負荷率, 31C, 28C, 25C, 22C");
        for (int i = 0; i < 13; i++)
        {
          double pl = (1 - 0.05 * i);
          double fl = (274.9 / 60) * pl;

          sWriter.Write((pl * 100).ToString("F0"));
          for (int j = 0; j < 4; j++)
          {
            ar.Update(12.5, fl, 31 - j * 3, 918d / 60, 88, 432d / 60);
            sWriter.Write("," + ar.COP.ToString("F3"));
          }
          sWriter.WriteLine();
        }

        sWriter.WriteLine();
        sWriter.WriteLine("温水温度・温水流量・処理熱量の関係");
        sWriter.WriteLine("温水温度, 100%, 75%, 50%");
        ar.ChilledWaterOutletSetPointTemperature = 0;
        for (int i = 0; i < 26; i++)
        {
          double thw = 70 + i;
          sWriter.Write(thw.ToString("F0"));
          for (int j = 0; j < 3; j++)
          {
            ar.Update(12.5, 274.9 / 60, 31, 918d / 60, thw, 432d / 60 * (1 - 0.25 * j));
            sWriter.Write("," + ar.CoolingLoad.ToString("F1"));
          }
          sWriter.WriteLine();
        }
      }
    }

    private static void DirectFiredAbsorptionChillerTest1()
    {
      DirectFiredAbsorptionChiller ar = new DirectFiredAbsorptionChiller(103d / 3600, 103d / 3600,
        15, 7, 32, 37, 54.7, 60, 189 / 3.6, 500 / 3.6, 189 / 3.6, 0, Boiler.Fuel.Gas13A);

      using (StreamWriter sWriter = new StreamWriter
        ("DirectFiredAbsorptionChillerTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.WriteLine("負荷率,COP(INV),COP(定速)");

        for (int i = 0; i < 19; i++)
        {
          //JIS B8622 条件
          double pl = (1 - 0.05 * i);
          double tcd = 27 + 5 * pl;
          double tch = 7 + 8 * pl;

          sWriter.Write((pl * 100).ToString("F0"));

          ar.HasSolutionInverterPump = true;
          ar.Update(tcd, tch, 500 / 3.6, 189 / 3.6);
          sWriter.Write("," + ar.COP.ToString("F3"));

          ar.HasSolutionInverterPump = false;
          ar.Update(tcd, tch, 500 / 3.6, 189 / 3.6);
          sWriter.Write("," + ar.COP.ToString("F3"));

          sWriter.WriteLine();
        }
      }
    }

    private static void DirectFiredAbsorptionChillerTest2()
    {
      DirectFiredAbsorptionChiller ar = new DirectFiredAbsorptionChiller(103d / 3600, 103d / 3600,
        15, 7, 32, 37, 54.7, 60, 189 / 3.6, 500 / 3.6, 189 / 3.6, 0, Boiler.Fuel.Gas13A);
      ar.HasSolutionInverterPump = true;

      using (StreamWriter sWriter = new StreamWriter
        ("DirectFiredAbsorptionChillerTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.WriteLine("条件,蒸発温度,凝縮温度,再生温度,COP,稀溶液濃度,濃溶液濃度");

        sWriter.Write("定格性能,");
        ar.Update(32, 15, 500 / 3.6, 189 / 3.6);
        sWriter.WriteLine(ar.EvaporatingTemperature + "," + ar.CondensingTemperature + "," + ar.DesorbTemperature
          + "," + ar.COP + "," + ar.ThinSolutionMassFraction + "," + ar.ThickSolutionMassFraction);

        sWriter.Write("負荷率50%,");
        ar.Update(32, 11, 500 / 3.6, 189 / 3.6);
        sWriter.WriteLine(ar.EvaporatingTemperature + "," + ar.CondensingTemperature + "," + ar.DesorbTemperature
          + "," + ar.COP + "," + ar.ThinSolutionMassFraction + "," + ar.ThickSolutionMassFraction);

        sWriter.Write("冷却水温度25度,");
        ar.Update(25, 15, 500 / 3.6, 189 / 3.6);
        sWriter.WriteLine(ar.EvaporatingTemperature + "," + ar.CondensingTemperature + "," + ar.DesorbTemperature
          + "," + ar.COP + "," + ar.ThinSolutionMassFraction + "," + ar.ThickSolutionMassFraction);

        sWriter.Write("冷水流量50%,");
        ar.Update(32, 15, 500 / 3.6, 189 / 3.6 * 0.5);
        sWriter.WriteLine(ar.EvaporatingTemperature + "," + ar.CondensingTemperature + "," + ar.DesorbTemperature
          + "," + ar.COP + "," + ar.ThinSolutionMassFraction + "," + ar.ThickSolutionMassFraction);

        sWriter.Write("冷水出口温度10度,");
        ar.OutletWaterSetPointTemperature = 10;
        ar.Update(32, 18, 500 / 3.6, 189 / 3.6);
        sWriter.WriteLine(ar.EvaporatingTemperature + "," + ar.CondensingTemperature + "," + ar.DesorbTemperature
          + "," + ar.COP + "," + ar.ThinSolutionMassFraction + "," + ar.ThickSolutionMassFraction);
      }
    }

    private static void AbsorptionChillerTest3_sub
      (DirectFiredAbsorptionChiller ar, StreamWriter sWriter)
    {
      double tv = LithiumBromide.GetVaporTemperatureFromLiquidTemperatureAndMassFraction
        (ar.DesorbTemperature + 273.15, ar.ThickSolutionMassFraction) - 273.15;
      double tl = LithiumBromide.GetLiquidTemperatureFromVaporTemperatureAndMassFraction
        (tv + 273.15, ar.ThinSolutionMassFraction) - 273.15;
      sWriter.WriteLine(tl + "," + tv);
      sWriter.WriteLine(tv + "," + tv);
      sWriter.WriteLine(ar.CondensingTemperature + "," + ar.CondensingTemperature);
      sWriter.WriteLine(ar.EvaporatingTemperature + "," + ar.EvaporatingTemperature);
      sWriter.WriteLine(ar.CondensingTemperature + "," + ar.EvaporatingTemperature);
      tl = LithiumBromide.GetLiquidTemperatureFromVaporTemperatureAndMassFraction
         (ar.CondensingTemperature + 273.15, ar.ThinSolutionMassFraction) - 273.15;
      sWriter.WriteLine(tl + "," + ar.CondensingTemperature);
      tl = LithiumBromide.GetLiquidTemperatureFromVaporTemperatureAndMassFraction
         (tv + 273.15, ar.ThinSolutionMassFraction) - 273.15;
      sWriter.WriteLine(tl + "," + tv);
      sWriter.WriteLine(ar.DesorbTemperature + "," + tv);
      tl = LithiumBromide.GetLiquidTemperatureFromVaporTemperatureAndMassFraction
         (ar.CondensingTemperature + 273.15, ar.ThickSolutionMassFraction) - 273.15;
      sWriter.WriteLine(tl + "," + ar.CondensingTemperature);
      tl = LithiumBromide.GetLiquidTemperatureFromVaporTemperatureAndMassFraction
         (ar.EvaporatingTemperature + 273.15, ar.ThickSolutionMassFraction) - 273.15;
      sWriter.WriteLine(tl + "," + ar.EvaporatingTemperature);
      sWriter.WriteLine(ar.COP);
    }

    private static void AbsorptionChillerTest5()
    {
      MersenneTwister mt = new MersenneTwister(1);

      DirectFiredAbsorptionChiller ar1 = new DirectFiredAbsorptionChiller
        (103d / 3600, 103d / 3600, 15, 7, 32, 37, 54.7, 60, 189 / 3.6, 500 / 3.6, 189 / 3.6, 0, Boiler.Fuel.Gas13A);
      for (int i = 0; i < 1000; i++)
      {
        double pl = mt.NextDouble();
        double tcdi = 27 + 5 * mt.NextDouble();
        double wfl = pl + (1 - pl) * mt.NextDouble();
        ar1.OutletWaterSetPointTemperature = 6 + 9 * mt.NextDouble();
        double tchi = ar1.OutletWaterSetPointTemperature + 8 * pl / wfl;
        ar1.Update(tcdi, tchi, 500 / 3.6 * pl, 189 / 3.6 * wfl);
        Console.WriteLine(ar1.COP.ToString("F2"));
      }

      ar1.IsCoolingMode = false;
      for (int i = 0; i < 1000; i++)
      {
        double pl = mt.NextDouble();
        double wfl = pl + (1 - pl) * mt.NextDouble();
        ar1.OutletWaterSetPointTemperature = 60 - 6.3 * mt.NextDouble();
        double hi = ar1.OutletWaterSetPointTemperature - 5.3 * pl / wfl;
        ar1.Update(32, hi, 500 / 3.6 * pl, 189 / 3.6 * wfl);
        Console.WriteLine(ar1.COP.ToString("F2"));
      }

      HotWaterAbsorptionChiller ar0 = new HotWaterAbsorptionChiller
        (12.5, 7, 274.9 / 60, 31, 35, 918d / 60, 88, 83, 432d / 60);
      for (int i = 0; i < 1000; i++)
      {
        double pl = mt.NextDouble();
        double tcdi = 27 + 5 * mt.NextDouble();
        double wfl = pl + (1 - pl) * mt.NextDouble();
        ar0.ChilledWaterOutletSetPointTemperature = 6 + 4 * mt.NextDouble();
        double tchi = ar0.ChilledWaterOutletSetPointTemperature + 8 * pl / wfl;
        double thi = 82 + mt.NextDouble() * 8d;
        ar0.Update(tchi, 274.9 / 60 * wfl, tcdi, 918d / 60 * pl, thi, 432d / 60);
        Console.WriteLine(ar0.COP.ToString("F2"));
      }
    }

    #endregion

    #region 蓄熱槽テスト

    private static void WaterHeatStorageTest1()
    {
      int tNum = 10;
      double wf = 0.6 / 60d;

      double[] volumes = new double[tNum];
      for (int i = 0; i < tNum; i++) volumes[i] = 15;
      MultiConnectedWaterTank wTank = new MultiConnectedWaterTank(volumes);
      wTank.InitializeTemperature(17);
      wTank.TimeStep = 600;
      for (int i = 0; i < tNum; i++) wTank.SetHeatLossCoefficient(i, 0.02);
      wTank.AmbientTemperature = 15;

      using (StreamWriter sw = new StreamWriter("WaterHeatStorageTest1.csv"))
      {
        for (int i = 0; i < 48; i++)
        {
          sw.Write(i);
          for (int j = 0; j < tNum; j++) sw.Write(", " + wTank.GetTemperature(j));
          sw.WriteLine();

          wTank.ForecastState(7, wf, true);
          wTank.FixState();
        }
        for (int i = 0; i < 48; i++)
        {
          sw.Write(i);
          for (int j = 0; j < tNum; j++) sw.Write(", " + wTank.GetTemperature(j));
          sw.WriteLine();

          wTank.ForecastState(17, wf, false);
          wTank.FixState();
        }
      }
    }

    private static void WaterHeatStorageTest2()
    {
      MultipleStratifiedWaterTank tank = new MultipleStratifiedWaterTank(0.8, 0.8 * 0.8, 0.05, 0.72, 100);
      tank.HeatLossCoefficient = 0.001 * 6 * 0.04 / 0.1;
      tank.AmbientTemperature = 20;
      tank.TimeStep = 10;

      using (StreamWriter sWriter = new StreamWriter
        ("WaterHeatStorageTest2.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.WriteLine("ステップ温度上昇");
        double waterChangeRate = 0.0;
        double trig = 0.0;
        tank.InitializeTemperature(15);
        while (waterChangeRate < 1.0)
        {
          double inletTemp = 21;
          if (0.5 < waterChangeRate) inletTemp = 25;
          tank.UpdateState(inletTemp, 0.25 / 3600, true);
          waterChangeRate += (0.25 / 3600 * tank.TimeStep) / tank.WaterVolume;

          if (trig < waterChangeRate)
          {
            sWriter.Write(waterChangeRate.ToString("F1"));
            for (int j = 0; j < tank.LayerNumber; j++) sWriter.Write(", " + tank.GetTemperature(j));
            sWriter.WriteLine();
            trig += 0.1;
          }
        }

        sWriter.WriteLine("ステップ温度低下");
        waterChangeRate = 0.0;
        trig = 0.0;
        tank.InitializeTemperature(15);
        while (waterChangeRate < 1.0)
        {
          double inletTemp = 24;
          if (0.5 < waterChangeRate) inletTemp = 21;
          tank.UpdateState(inletTemp, 0.25 / 3600, true);
          waterChangeRate += (0.25 / 3600 * tank.TimeStep) / tank.WaterVolume;

          if (trig < waterChangeRate)
          {
            sWriter.Write(waterChangeRate.ToString("F1"));
            for (int j = 0; j < tank.LayerNumber; j++) sWriter.Write(", " + tank.GetTemperature(j));
            sWriter.WriteLine();
            trig += 0.1;
          }
        }

        sWriter.WriteLine("ステップ流量変化");
        waterChangeRate = 0.0;
        trig = 0.0;
        tank.InitializeTemperature(6);
        while (waterChangeRate < 1.0)
        {
          double waterFlowRate = 0.5 / 3600;
          if (0.3 < waterChangeRate && waterChangeRate < 0.8) waterFlowRate = 0.1 / 3600;
          tank.UpdateState(12, waterFlowRate, true);
          waterChangeRate += (waterFlowRate * tank.TimeStep) / tank.WaterVolume;

          if (trig < waterChangeRate)
          {
            sWriter.Write(waterChangeRate.ToString("F1"));
            for (int j = 0; j < tank.LayerNumber; j++) sWriter.Write(", " + tank.GetTemperature(j));
            sWriter.WriteLine();
            trig += 0.1;
          }
        }
      }
    }

    #endregion

    #region 人体モデルテスト

    private static void TwoNodeModelTest()
    {
      double[] activity = new double[] { 45, 65, 100 };
      double[] opTemp = new double[] { 22, 24, 26, 28 };

      Console.WriteLine
        ("22CSH, 22CLH, 22CSET*, 24CSH, 24CLH, 24CSET*, 26CSH, 26CLH, 26CSET*, 28CSH, 28CLH, 28CSET*");
      double st, ct, bt, clt, ss, ls, sr, lr, wd;
      for (int i = 0; i < activity.Length; i++)
      {
        for (int j = 0; j < opTemp.Length; j++)
        {
          TwoNodeModel.GetSteadyState
            (opTemp[j], opTemp[j], 50, 0.3, 0.6, activity[i], 0, 101.325,
            out st, out ct, out bt, out clt, out ss, out ls, out sr, out lr, out wd);
          double sh = (ss + sr) * 1.8;    //顕熱負荷[W]
          double lh = (ls + lr) * 1.8;    //潜熱負荷[W]
          double setstar = TwoNodeModel.GetSETStar(opTemp[j], activity[i], 0, clt, st, ss, ls, wd);

          Console.Write(sh.ToString("F1") + ", " + lh.ToString("F1") + ", " + setstar.ToString("F1") + ", ");
        }
        Console.WriteLine();
      }
    }

    private static void TwoNodeModelTest2()
    {
      //温度・湿度・着衣条件　0:夏季,1:冬季,2:中間期
      double[] dbt = new double[] { 26, 24, 22 };
      double[] hmd = new double[] { 50, 50, 40 };
      double[] clth = new double[] { 0.6, 0.8, 1.1 };

      for (int i = 0; i < 3; i++)
      {
        //標準条件のSET*
        double stnd = TwoNodeModel.GetSETStarFromAmbientCondition
          (dbt[i], dbt[i], hmd[i], 0.2, clth[i], 65, 0, 101.325);
        for (int j = 30; j <= 100; j += 10)
        {
          Roots.ErrorFunction eFnc = delegate (double temp)
          {
            return stnd - TwoNodeModel.GetSETStarFromAmbientCondition(temp, temp, j, 0.2, clth[i], 65, 0, 101.325);
          };
          double set2 = Roots.Newton(eFnc, 24, 0.0001, 0.0001, 0.0001, 20);
          Console.Write(", " + set2.ToString("F3"));
        }
        Console.WriteLine();
      }
    }

    private static void TwoNodeModelTest3()
    {
      int[] age = new int[] { 20, 30, 40, 50, 60 };
      double[] weight = new double[] { 45, 55, 65, 75, 85 };

      double st, ct, bt, clt, ss, ls, sr, lr, wd;
      for (int i = 0; i < age.Length; i++)
      {
        Console.Write(age[i]);
        for (int j = 0; j < weight.Length; j++)
        {
          TwoNodeModel.GetSteadyState(age[i], 1.7, weight[j], 26, 26, 50, 0.1, 0.6, 65, 0, 101.325,
            out st, out ct, out bt, out clt, out ss, out ls, out sr, out lr, out wd);
          Console.Write(", " + ss.ToString("F4"));
        }
        Console.WriteLine();
      }
    }

    private static void TwoNodeModelTest4()
    {
      double[] AVE_HEIGHT = new double[] { 171.90, 172.04, 171.49, 170.31, 167.39, 158.56, 158.82, 158.67, 157.17, 154.38 };  //平均身長
      double[] SD_HEIGHT = new double[] { 5.64, 5.64, 5.65, 5.50, 5.35, 5.29, 5.10, 5.19, 5.04, 4.89 }; //身長標準偏差
      double[] AVE_WEIGHT = new double[] { 66.34, 68.19, 69.38, 68.14, 65.21, 50.60, 51.35, 52.71, 53.23, 52.24 };  //平均体重
      double[] SD_WEIGHT = new double[] { 9.23, 9.24, 9.45, 8.84, 8.01, 5.78, 6.02, 6.21, 6.58, 6.94 }; //体重標準偏差

      //身長体重初期化
      NormalRandom nRnd = new NormalRandom(1);
      TwoNodeModel[] mdls = new TwoNodeModel[1000];
      int indx = 0;
      for (uint age = 25; age < 70; age += 10)
      {
        int hwInd = 0;
        if (age < 30) hwInd += 0;
        else if (age < 40) hwInd += 1;
        else if (age < 50) hwInd += 2;
        else if (age < 60) hwInd += 3;
        else hwInd += 4;
        for (int i = 0; i < 100; i++) //男性100体
        {
          double height = Math.Round(nRnd.NextDouble() * SD_HEIGHT[hwInd] + AVE_HEIGHT[hwInd], 1);
          double weight = Math.Round(nRnd.NextDouble() * SD_WEIGHT[hwInd] + AVE_WEIGHT[hwInd], 1);
          mdls[indx] = new TwoNodeModel(age, true, 0.01 *  height, weight);
          indx++;
        }
        hwInd += 5;
        for (int i = 0; i < 100; i++) //女性100体
        {
          double height = Math.Round(nRnd.NextDouble() * SD_HEIGHT[hwInd] + AVE_HEIGHT[hwInd], 1);
          double weight = Math.Round(nRnd.NextDouble() * SD_WEIGHT[hwInd] + AVE_WEIGHT[hwInd], 1);
          mdls[indx] = new TwoNodeModel(age, false, 0.01 * height, weight);
          indx++;
        }
      }

      using (StreamWriter sWriter = new StreamWriter("TwoNodeModelTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        for (int dbt = 10; dbt < 40; dbt++)
        {
          Console.WriteLine(dbt);

          double pmv = ThermalComfort.GetPMV(dbt, dbt, 50, 0.1, 0.9, 1.1, 0);
          double ppd = ThermalComfort.GetPPD(pmv);
          sWriter.Write(pmv + ", " + ppd);

          for (int j = 0; j < mdls.Length; j++)
          {
            mdls[j].UpdateState(3600, dbt, dbt, 50, 0.1, 0.9, 1.1, 0, 101.325);
            double tsv = -6.12
              + 35.86 * (0.5 + Math.Atan((mdls[j].SkinTemperature - 39.48) / 2.06) / Math.PI)
              + 3.69 * (0.5 + Math.Atan((0 + 0.04) / 0.17) / Math.PI);
            tsv += nRnd.NextDouble() * 0.64;
            sWriter.Write(", " + tsv);
          }

          sWriter.WriteLine();
        }
      }
    }

    private static void PMVTest()
    {
      //上下限値
      const int HMD_MAX = 70;
      const int HMD_MIN = 20;

      using (StreamWriter sWriter = new StreamWriter("PMVTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行
        for (int hmd = HMD_MIN; hmd <= HMD_MAX; hmd += 10) sWriter.Write("," + hmd.ToString("F0"));
        sWriter.WriteLine();

        sWriter.WriteLine("夏季");
        for (int mrt = 20; mrt <= 40; mrt++)
        {
          sWriter.Write(mrt.ToString("F0"));
          for (int hmd = HMD_MIN; hmd <= HMD_MAX; hmd += 10)
          {
            double pmv = ThermalComfort.GetDrybulbTemperature(0, mrt, hmd, 0.1, 0.65, 1.1, 0.0);
            sWriter.Write("," + pmv.ToString("F2"));
          }
          sWriter.WriteLine();
        }

        sWriter.WriteLine();
        sWriter.WriteLine("冬季");
        for (int mrt = 10; mrt <= 30; mrt++)
        {
          sWriter.Write(mrt.ToString("F0"));
          for (int hmd = HMD_MIN; hmd <= HMD_MAX; hmd += 10)
          {
            double pmv = ThermalComfort.GetDrybulbTemperature(0, mrt, hmd, 0.1, 0.80, 1.1, 0.0);
            sWriter.Write("," + pmv.ToString("F2"));
          }
          sWriter.WriteLine();
        }
      }
    }

    private static double estimateCLOValue
      (double tdb1, double trd1, double hrt1, double clo1, double tdb2, double trd2, double hrt2)
    {
      double rel1 = MoistAir.GetRelativeHumidityFromDryBulbTemperatureAndHumidityRatio(tdb1, hrt1, 101.325);
      double rel2 = MoistAir.GetRelativeHumidityFromDryBulbTemperatureAndHumidityRatio(tdb2, hrt2, 101.325);
      double pmv1 = ThermalComfort.GetPMV(tdb1, trd1, rel1, 0.2, clo1, 1.1, 0);

      Roots.ErrorFunction eFnc = delegate (double clo2)
      { return pmv1 - ThermalComfort.GetPMV(tdb2, trd2, rel2, 0.2, clo2, 1.1, 0); };

      return Roots.Bisection(eFnc, 0.01, 2.0, 1e-4, 1e-4, 50);
    }

    private static double estimateVelocity
      (double tdb1, double trd1, double hrt1, double clo1, double vel1, double tdb2, double trd2, double hrt2, double clo2)
    {
      double rel1 = MoistAir.GetRelativeHumidityFromDryBulbTemperatureAndHumidityRatio(tdb1, hrt1, 101.325);
      double rel2 = MoistAir.GetRelativeHumidityFromDryBulbTemperatureAndHumidityRatio(tdb2, hrt2, 101.325);
      double pmv1 = ThermalComfort.GetPMV(tdb1, trd1, rel1, vel1, clo1, 1.1, 0);

      Roots.ErrorFunction eFnc = delegate (double vel2)
      { return pmv1 - ThermalComfort.GetPMV(tdb2, trd2, rel2, vel2, clo2, 1.1, 0); };

      return Roots.Bisection(eFnc, 0.01, 2.0, 1e-4, 1e-4, 50);
    }

    private static void MultiNodeModelTest2()
    {
      //人体モデル作成
      MultiNodeModel mn = new MultiNodeModel();
      mn.UpdateBoundary(0, 28.8, 28.8, 50);
      mn.UpdateBoundary(MultiNodeModel.Node.RightLeg, 0, 40, 40, 50);
      for (int i = 0; i < 120; i++) mn.Update(600);

      //四肢末端部位
      const MultiNodeModel.Node TERMINAL_NODE = 
        MultiNodeModel.Node.LeftHand | MultiNodeModel.Node.RightHand | 
        MultiNodeModel.Node.LeftFoot | MultiNodeModel.Node.RightFoot;

      //四肢部位
      const MultiNodeModel.Node LIMBS = TERMINAL_NODE | 
        MultiNodeModel.Node.LeftShoulder | MultiNodeModel.Node.RightShoulder | 
        MultiNodeModel.Node.LeftArm | MultiNodeModel.Node.RightArm | 
        MultiNodeModel.Node.LeftThigh | MultiNodeModel.Node.RightThigh | 
        MultiNodeModel.Node.LeftLeg | MultiNodeModel.Node.RightLeg;

      using (StreamWriter sWriter =
        new StreamWriter("MultiNodeTest2.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.WriteLine();

        foreach (MultiNodeModel.Node nd in Enum.GetValues(typeof(MultiNodeModel.Node)))
        {
          double tar = mn.GetTemperature(nd, MultiNodeModel.Layer.Artery);
          double tdv = mn.GetTemperature(nd, MultiNodeModel.Layer.DeepVein);
          double tcr = mn.GetTemperature(nd, MultiNodeModel.Layer.Core);
          double tms = mn.GetTemperature(nd, MultiNodeModel.Layer.Muscle);
          double tft = mn.GetTemperature(nd, MultiNodeModel.Layer.Fat);
          double tsk = mn.GetTemperature(nd, MultiNodeModel.Layer.Skin);
          double bfar = mn.GetBloodFlow(nd, MultiNodeModel.Layer.Artery);
          double bfdv = mn.GetBloodFlow(nd, MultiNodeModel.Layer.DeepVein);
          double bfcr = mn.GetBloodFlow(nd, MultiNodeModel.Layer.Core);
          double bfms = mn.GetBloodFlow(nd, MultiNodeModel.Layer.Muscle);
          double bfft = mn.GetBloodFlow(nd, MultiNodeModel.Layer.Fat);
          double bfsk = mn.GetBloodFlow(nd, MultiNodeModel.Layer.Skin);
          double bfava = mn.GetBloodFlow(nd, MultiNodeModel.Layer.AVA);
          double tsv, bfsv;
          if ((nd & LIMBS) == 0)
          {
            tsv = 0;
            bfsv = 0;
          }
          else
          {
            tsv = mn.GetTemperature(nd, MultiNodeModel.Layer.SuperficialVein);
            bfsv = mn.GetBloodFlow(nd, MultiNodeModel.Layer.SuperficialVein);
          }

          //一般情報******************************
          sWriter.WriteLine(nd.ToString() + "核層代謝量," + mn.GetMetabolicRate(nd, MultiNodeModel.Layer.Core));
          sWriter.WriteLine(nd.ToString() + "筋肉層代謝量," + mn.GetMetabolicRate(nd, MultiNodeModel.Layer.Muscle));
          sWriter.WriteLine(nd.ToString() + "脂肪層代謝量," + mn.GetMetabolicRate(nd, MultiNodeModel.Layer.Fat));
          sWriter.WriteLine(nd.ToString() + "皮膚層代謝量," + mn.GetMetabolicRate(nd, MultiNodeModel.Layer.Skin));
          sWriter.WriteLine(nd.ToString() + "核層温度," + tcr);
          sWriter.WriteLine(nd.ToString() + "筋肉層温度," + tms);
          sWriter.WriteLine(nd.ToString() + "脂肪層温度," + tft);
          sWriter.WriteLine(nd.ToString() + "皮膚層温度," + tsk);
          sWriter.WriteLine(nd.ToString() + "動脈温度," + tar);
          sWriter.WriteLine(nd.ToString() + "静脈温度," + tdv);
          sWriter.WriteLine(nd.ToString() + "表在静脈温度," + tsv);
          sWriter.WriteLine(nd.ToString() + "外界相当温度," + mn.GetOperatingTemperature(nd) + "," + mn.GetRelativeHumidity(nd));

          //部位内熱移動******************************
          double[] ht = new double[14];
          ht[0] = (tar - tdv) * mn.GetHeatConductance(nd, MultiNodeModel.Layer.Artery, MultiNodeModel.Layer.DeepVein);
          ht[1] = tar * bfava * MultiNodeModel.BLD_SPECIFICHEAT;
          ht[2] = (tar - tcr) * mn.GetHeatConductance(nd, MultiNodeModel.Layer.Artery, MultiNodeModel.Layer.Core) + tar * bfcr * MultiNodeModel.BLD_SPECIFICHEAT;
          ht[3] = tar * bfms * MultiNodeModel.BLD_SPECIFICHEAT;
          ht[4] = tar * bfft * MultiNodeModel.BLD_SPECIFICHEAT;
          ht[5] = tar * bfsk * MultiNodeModel.BLD_SPECIFICHEAT;
          ht[6] = tcr * bfcr * MultiNodeModel.BLD_SPECIFICHEAT + (tcr - tdv) * mn.GetHeatConductance(nd, MultiNodeModel.Layer.Core, MultiNodeModel.Layer.DeepVein);
          ht[7] = tms * bfms * MultiNodeModel.BLD_SPECIFICHEAT;
          ht[8] = tft * bfft * MultiNodeModel.BLD_SPECIFICHEAT;
          ht[9] = tsk * bfsk * MultiNodeModel.BLD_SPECIFICHEAT;
          ht[10] = (tsk - tsv) * mn.GetHeatConductance(nd, MultiNodeModel.Layer.Skin, MultiNodeModel.Layer.SuperficialVein);
          ht[11] = (tcr - tms) * mn.GetHeatConductance(nd, MultiNodeModel.Layer.Core, MultiNodeModel.Layer.Muscle);
          ht[12] = (tms - tft) * mn.GetHeatConductance(nd, MultiNodeModel.Layer.Muscle, MultiNodeModel.Layer.Fat);
          ht[13] = (tft - tsk) * mn.GetHeatConductance(nd, MultiNodeModel.Layer.Fat, MultiNodeModel.Layer.Skin);
          sWriter.WriteLine(nd.ToString() + "動脈→深部静脈熱移動," + ht[0]);
          sWriter.WriteLine(nd.ToString() + "動脈→表在静脈熱移動," + ht[1]);
          sWriter.WriteLine(nd.ToString() + "動脈→核層熱移動," + ht[2]);
          sWriter.WriteLine(nd.ToString() + "動脈→筋肉層熱移動," + ht[3]);
          sWriter.WriteLine(nd.ToString() + "動脈→脂肪層熱移動," + ht[4]);
          sWriter.WriteLine(nd.ToString() + "動脈→皮膚層熱移動," + ht[5]);
          sWriter.WriteLine(nd.ToString() + "核層→深部静脈熱移動," + ht[6]);
          sWriter.WriteLine(nd.ToString() + "筋肉層→深部静脈熱移動," + ht[7]);
          sWriter.WriteLine(nd.ToString() + "脂肪層→深部静脈熱移動," + ht[8]);
          sWriter.WriteLine(nd.ToString() + "皮膚層→深部静脈熱移動," + ht[9]);
          sWriter.WriteLine(nd.ToString() + "皮膚層→表在静脈熱移動," + ht[10]);
          sWriter.WriteLine(nd.ToString() + "核層→筋肉層熱移動," + ht[11]);
          sWriter.WriteLine(nd.ToString() + "筋肉層→脂肪層熱移動," + ht[12]);
          sWriter.WriteLine(nd.ToString() + "脂肪層→皮膚層熱移動," + ht[13]);
          sWriter.WriteLine(nd.ToString() + "皮膚層→外界熱移動," + (mn.GetSensibleHeatLoss(nd) + mn.GetLatentHeatLoss(nd)) + "," + mn.GetLatentHeatLoss(nd));

          //動脈による熱移動
          double hSum;
          double bf = (bfdv + bfsv);
          MultiNodeModel.Node up = MultiNodeModel.GetUpstreamNode(nd);
          if (up == 0) hSum = mn.CentralBloodTemperature * bf * MultiNodeModel.BLD_SPECIFICHEAT;
          else hSum = mn.GetTemperature(up, MultiNodeModel.Layer.Artery) * bf * MultiNodeModel.BLD_SPECIFICHEAT;
          sWriter.WriteLine(nd.ToString() + "上流動脈からの熱移動," + hSum);
          hSum = 0;
          hSum += tar * bfar * MultiNodeModel.BLD_SPECIFICHEAT;
          sWriter.WriteLine(nd.ToString() + "下流動脈への熱移動," + hSum);

          //深部静脈による熱移動
          hSum = tdv * bfdv * MultiNodeModel.BLD_SPECIFICHEAT;
          sWriter.WriteLine(nd.ToString() + "上流深部静脈への熱移動," + hSum);
          hSum = 0;
          MultiNodeModel.Node[] dn = MultiNodeModel.GetDownStreamNode(nd);
          foreach (MultiNodeModel.Node n in dn)
          {
            hSum += mn.GetTemperature(n, MultiNodeModel.Layer.DeepVein) 
              * mn.GetBloodFlow(n, MultiNodeModel.Layer.DeepVein) * MultiNodeModel.BLD_SPECIFICHEAT;
          }
          sWriter.WriteLine(nd.ToString() + "下流深部静脈からの熱移動," + hSum);

          //表在静脈による熱移動
          if ((nd & LIMBS) != 0 || nd == MultiNodeModel.Node.Pelvis)
          {
            hSum = tsv * bfsv * MultiNodeModel.BLD_SPECIFICHEAT;
            sWriter.WriteLine(nd.ToString() + "上流表在静脈への熱移動," + hSum);
            hSum = 0;
            foreach (MultiNodeModel.Node n in dn) hSum += mn.GetTemperature(n, MultiNodeModel.Layer.SuperficialVein) * mn.GetBloodFlow(n, MultiNodeModel.Layer.SuperficialVein) * MultiNodeModel.BLD_SPECIFICHEAT;
            sWriter.WriteLine(nd.ToString() + "下流表在静脈からの熱移動," + hSum);
          }
          else
          {
            sWriter.WriteLine(nd.ToString() + "上流表在静脈への熱移動,0");
            sWriter.WriteLine(nd.ToString() + "下流表在静脈からの熱移動,0");
          }

          sWriter.WriteLine();
        }
        sWriter.WriteLine("呼吸による熱移動," + mn.HeatLossByBreathing);
        sWriter.WriteLine("中央血液溜まりの温度," + mn.CentralBloodTemperature);
      }
    }

    private static void MultiNodeModelTest(double operatingTemperature)
    {
      //人体モデル作成
      MultiNodeModel mn = new MultiNodeModel();
      mn.InitializeTemperature(35);
      mn.UpdateBoundary(0, operatingTemperature, operatingTemperature, 50);

      //四肢部位
      const MultiNodeModel.Node LIMBS =
        MultiNodeModel.Node.LeftHand | MultiNodeModel.Node.RightHand |
        MultiNodeModel.Node.LeftFoot | MultiNodeModel.Node.RightFoot |
        MultiNodeModel.Node.LeftShoulder | MultiNodeModel.Node.RightShoulder |
        MultiNodeModel.Node.LeftArm | MultiNodeModel.Node.RightArm |
        MultiNodeModel.Node.LeftThigh | MultiNodeModel.Node.RightThigh |
        MultiNodeModel.Node.LeftLeg | MultiNodeModel.Node.RightLeg;

      using (StreamWriter sWriter =
        new StreamWriter("MultiNodeTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行
        sWriter.Write("中央血液溜まり,");
        foreach (MultiNodeModel.Node nd in Enum.GetValues(typeof(MultiNodeModel.Node)))
          sWriter.Write(nd.ToString() + "核,筋肉,脂肪,皮膚,動脈,静脈,表在静脈,");
        sWriter.WriteLine();

        //時系列データ書き出し
        for (int i = 0; i < 600; i++)
        {
          sWriter.Write(mn.CentralBloodTemperature + ",");
          foreach (MultiNodeModel.Node nd in Enum.GetValues(typeof(MultiNodeModel.Node)))
          {
            sWriter.Write(mn.GetTemperature(nd, MultiNodeModel.Layer.Core) + ",");
            sWriter.Write(mn.GetTemperature(nd, MultiNodeModel.Layer.Muscle) + ",");
            sWriter.Write(mn.GetTemperature(nd, MultiNodeModel.Layer.Fat) + ",");
            sWriter.Write(mn.GetTemperature(nd, MultiNodeModel.Layer.Skin) + ",");
            sWriter.Write(mn.GetTemperature(nd, MultiNodeModel.Layer.Artery) + ",");
            sWriter.Write(mn.GetTemperature(nd, MultiNodeModel.Layer.DeepVein) + ",");
            if ((nd & LIMBS) == 0) sWriter.Write("0,");
            else sWriter.Write
              (mn.GetTemperature(nd, MultiNodeModel.Layer.SuperficialVein) + ",");
          }
          sWriter.WriteLine("");
          //状態更新
          mn.Update(60);
        }
      }
    }

    private static void MultiNodeModelTest3()
    {
      //人体モデル作成
      MultiNodeModel mn = new MultiNodeModel();
      mn.InitializeTemperature(35);

      //四肢部位
      const MultiNodeModel.Node LIMBS =
        MultiNodeModel.Node.LeftHand | MultiNodeModel.Node.RightHand |
        MultiNodeModel.Node.LeftFoot | MultiNodeModel.Node.RightFoot |
        MultiNodeModel.Node.LeftShoulder | MultiNodeModel.Node.RightShoulder |
        MultiNodeModel.Node.LeftArm | MultiNodeModel.Node.RightArm |
        MultiNodeModel.Node.LeftThigh | MultiNodeModel.Node.RightThigh |
        MultiNodeModel.Node.LeftLeg | MultiNodeModel.Node.RightLeg;

      using (StreamWriter sWriter =
        new StreamWriter("MultiNodeTest3.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行
        sWriter.Write("中央血液溜まり,");
        foreach (MultiNodeModel.Node nd in Enum.GetValues(typeof(MultiNodeModel.Node)))
          sWriter.Write(nd.ToString() + "核,筋肉,脂肪,皮膚,動脈,静脈,表在静脈,");
        sWriter.WriteLine();

        //時系列データ書き出し
        mn.UpdateBoundary(0, 15, 15, 50);
        for (int i = 0; i < 600; i++)
        {
          if (i == 300) mn.UpdateBoundary(0, 35, 35, 50);
          sWriter.Write(mn.CentralBloodTemperature + ",");
          foreach (MultiNodeModel.Node nd in Enum.GetValues(typeof(MultiNodeModel.Node)))
          {
            sWriter.Write(mn.GetTemperature(nd, MultiNodeModel.Layer.Core) + ",");
            sWriter.Write(mn.GetTemperature(nd, MultiNodeModel.Layer.Muscle) + ",");
            sWriter.Write(mn.GetTemperature(nd, MultiNodeModel.Layer.Fat) + ",");
            sWriter.Write(mn.GetTemperature(nd, MultiNodeModel.Layer.Skin) + ",");
            sWriter.Write(mn.GetTemperature(nd, MultiNodeModel.Layer.Artery) + ",");
            sWriter.Write(mn.GetTemperature(nd, MultiNodeModel.Layer.DeepVein) + ",");
            if ((nd & LIMBS) == 0) sWriter.Write("0,");
            else sWriter.Write
              (mn.GetTemperature(nd, MultiNodeModel.Layer.SuperficialVein) + ",");
          }
          sWriter.WriteLine("");
          //状態更新
          mn.Update(60);
        }
      }
    }

    #endregion

    #region プレートフィン型熱交換器テスト

    /// <summary>簡易モデルで感度解析を行う</summary>
    private static void PlateFinHeatExchangerTest1()
    {
      //モデルパラメータ
      double kd, kw;  //熱貫流率
      double sArea;   //伝熱面積

      //出力
      double outletAirTemperature;
      double outletAirHumidity;
      double outletWaterTemperature;
      double dryRate;

      //定格条件と能力
      const double inletAirTemperature = 32;          //C
      const double inletAirHumidityRatio = 0.0125;    //kg/kg
      const double borderRelativeHumidity = 90;       //%
      const double inletWaterTemperature = 5;         //C
      const double heatExchange = 70;                 //kW
      const double waterFlowRate = 300d / 60;         //kg/s
      const double airFlowRate = 6750d * 1.2 / 3600;  //kg/s

      //簡易モデルの計算////////////////////////////////////////////////
      double velocity = 2.5;
      double waterSpeed = 1.5;
      //熱貫流率の計算
      CrossFinHeatExchanger.GetHeatTransferCoefficient(waterSpeed, velocity, out kd, out kw);
      //伝熱面積の計算
      sArea = CrossFinHeatExchanger.GetSurfaceArea
        (inletAirTemperature, inletAirHumidityRatio, borderRelativeHumidity,
        inletWaterTemperature, airFlowRate, waterFlowRate, heatExchange, kd, kw);
      //感度解析1（入口水温に対する出口状態の変化）
      Console.WriteLine("簡易モデル（水温変化）");
      Console.WriteLine("入口水温[C], 出口空気温度[C], 出口水温[C], 熱交換量[kW]");
      for (int i = 0; i < 10; i++)
      {
        double iwt = 3 + 0.5 * i;
        //簡易モデルでは温度変化によって熱貫流率は変わらない
        CrossFinHeatExchanger.GetOutletState
          (inletAirTemperature, inletAirHumidityRatio, borderRelativeHumidity, iwt,
          airFlowRate, waterFlowRate, kd, kw, sArea, out outletAirTemperature,
          out outletAirHumidity, out outletWaterTemperature, out dryRate);
        //熱量計算[kW]
        double hl = (outletWaterTemperature - iwt) * 4.186 * waterFlowRate;
        //書き出し処理
        Console.WriteLine(iwt.ToString("F2") + ", " + outletAirTemperature.ToString("F2") + ", " +
          outletWaterTemperature.ToString("F2") + ", " + hl.ToString("F2"));
      }
      //感度解析2（空気温度設定値に対する必要水量の変化）
      Console.WriteLine();
      Console.WriteLine("簡易モデル（空気温度設定値変化）");
      Console.WriteLine("空気温度設定値[kW], 出口空気温度[C], 水量[L/min], 熱交換量[kW]");
      for (int i = 0; i < 10; i++)
      {
        double oats = 12 + 0.5 * i;

        //必要水量[L/min]の計算
        double wf = CrossFinHeatExchanger.GetWaterFlowRate
          (inletAirTemperature, inletAirHumidityRatio, borderRelativeHumidity, inletWaterTemperature,
          velocity, waterSpeed, airFlowRate, waterFlowRate, waterFlowRate, sArea, oats);
        //熱貫流率の計算
        CrossFinHeatExchanger.GetHeatTransferCoefficient
          (waterSpeed * (wf / waterFlowRate), velocity, out kd, out kw);
        //出口状態の計算
        CrossFinHeatExchanger.GetOutletState
          (inletAirTemperature, inletAirHumidityRatio, borderRelativeHumidity,
          inletWaterTemperature, airFlowRate, wf, kd, kw, sArea, out outletAirTemperature,
          out outletAirHumidity, out outletWaterTemperature, out dryRate);
        //熱量計算[kW]
        double hl = (outletWaterTemperature - inletWaterTemperature) * 4.186 * wf;
        //書き出し処理
        Console.WriteLine(oats.ToString("F2") + ", " + outletAirTemperature.ToString("F2") + ", " +
          (wf * 60).ToString("F2") + ", " + hl.ToString("F2"));
      }
    }

    /// <summary>詳細モデルで感度解析を行う</summary>
    private static void PlateFinHeatExchangerTest2()
    {
      //定格条件・能力等
      const double thermalConductivity = 237;     //熱伝導率[W/(mK)]
      const double inletAirTemperature = 32;      //C
      const double inletAirHumidityRatio = 0.0125;//kg/kg
      const double borderRelativeHumidity = 90;   //%
      const double inletWaterTemperature = 5;     //C
      const double waterFlowRate = 300d / 60;     //kg/s
      const double airFlowRate = 6750d * 1.2 / 3600; //kg/s
      double[] cap = new double[] { 52, 70, 79 }; //kW

      //形状
      const double width = 1.0;             //m
      const double height = 0.75;           //m
      const int columnNumber = 20;          //段
      const double finPitch = 0.0029;       //m
      const double finThickness = 0.0002;   //m
      const double innerDiameter = 0.0146;  //m
      const double outerDiameter = 0.0158;  //m

      //プレート熱交換器をインスタンス化
      CrossFinHeatExchanger[] pl = new CrossFinHeatExchanger[3];
      for (int i = 0; i < 3; i++)
      {
        int rNum = 4 + i * 2;
        double depth = rNum * 0.0329;
        pl[i] = new CrossFinHeatExchanger
          (depth, width, height, rNum, columnNumber, finPitch, finThickness, thermalConductivity, 
          innerDiameter, outerDiameter, airFlowRate, inletAirTemperature, inletAirHumidityRatio,
          borderRelativeHumidity, waterFlowRate, waterFlowRate, inletWaterTemperature,
          CrossFinHeatExchanger.WaterFlowType.SingleFlow, cap[i], true);
      }

      Console.WriteLine("水量[L/min], 熱交換量(4列)[kW], 出口温度(4列)[C]," +
        "熱交換量(6列)[kW], 出口温度(6列)[C],熱交換量(8列)[kW], 出口温度(8列)[C]");
      for (int i = 0; i <= 30; i++)
      {
        //水量[L/min]を計算
        double wf = 10 * i;
        Console.Write(wf.ToString("F1"));
        //出口状態を更新して書き出し
        for (int j = 0; j < 3; j++)
        {
          pl[j].UpdateOutletState
            (inletAirTemperature, inletAirHumidityRatio, inletWaterTemperature, airFlowRate, wf / 60d);
          Console.Write(", " + pl[j].HeatTransfer + ", " + pl[j].OutletAirTemperature);
        }
        Console.WriteLine();
      }
    }

    /// <summary>詳細モデルで感度解析を行う2</summary>
    private static void PlateFinHeatExchangerTest3()
    {
      //モデルパラメータ
      double kd, kw;  //熱貫流率
      double sArea;   //伝熱面積
      double thermalConductivity = 220; //熱伝導率[W/(mK)]

      //出力
      double outletAirTemperature;
      double outletAirHumidity;
      double outletWaterTemperature;
      double dryRate;

      //定格条件と能力
      const double inletAirTemperature = 32;      //C
      const double inletAirHumidityRatio = 0.0125;//kg/kg
      const double borderRelativeHumidity = 90;   //%
      const double inletWaterTemperature = 5;     //C
      const double heatExchange = 70;             //kW
      const double waterFlowRate = 300d / 60;     //kg/s
      const double airFlowRate = 6750d * 1.2 / 3600; //kg/s

      //形状
      const double depth = 0.197;           //m
      const double width = 1.0;             //m
      const double height = 0.75;           //m
      const int rowNumber = 6;              //列
      const int columnNumber = 20;          //段
      const double finPitch = 0.0029;       //m
      const double finThickness = 0.0002;   //m
      const double innerDiameter = 0.0146;  //m
      const double outerDiameter = 0.0158;  //m

      //幾何学形状の計算
      double airWaterSurfaceRatio, coreArea, equivalentFinRadius,
        equivalentDiameter, waterPath, airSurfaceArea;
      waterPath = columnNumber * 1;
      CrossFinHeatExchanger.GetGeometricCompfigulation
        (depth, width, height, rowNumber, columnNumber, finPitch, finThickness,
        innerDiameter, outerDiameter, out airWaterSurfaceRatio, out coreArea,
        out equivalentFinRadius, out equivalentDiameter, out airSurfaceArea);

      //熱貫流率の計算
      CrossFinHeatExchanger.GetHeatTransferCoefficient
        (airWaterSurfaceRatio, coreArea, equivalentFinRadius, equivalentDiameter,
        waterPath, finThickness, thermalConductivity, innerDiameter, outerDiameter,
        airFlowRate, inletAirTemperature, inletAirHumidityRatio,
        borderRelativeHumidity, waterFlowRate, inletWaterTemperature, out kd, out kw);
      //伝熱面積の計算
      sArea = CrossFinHeatExchanger.GetSurfaceArea(
        inletAirTemperature, inletAirHumidityRatio, borderRelativeHumidity,
        inletWaterTemperature, airFlowRate, waterFlowRate, heatExchange, kd, kw);
      //感度解析1（入口水温に対する出口状態の変化）
      Console.WriteLine("詳細モデル（水温変化）");
      Console.WriteLine("入口水温[C], 出口空気温度[C], 出口水温[C], 熱交換量[kW]");
      for (int i = 0; i < 10; i++)
      {
        double iwt = 3 + 0.5 * i;
        //熱貫流率の計算
        CrossFinHeatExchanger.GetHeatTransferCoefficient
          (airWaterSurfaceRatio, coreArea, equivalentFinRadius, equivalentDiameter,
          waterPath, finThickness, thermalConductivity, innerDiameter, outerDiameter,
          airFlowRate, inletAirTemperature, inletAirHumidityRatio,
          borderRelativeHumidity, waterFlowRate, iwt, out kd, out kw);
        //出口状態の計算
        CrossFinHeatExchanger.GetOutletState
          (inletAirTemperature, inletAirHumidityRatio, borderRelativeHumidity, iwt,
          airFlowRate, waterFlowRate, kd, kw, sArea, out outletAirTemperature,
          out outletAirHumidity, out outletWaterTemperature, out dryRate);
        //熱量計算[kW]
        double hl = (outletWaterTemperature - iwt) * 4.186 * waterFlowRate;
        //書き出し処理
        Console.WriteLine(iwt.ToString("F1") + ", " +
          outletAirTemperature.ToString("F1") + ", " +
          outletWaterTemperature.ToString("F1") + ", " + hl.ToString("F1"));
      }
      //感度解析2（空気温度設定値に対する必要水量の変化）
      Console.WriteLine();
      Console.WriteLine("詳細モデル（空気温度設定値変化）");
      Console.WriteLine("空気温度設定値[kW], 出口空気温度[C], 水量[L/min], 熱交換量[kW]");
      for (int i = 0; i < 10; i++)
      {
        double oats = 12 + 0.5 * i;

        //必要水量[L/min]の計算
        double wf = CrossFinHeatExchanger.GetWaterFlowRate
          (airWaterSurfaceRatio, coreArea, equivalentFinRadius, equivalentDiameter,
          waterPath, finThickness, thermalConductivity, innerDiameter, outerDiameter,
          airFlowRate, inletAirTemperature, inletAirHumidityRatio,
          borderRelativeHumidity, waterFlowRate, inletWaterTemperature,
          waterFlowRate, sArea, oats);
        //熱貫流率の計算
        CrossFinHeatExchanger.GetHeatTransferCoefficient
          (airWaterSurfaceRatio, coreArea, equivalentFinRadius, equivalentDiameter,
          waterPath, finThickness, thermalConductivity, innerDiameter, outerDiameter,
          airFlowRate, inletAirTemperature, inletAirHumidityRatio,
          borderRelativeHumidity, wf, inletWaterTemperature, out kd, out kw);
        //出口状態の計算
        CrossFinHeatExchanger.GetOutletState
          (inletAirTemperature, inletAirHumidityRatio, borderRelativeHumidity,
          inletWaterTemperature, airFlowRate, wf, kd, kw, sArea,
          out outletAirTemperature, out outletAirHumidity,
          out outletWaterTemperature, out dryRate);
        //熱量計算[kW]
        double hl = (outletWaterTemperature - inletWaterTemperature) * 4.186 * wf;
        //書き出し処理
        Console.WriteLine(oats.ToString("F1") + ", " +
          outletAirTemperature.ToString("F1") + ", " +
          (wf * 60).ToString("F1") + ", " + hl.ToString("F1"));
      }
    }

    /// <summary>詳細モデルで感度解析を行う3</summary>
    private static void PlateFinHeatExchangerTest4()
    {
      CrossFinHeatExchanger phex1 = new CrossFinHeatExchanger(3600d * 1.2 / 3600 * 0.75 * 2.5, 3, 32, 0.0125, 95, 300d / 60, 1.5, 300d / 60, 5, 70);
      CrossFinHeatExchanger phex2 = new CrossFinHeatExchanger(0.197, 1.0, 0.75, 6, 20, 0.0029, 0.0002, 220, 0.0146, 0.0158, 1.0 * 0.75 * 3600 * 2.5 * 1.2 / 3600,
          32, 0.0125, 95, 300d / 60, 300d / 60, 5, CrossFinHeatExchanger.WaterFlowType.SingleFlow, 70, true);
      for (int i = 0; i < 6; i++)
      {
        double afl = 300 - i * 50;
        phex1.UpdateOutletState(32, 0.0125, 5, 3600 * 0.75 * 2.5 * 1.2 / 3600, afl / 60d);
        phex2.UpdateOutletState(32, 0.0125, 5, 3600 * 0.75 * 2.5 * 1.2 / 3600, afl / 60d);
        Console.WriteLine(afl + ", " + phex1.OutletAirTemperature.ToString("F1") + ", " + phex2.OutletAirTemperature.ToString("F1"));
      }
      phex1.ControlOutletAirTemperature(32, 0.0125, 5, 3600 * 0.75 * 2.5 * 1.2 / 3600, 19);
      phex2.ControlOutletAirTemperature(32, 0.0125, 5, 3600 * 0.75 * 2.5 * 1.2 / 3600, 19);
    }

    /// <summary>詳細モデルで感度解析を行う4</summary>
    private static void PlateFinHeatExchangerTest5()
    {
      double[] af = new double[] { 0.01, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0, 1.5, 2.0, 2.5, 3.0, 3.5, 4.0, 4.5, 5.0 };

      for (int i = 0; i < af.Length; i++)
      {
        double vel = af[i];
        double kd, kw;
        CrossFinHeatExchanger.GetHeatTransferCoefficient(0.2, vel, out kd, out kw);
        Console.Write(kd.ToString("F1") + ",");
        CrossFinHeatExchanger.GetHeatTransferCoefficient(0.3, vel, out kd, out kw);
        Console.Write(kd.ToString("F1") + ",");
        CrossFinHeatExchanger.GetHeatTransferCoefficient(0.4, vel, out kd, out kw);
        Console.Write(kd.ToString("F1") + ",");
        CrossFinHeatExchanger.GetHeatTransferCoefficient(0.5, vel, out kd, out kw);
        Console.Write(kd.ToString("F1") + ",");
        CrossFinHeatExchanger.GetHeatTransferCoefficient(0.6, vel, out kd, out kw);
        Console.Write(kd.ToString("F1") + ",");
        CrossFinHeatExchanger.GetHeatTransferCoefficient(0.7, vel, out kd, out kw);
        Console.Write(kd.ToString("F1") + ",");
        CrossFinHeatExchanger.GetHeatTransferCoefficient(0.8, vel, out kd, out kw);
        Console.Write(kd.ToString("F1") + ",");
        CrossFinHeatExchanger.GetHeatTransferCoefficient(1.0, vel, out kd, out kw);
        Console.Write(kd.ToString("F1") + ",");
        CrossFinHeatExchanger.GetHeatTransferCoefficient(1.2, vel, out kd, out kw);
        Console.Write(kd.ToString("F1") + ",");
        CrossFinHeatExchanger.GetHeatTransferCoefficient(1.5, vel, out kd, out kw);
        Console.Write(kd.ToString("F1") + ",");
        CrossFinHeatExchanger.GetHeatTransferCoefficient(2.0, vel, out kd, out kw);
        Console.WriteLine(kd.ToString("F1") + ",");
      }
    }

    #region 冷媒コイル

    /// <summary>冷却・除湿・着霜コイルの感度解析を行う</summary>
    private static void CrossFinEvaporatorTest()
    {
      //蒸発器初期化
      double hr = MoistAir.GetHumidityRatioFromDryBulbTemperatureAndWetBulbTemperature(7, 6, 101.325);
      CrossFinEvaporator evp = new CrossFinEvaporator(2, 13, 167.0 / 60 * 1.2, 7, hr, 95);

      using (StreamWriter sWriter = new StreamWriter
        ("CrossFinEvaporatorTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //乾球温度・蒸発温度・能力の関係
        double[] te = new double[] { -18, -13, -8, -3, 2, 7 };
        sWriter.WriteLine("乾球温度・蒸発温度・能力の関係");
        sWriter.Write("乾球温度[C]");
        for (int i = 0; i < te.Length; i++)
          sWriter.Write("," + te[i] + "C 交換熱量," + te[i] + "C 除霜," + te[i] + "C 出口温度");
        sWriter.WriteLine();

        for (int i = -15; i <= 15; i++)
        {
          sWriter.Write(i);
          for (int j = 0; j < te.Length; j++)
          {
            hr = MoistAir.GetHumidityRatioFromDryBulbTemperatureAndRelativeHumidity(i, 85, 101.325);
            sWriter.Write("," + evp.GetHeatTransfer(te[j], evp.NominalAirFlowRate, i, hr));
            sWriter.Write("," + evp.DefrostLoad + "," + evp.OutletAirTemperature);
          }
          sWriter.WriteLine();
        }

        sWriter.WriteLine();
        //乾球温度・相対湿度・能力の関係
        double[] rh = new double[] { 50, 60, 70, 80, 90, 100 };
        sWriter.WriteLine("乾球温度・蒸発温度・能力の関係");
        sWriter.Write("乾球温度[C]");
        for (int i = 0; i < rh.Length; i++)
          sWriter.Write("," + rh[i] + "% 交換熱量," + rh[i] + "% 除霜," + rh[i] + "% 出口温度");
        sWriter.WriteLine();

        for (int i = -5; i <= 15; i++)
        {
          sWriter.Write(i);
          for (int j = 0; j < rh.Length; j++)
          {
            hr = MoistAir.GetHumidityRatioFromDryBulbTemperatureAndRelativeHumidity(i, rh[j], 101.325);
            sWriter.Write("," + evp.GetHeatTransfer(-10, evp.NominalAirFlowRate, i, hr));
            sWriter.Write("," + evp.DefrostLoad + "," + evp.OutletAirTemperature);
          }
          sWriter.WriteLine();
        }
      }
    }

    /// <summary>冷却・除湿・着霜コイルの感度解析を行う2</summary>
    private static void CrossFinEvaporatorTest2()
    {
      //蒸発器初期化
      double hr = MoistAir.GetHumidityRatioFromDryBulbTemperatureAndWetBulbTemperature
        (7, 6, 101.325);
      CrossFinEvaporator evp = new CrossFinEvaporator
        (2, 13, 167.0 / 60 * 1.2, 7, hr, 95);

      using (StreamWriter sWriter = new StreamWriter
        ("CrossFinEvaporatorTest2.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //乾球温度・蒸発温度・能力の関係
        double[] qe = new double[] { 11, 12, 13, 14, 15, 16 };
        sWriter.WriteLine("乾球温度・蒸発温度・能力の関係");
        sWriter.Write("乾球温度[C]");
        for (int i = 0; i < qe.Length; i++)
          sWriter.Write("," + qe[i] + "kW 蒸発温度," + qe[i] + "kW 除霜," + qe[i] + "kW 出口温度");
        sWriter.WriteLine();

        for (int i = -15; i <= 15; i++)
        {
          sWriter.Write(i);
          for (int j = 0; j < qe.Length; j++)
          {
            hr = MoistAir.GetHumidityRatioFromDryBulbTemperatureAndRelativeHumidity(i, 85, 101.325);
            sWriter.Write("," + evp.GetEvaporatingTemperature(qe[j], evp.NominalAirFlowRate, i, hr, false));
            sWriter.Write("," + evp.DefrostLoad);
            sWriter.Write("," + evp.OutletAirTemperature);
          }
          sWriter.WriteLine();
        }
      }
    }

    /// <summary>水噴霧形凝縮器の感度解析を行う</summary>
    private static void CrossFinCondensorTest()
    {
      //凝縮器初期化
      double hr = MoistAir.GetHumidityRatioFromDryBulbTemperatureAndRelativeHumidity(35, 55, 101.325);
      CrossFinCondensor cnd = new CrossFinCondensor(45, 25, 167d / 60 * 1.2, 35, hr);
      cnd.SprayEffectiveness = 0;

      using (StreamWriter sWriter = new StreamWriter
        ("CrossFinCondenserTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //乾球温度・凝縮温度・能力の関係
        double[] rh = new double[] { 35, 55, 75 };
        sWriter.WriteLine("乾球温度・凝縮温度・能力の関係");
        sWriter.Write("乾球温度[C]");
        for (int i = 0; i < rh.Length; i++)
          sWriter.Write("," + rh[i] + "% 交換熱量1," + rh[i] + "% 交換熱量2," + rh[i] + "% 水噴霧");
        sWriter.WriteLine();

        for (int i = 20; i <= 40; i++)
        {
          sWriter.Write(i);
          for (int j = 0; j < rh.Length; j++)
          {
            hr = MoistAir.GetHumidityRatioFromDryBulbTemperatureAndRelativeHumidity(i, rh[j], 101.325);
            cnd.SprayEffectiveness = 0.0;
            sWriter.Write("," + cnd.GetHeatTransfer(45, cnd.NominalAirFlowRate, i, hr));
            cnd.SprayEffectiveness = 0.6;
            sWriter.Write("," + cnd.GetHeatTransfer(45, cnd.NominalAirFlowRate, i, hr));
            sWriter.Write("," + cnd.WaterSupply * 3600);
          }
          sWriter.WriteLine();
        }
      }
    }

    #endregion

    #endregion

    #region 全熱交換器テスト

    private static void RotaryRegeneratorTest()
    {
      RotaryRegenerator rg = new RotaryRegenerator(0.72, 2.15, 0.4, 210, 10000, 8000, true, 35, 0.0195, 26, 0.0105, 0.4);
      using (StreamWriter sWriter = new StreamWriter
        ("RotaryRegenerator.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行
        //流量変更
        for (int i = 0; i <= 10; i++) sWriter.Write("," + (100 - 5 * i) + "%");
        sWriter.WriteLine();

        //回転数変更
        for (int i = 0; i <= 10; i++)
        {
          sWriter.Write((100 - 5 * i) + "%, ");
          double rotatingRate = 1 - 0.05 * i;
          //流量変更
          for (int j = 0; j <= 10; j++)
          {
            double oaf = 10000 * (1 - 0.05 * j);
            rg.UpdateState(oaf, 8000, rotatingRate, 35, 0.0195, 26, 0.0105);
            sWriter.Write(rg.Efficiency.ToString("F3") + ", ");
          }
          sWriter.WriteLine();
        }
      }
    }

    private static void RotaryRegeneratorTest2()
    {
      RotaryRegenerator rg = new RotaryRegenerator
        (0.72, 2.15, 0.4, 210, 10000, 8000, true, 35, 0.0195, 26, 0.0105, 0.4);
      using (StreamWriter sWriter = new StreamWriter
        ("RotaryRegenerator2.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行
        sWriter.WriteLine("外気温度, 外気湿度, 外気比エンタルピー, 成行温度, 成行湿度, 成行比エンタルピー, 制御温度, 制御湿度, 制御比エンタルピー, 消費電力");

        //外気温度変更
        for (int i = 0; i <= 15; i++)
        {
          double dbt = 15 + i;
          double hrt = 0.0045 + 0.001 * i;
          double ent = MoistAir.GetEnthalpyFromDryBulbTemperatureAndHumidityRatio(dbt, hrt);
          sWriter.Write(dbt + "," + hrt + "," + ent);
          rg.UpdateState(10000, 8000, 1.0, dbt, hrt, 26, 0.0105);
          ent = MoistAir.GetEnthalpyFromDryBulbTemperatureAndHumidityRatio
            (rg.SupplyAirOutletDrybulbTemperature, rg.SupplyAirOutletHumidityRatio);
          sWriter.Write(", " + rg.SupplyAirOutletDrybulbTemperature);
          sWriter.Write(", " + rg.SupplyAirOutletHumidityRatio);
          sWriter.Write(", " + ent);
          //rg.ControlOutletTemperature(10000, 8000, 1.0, dbt, hrt, 26, 0.0105, 24);
          //rg.ControlOutletHumidity(10000, 8000, 1.0, dbt, hrt, 26, 0.0105, 0.0135);
          rg.ControlOutletEnthalpy(10000, 8000, 1.0, dbt, hrt, 26, 0.0105, 45);
          ent = MoistAir.GetEnthalpyFromDryBulbTemperatureAndHumidityRatio
            (rg.SupplyAirOutletDrybulbTemperature, rg.SupplyAirOutletHumidityRatio);
          sWriter.Write(", "
            + rg.SupplyAirOutletDrybulbTemperature + ", "
            + rg.SupplyAirOutletHumidityRatio + ", " + ent + ","
            + rg.Electricity);

          sWriter.WriteLine();
        }
      }
    }

    private static void AirToAirFlatPlateHeatExchangerTest()
    {
      //初期化処理
      AirToAirFlatPlateHeatExchanger aHex = new AirToAirFlatPlateHeatExchanger
        (150, 150, 34.5, 0.0263, 26.5, 0.014, 0.74, 0.67,
        AirToAirFlatPlateHeatExchanger.AirFlow.CrossFlow, true);

      using (StreamWriter sWriter = new StreamWriter
        ("AToAFlatPlateHeatExchanger.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        //タイトル行
        //流量変更
        for (int i = 0; i <= 7; i++)
          sWriter.Write("," + (150 - (10 * i)));
        sWriter.WriteLine();

        for (int i = 0; i <= 7; i++)
        {
          //排気風量を変更（50%～100%）
          double afEA = (150 - (10 * i));
          sWriter.Write(afEA.ToString());
          for (int j = 0; j <= 7; j++)
          {            
            //給気風量を変更（50%～100%）
            double afSA = (150 - (10 * j));
            aHex.UpdateState(afSA, afEA, 34.5, 0.0263, 26.5, 0.014);
            //書き出し処理
            sWriter.Write(", " + aHex.LatentEfficiency.ToString("F3"));
          }
          sWriter.WriteLine();
        }
      }
    }

    #endregion

    #region 流体機械テスト

    private static void CentrifugalPumpTest()
    {
      CentrifugalPump p1 = new CentrifugalPump
        (260, 0.03, 250, 0.03, CentrifugalPump.ControlMethod.ConstantPressureWithBypass, 40);
      CentrifugalPump p2 = new CentrifugalPump
        (260, 0.03, 250, 0.03, CentrifugalPump.ControlMethod.ConstantPressureWithInverter, 40);
      CentrifugalPump p3 = new CentrifugalPump
        (260, 0.03, 250, 0.03, CentrifugalPump.ControlMethod.MinimumPressure, 40);
      PumpSystem[] pss = new PumpSystem[3];
      pss[0] = new PumpSystem(p1, 250, 0.09, 40, 3);
      pss[1] = new PumpSystem(p2, 250, 0.09, 40, 3);
      pss[2] = new PumpSystem(p3, 250, 0.09, 40, 3);

      using (StreamWriter sWriter =
          new StreamWriter("CentrifugalPumpTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        for (int i = 0; i < 216; i++)
        {
          double wf = (5400 - 25 * i) / 60d / 1000d;
          for (int j = 0; j < pss.Length; j++)
          {
            pss[j].TotalFlowRate = wf;
            pss[j].UpdateState();
          }

          sWriter.Write(wf * 60d * 1000);
          for (int j = 0; j < pss.Length; j++) sWriter.Write(", " + pss[j].GetElectricConsumption());
          for (int j = 0; j < pss.Length; j++) sWriter.Write(", " + pss[j].Pump.GetTotalEfficiency());
          for (int j = 0; j < pss.Length; j++) sWriter.Write(", " + pss[j].BypassFlowRate * (60 * 1000));
          sWriter.WriteLine();
        }
      }
    }

    private static void CentrifugalFanTest()
    {
      double nf = 13500d / 3600;
      double df = 13000d / 3600;
      CentrifugalFan f1 = new CentrifugalFan(0.55, nf, 0.53, df, 4, false);
      CentrifugalFan f2 = new CentrifugalFan(0.55, nf, 0.53, df, 4, true);

      using (StreamWriter sWriter =
          new StreamWriter("CentrifugalFanTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        for (int i = 0; i < 100; i++)
        {
          double vf = (13000 - 130 * i) / 3600d;
          f1.UpdateState(vf);
          f2.UpdateState(vf);
          sWriter.WriteLine(vf * 3600d +
            ", " + f1.GetElectricConsumption() + ", " + f2.GetElectricConsumption() +
            ", " + f1.GetTotalEfficiency() + ", " + f2.GetTotalEfficiency());
        }
      }
    }

    #endregion

    #region ビルマルテスト

    private static void GEHPTest1()
    {
      //凝縮・蒸発温度
      const double CND_TEMP = 50;
      const double EVP_TEMP = 2;

      //初期化:45kW級GHP+4.5kW室内機10台×2セット
      IndoorUnit[] iU1 = new IndoorUnit[10];
      IndoorUnit[] iU2 = new IndoorUnit[10];
      for (int i = 0; i < iU1.Length; i++)
      {
        iU1[i] = new IndoorUnit(EVP_TEMP, CND_TEMP, 4.5, 5.0, 0.0048, 95, true);
        iU2[i] = new IndoorUnit(EVP_TEMP, CND_TEMP, 4.5, 5.0, 0.0048, 95, true);
      }
      GasEngineHeatPump ghp1 = new GasEngineHeatPump(EVP_TEMP, CND_TEMP, 32.8, 34.2, 0.615, 0.615, 0.0, 95, 45.0, 50.0, iU1);
      GasEngineHeatPump ghp2 = new GasEngineHeatPump(EVP_TEMP, CND_TEMP, 32.8, 34.2, 0.615, 0.615, 0.0, 95, 45.0, 50.0, iU2);

      using (StreamWriter sWriter = new StreamWriter
        ("GEHPTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        sWriter.WriteLine("暖房負荷率とガス消費量の関係");
        sWriter.WriteLine("負荷率, ガス消費量（均等負荷率）,ガス消費量（1台100%負荷）, 圧縮比（均等負荷率）,圧縮比（1台100%負荷）");
        ghp1.OutdoorAir = ghp2.OutdoorAir = new MoistAir(7, 0.0055);
        ImmutableMoistAir ima = new MoistAir(20, 0.0072);
        for (int i = 0; i < iU1.Length; i++)
        {
          iU1[i].IsOperating = iU2[i].IsOperating = true;
          iU1[i].IsCooling = iU2[i].IsCooling = false;
          iU1[i].IndoorAir = iU2[i].IndoorAir = ima;
        }
        for (int i = 0; i < 13; i++)
        {
          double pl1 = 1 - i * 0.05;
          for (int j = 0; j < iU1.Length; j++) iU1[j].HeatLoad = 5.0 * pl1;
          double pl2 = 1 - (i * 0.05 * 10d / 9d);
          for (int j = 0; j < iU2.Length - 1; j++) iU2[j].HeatLoad = 5.0 * pl2;
          iU2[iU2.Length - 1].HeatLoad = 5.0;
          ghp1.Update();
          ghp2.Update();
          double cr1 = getCompressionRate(ghp1.EvaporatingTemperature, ghp1.CondensingTemperature);
          double cr2 = getCompressionRate(ghp2.EvaporatingTemperature, ghp2.CondensingTemperature);
          sWriter.WriteLine(pl1 + "," + ghp1.GasConsumption + "," + ghp2.GasConsumption + "," + cr1 + "," + cr2);
        }

        sWriter.WriteLine("冷房負荷率とガス消費量の関係");
        sWriter.WriteLine("負荷率, ガス消費量（均等負荷率）,ガス消費量（1台100%負荷）, 圧縮比（均等負荷率）,圧縮比（1台100%負荷）");
        ghp1.OutdoorAir = ghp2.OutdoorAir = new MoistAir(35, 0.0195);
        ima = new MoistAir(27, 0.011);
        for (int i = 0; i < iU1.Length; i++)
        {
          iU1[i].IsOperating = iU2[i].IsOperating = true;
          iU1[i].IsCooling = iU2[i].IsCooling = true;
          iU1[i].IndoorAir = iU2[i].IndoorAir = ima;
        }
        for (int i = 0; i < 13; i++)
        {
          double pl1 = 1 - i * 0.05;
          for (int j = 0; j < iU1.Length; j++) iU1[j].HeatLoad = -4.5 * pl1;
          double pl2 = 1 - (i * 0.05 * 10d / 9d);
          for (int j = 0; j < iU2.Length - 1; j++) iU2[j].HeatLoad = -4.5 * pl2;
          iU2[iU2.Length - 1].HeatLoad = -4.5;
          ghp1.Update();
          ghp2.Update();
          double cr1 = getCompressionRate(ghp1.EvaporatingTemperature, ghp1.CondensingTemperature);
          double cr2 = getCompressionRate(ghp2.EvaporatingTemperature, ghp2.CondensingTemperature);
          sWriter.WriteLine(pl1 + "," + ghp1.GasConsumption + "," + ghp2.GasConsumption + "," + cr1 + "," + cr2);
        }
      }
    }

    private static void GEHPTest2()
    {
      //凝縮・蒸発温度
      const double CND_TEMP = 50;
      const double EVP_TEMP = 2;

      //初期化:45kW級GHP+4.5kW室内機12台
      IndoorUnit[] iU = new IndoorUnit[12];
      for (int i = 0; i < iU.Length; i++)
        iU[i] = new IndoorUnit(EVP_TEMP, CND_TEMP, 4.5, 5.0, 0.0048, 95, true);
      GasEngineHeatPump ghp = new GasEngineHeatPump(EVP_TEMP, CND_TEMP, 32.8, 34.2, 0.615, 0.615, 0.0, 95, 45.0, 50.0, iU);
      ghp.HasHeatRecoverySystem = false;

      using (StreamWriter sWriter = new StreamWriter
        ("GEHPTest2.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {
        ImmutableMoistAir ima = new MoistAir(20, 0.0072);
        for (int i = 0; i < iU.Length; i++)
        {
          iU[i].IsOperating = true;
          iU[i].IsCooling = false;
          iU[i].IndoorAir = ima;
          iU[i].HeatLoad = 5.0;
        }

        for (int i = 0; i < 14; i++)
        {
          double dbt = 5 - i * 0.5;
          double hr = MoistAir.GetHumidityRatioFromDryBulbTemperatureAndRelativeHumidity(dbt, 80, 101.325);
          ghp.OutdoorAir = new MoistAir(dbt, hr);
          ghp.Update();
          double load = iU.Length * 5.0;
          for (int j = 0; j < ghp.IndoorUnits.Length; j++)
            load -= ghp.IndoorUnits[j].OverLoad;
          sWriter.WriteLine(dbt + "," + ghp.AirHeatExchanger.DefrostLoad + "," + load);
        }        
      }
    }

    private static double getCompressionRate(double tEvp, double tCnd)
    {
      Refrigerant r410a = new Refrigerant(Refrigerant.Fluid.R410A);
      double dsl, dsv, pcnd, pevp;
      r410a.GetSaturatedPropertyFromTemperature(tEvp + 273.15, out dsl, out dsv, out pevp);
      r410a.GetSaturatedPropertyFromTemperature(tCnd + 273.15, out dsl, out dsv, out pcnd);
      return pcnd / pevp;
    }

    #endregion

    #region 大規模熱負荷計算テスト

    #region 建物熱負荷計算モデル作成処理

    private static void largeHeatLoadTest()
    {
      BuildingThermalModel bModel = makeLargeBuilding();

      using (StreamWriter sWriter = new StreamWriter("heatLoadTestOut.csv", false, Encoding.GetEncoding("Shift_JIS")))
      using (StreamReader sReader = new StreamReader("bound.csv"))
      {
        DateTime dTime = new DateTime(1999, 1, 1, 0, 0, 0);
        Sun sun = new Sun(Sun.City.Tokyo);

        //ヘッダ
        sReader.ReadLine();
        for (int i = 0; i < bModel.MultiRoom.Length; i++)
          for (int j = 0; j < bModel.MultiRoom[i].ZoneNumber; j++)
            sWriter.Write("," + bModel.MultiRoom[i].Zones[j].Name + "乾球温度");
        for (int i = 0; i < bModel.MultiRoom.Length; i++)
          for (int j = 0; j < bModel.MultiRoom[i].ZoneNumber; j++)
            sWriter.Write("," + bModel.MultiRoom[i].Zones[j].Name + "絶対湿度");
        for (int i = 0; i < bModel.MultiRoom.Length; i++)
          for (int j = 0; j < bModel.MultiRoom[i].ZoneNumber; j++)
            sWriter.Write("," + bModel.MultiRoom[i].Zones[j].Name + "顕熱負荷");
        for (int i = 0; i < bModel.MultiRoom.Length; i++)
          for (int j = 0; j < bModel.MultiRoom[i].ZoneNumber; j++)
            sWriter.Write("," + bModel.MultiRoom[i].Zones[j].Name + "潜熱負荷");
        sWriter.WriteLine();

        for (int hour = 0; hour < 8760; hour++)
        {
          Console.WriteLine(dTime);

          string[] bf = sReader.ReadLine().Split(',');
          double dbt = double.Parse(bf[1]);
          double hrt = double.Parse(bf[2]);
          double dnr = double.Parse(bf[3]);
          double srd = double.Parse(bf[4]);
          double nrd = double.Parse(bf[5]);

          sun.Update(dTime);
          sun.SetGlobalHorizontalRadiation(srd, dnr);
          bModel.UpdateOutdoorCondition(dTime, sun, dbt, hrt, nrd);

          //空調設定
          if ((7 <= dTime.Hour && dTime.Hour < 21) && (dTime.DayOfWeek != DayOfWeek.Sunday && dTime.DayOfWeek != DayOfWeek.Saturday))
          {
            double dbtSet, hrtSet;
            if (12 <= dTime.Month || dTime.Month <= 3)
            {
              dbtSet = 22;
              hrtSet = MoistAir.GetHumidityRatioFromDryBulbTemperatureAndRelativeHumidity(22, 40, 101.325);
            }
            else if (6 <= dTime.Month && dTime.Month <= 9)
            {
              dbtSet = 26;
              hrtSet = MoistAir.GetHumidityRatioFromDryBulbTemperatureAndRelativeHumidity(26, 50, 101.325);
            }
            else
            {
              dbtSet = 24;
              hrtSet = MoistAir.GetHumidityRatioFromDryBulbTemperatureAndRelativeHumidity(24, 50, 101.325);
            }
            for (int fl = 0; fl < 7; fl++)
            {
              for (int i = 0; i < bModel.MultiRoom.Length; i++)
              {
                if ((i + 1) % 3 != 0)
                {
                  for (int j = 0; j < bModel.MultiRoom[i].ZoneNumber; j++)
                  {
                    bModel.ControlDrybulbTemperature(i, j, dbtSet);
                    bModel.ControlHumidityRatio(i, j, hrtSet);
                  }
                }
              }
            }
          }
          else
          {
            for (int i = 0; i < bModel.MultiRoom.Length; i++)
            {
              for (int j = 0; j < bModel.MultiRoom[i].ZoneNumber; j++)
              {
                bModel.ControlHeatSupply(i, j, 0);
                bModel.ControlWaterSupply(i, j, 0);
              }
            }
          }

          bModel.ForecastHeatTransfer();
          bModel.ForecastWaterTransfer();
          bModel.FixState();

          //書き出し
          sWriter.Write(dTime);
          for (int i = 0; i < bModel.MultiRoom.Length; i++)
            for (int j = 0; j < bModel.MultiRoom[i].ZoneNumber; j++)
              sWriter.Write("," + bModel.MultiRoom[i].Zones[j].Temperature);
          for (int i = 0; i < bModel.MultiRoom.Length; i++)
            for (int j = 0; j < bModel.MultiRoom[i].ZoneNumber; j++)
              sWriter.Write("," + bModel.MultiRoom[i].Zones[j].HumidityRatio);
          for (int i = 0; i < bModel.MultiRoom.Length; i++)
            for (int j = 0; j < bModel.MultiRoom[i].ZoneNumber; j++)
              sWriter.Write("," + bModel.MultiRoom[i].Zones[j].HeatSupply);
          for (int i = 0; i < bModel.MultiRoom.Length; i++)
            for (int j = 0; j < bModel.MultiRoom[i].ZoneNumber; j++)
              sWriter.Write("," + bModel.MultiRoom[i].Zones[j].WaterSupply);

          sWriter.WriteLine();

          dTime = dTime.AddHours(1);
        }
      }
    }

    /// <summary>巨大な熱負荷計算モデルを作成する</summary>
    /// <returns>巨大な熱負荷計算モデル</returns>
    private static BuildingThermalModel makeLargeBuilding()
    {
      //傾斜面の作成（四方位）//////////////
      Incline incN = new Incline(Incline.Orientation.N, 0.5 * Math.PI);
      Incline incE = new Incline(Incline.Orientation.E, 0.5 * Math.PI);
      Incline incW = new Incline(Incline.Orientation.W, 0.5 * Math.PI);
      Incline incS = new Incline(Incline.Orientation.S, 0.5 * Math.PI);
      Incline incH = new Incline(Incline.Orientation.S, 0);

      //壁構成を作成////////////////////////
      WallLayer[] exWL = new WallLayer[6];  //外壁一般部分
      exWL[0] = new WallLayer("タイル", 1.3, 2000, 0.010);
      exWL[1] = new WallLayer("セメント・モルタル", 1.5, 1600, 0.025);
      exWL[2] = new WallLayer("コンクリート", 1.6, 2000, 0.150);
      exWL[3] = new WallLayer("押出ポリスチレンフォーム1種", 0.040, 33, 0.025);
      exWL[4] = new AirGapLayer("非密閉中空層", false, 0.05);
      exWL[5] = new WallLayer("石膏ボード", 0.22, 830, 0.008);

      WallLayer[] exbmWL = new WallLayer[4];  //外壁梁部分
      exbmWL[0] = new WallLayer("タイル", 1.3, 2000, 0.010);
      exbmWL[1] = new WallLayer("セメント・モルタル", 1.5, 1600, 0.025);
      exbmWL[2] = new WallLayer("コンクリート", 1.6, 2000, 0.750);
      exbmWL[3] = new WallLayer("押出ポリスチレンフォーム1種", 0.040, 33, 0.025);

      WallLayer[] exRF = new WallLayer[9];  //外壁屋根
      exRF[0] = new WallLayer("コンクリート", 1.6, 2000, 0.060);
      exRF[1] = new WallLayer("押出ポリスチレンフォーム1種", 0.040, 33, 0.050);
      exRF[2] = new WallLayer("セメント・モルタル", 1.5, 1600, 0.015);
      exRF[3] = new WallLayer("アスファルト類", 0.110, 920, 0.005);
      exRF[4] = new WallLayer("セメント・モルタル", 1.5, 1600, 0.015);
      exRF[5] = new WallLayer("コンクリート", 1.6, 2000, 0.150);
      exRF[6] = new AirGapLayer("非密閉中空層", false, 0.05);
      exRF[7] = new WallLayer("石膏ボード", 0.220, 830, 0.010);
      exRF[8] = new WallLayer("ロックウール化粧吸音板", 0.064, 290, 0.015);

      WallLayer[] flWL = new WallLayer[6];  //床・天井
      flWL[0] = new WallLayer("ビニル系床材", 0.190, 2000, 0.003);
      flWL[1] = new AirGapLayer("非密閉中空層", false, 0.05);
      flWL[2] = new WallLayer("コンクリート", 1.6, 2000, 0.150);
      flWL[3] = new AirGapLayer("非密閉中空層", false, 0.05);
      flWL[4] = new WallLayer("石膏ボード", 0.220, 830, 0.009);
      flWL[5] = new WallLayer("ロックウール化粧吸音板", 0.064, 290, 0.015);

      WallLayer[] inWL = new WallLayer[3];  //内壁
      inWL[0] = new WallLayer("石膏ボード", 0.220, 830, 0.012);
      inWL[1] = new AirGapLayer("非密閉中空層", false, 0.05);
      inWL[2] = new WallLayer("石膏ボード", 0.220, 830, 0.012);

      WallLayer[] inSWL = new WallLayer[1];  //内壁_テナント間仕切用仮想壁
      inSWL[0] = new WallLayer("仮想壁", 10000, 1, 0.01);

      //ゾーンを作成/////////////////////////
      Zone[][] znNs = new Zone[7][];
      Zone[][] znSs = new Zone[7][];
      Zone[][] znCs = new Zone[7][];
      //1F
      znNs[0] = new Zone[5];
      znSs[0] = new Zone[5];
      znCs[0] = new Zone[3];
      znNs[0][0] = new Zone("1-NWP", (3.25 * 14) * 2.7 * 1.2);
      znNs[0][1] = new Zone("1-NP-1", (9.75 * 4) * 2.7 * 1.2);
      znNs[0][2] = new Zone("1-NP-2", (13 * 4) * 2.7 * 1.2);
      znNs[0][3] = new Zone("1-NI-1", (9.75 * 10) * 2.7 * 1.2);
      znNs[0][4] = new Zone("1-NI-2", (13 * 10) * 2.7 * 1.2);
      znSs[0][0] = new Zone("1-SWP", (3.25 * 14) * 2.7 * 1.2);
      znSs[0][1] = new Zone("1-SP-1", (9.75 * 4) * 2.7 * 1.2);
      znSs[0][2] = new Zone("1-SP-2", (6.5 * 4) * 2.7 * 1.2);
      znSs[0][3] = new Zone("1-SI-1", (9.75 * 10) * 2.7 * 1.2);
      znSs[0][4] = new Zone("1-SI-2", (6.5 * 10) * 2.7 * 1.2);
      znCs[0][0] = new Zone("1-HL", 140 * 3.0 * 1.2);
      znCs[0][1] = new Zone("1-WC", 90 * 2.4 * 1.2);
      znCs[0][2] = new Zone("1-IL", 160 * 2.4 * 1.2);
      //2-7F
      for (int i = 1; i < 7; i++)
      {
        znNs[i] = new Zone[10];
        znSs[i] = new Zone[9];
        znCs[i] = new Zone[2];

        znNs[i][0] = new Zone((i + 1) + "-NWP", (3.25 * 14) * 2.7 * 1.2);
        znNs[i][1] = new Zone((i + 1) + "-NP-1", (9.75 * 4) * 2.7 * 1.2);
        znNs[i][2] = new Zone((i + 1) + "-NP-2", (6.5 * 4) * 2.7 * 1.2);
        znNs[i][3] = new Zone((i + 1) + "-NP-3", (10.0 * 4) * 2.7 * 1.2);
        znNs[i][4] = new Zone((i + 1) + "-NP-4", (9.75 * 4) * 2.7 * 1.2);
        znNs[i][5] = new Zone((i + 1) + "-NEP", (3.25 * 14) * 2.7 * 1.2);
        znNs[i][6] = new Zone((i + 1) + "-NI-1", (9.75 * 10) * 2.7 * 1.2);
        znNs[i][7] = new Zone((i + 1) + "-NI-2", (6.5 * 10) * 2.7 * 1.2);
        znNs[i][8] = new Zone((i + 1) + "-NI-3", (10.0 * 10) * 2.7 * 1.2);
        znNs[i][9] = new Zone((i + 1) + "-NI-4", (9.75 * 10) * 2.7 * 1.2);
        znSs[i][0] = new Zone((i + 1) + "-SWP", (3.25 * 14) * 2.7 * 1.2);
        znSs[i][1] = new Zone((i + 1) + "-SP-1", (9.75 * 4) * 2.7 * 1.2);
        znSs[i][2] = new Zone((i + 1) + "-SP-2", (6.5 * 4) * 2.7 * 1.2);
        znSs[i][3] = new Zone((i + 1) + "-SP-3", (10.0 * 4) * 2.7 * 1.2);
        znSs[i][4] = new Zone((i + 1) + "-SP-4", (6.5 * 4) * 2.7 * 1.2);
        znSs[i][5] = new Zone((i + 1) + "-SI-1", (9.75 * 10) * 2.7 * 1.2);
        znSs[i][6] = new Zone((i + 1) + "-SI-2", (6.5 * 10) * 2.7 * 1.2);
        znSs[i][7] = new Zone((i + 1) + "-SI-3", (10.0 * 10) * 2.7 * 1.2);
        znSs[i][8] = new Zone((i + 1) + "-SI-4", (6.5 * 10) * 2.7 * 1.2);
        znCs[i][0] = new Zone((i + 1) + "-WC", 90 * 2.4 * 1.2);
        znCs[i][1] = new Zone((i + 1) + "-IL", 160 * 2.4 * 1.2);
      }

      //内部発熱を設定*************************************************************************
      for (int fl = 0; fl < 7; fl++)
      {
        for (int i = 0; i < znNs[fl].Length; i++)
        {
          double area = znNs[fl][i].AirMass / 1.2 / 2.7;
          znNs[fl][i].AddHeatGain(new SHASE_SimulationTest.MyHeatGain(0.1 * area, 12 * area, 12 * area, true));
        }
        for (int i = 0; i < znSs[fl].Length; i++)
        {
          double area = znSs[fl][i].AirMass / 1.2 / 2.7;
          znSs[fl][i].AddHeatGain(new SHASE_SimulationTest.MyHeatGain(0.1 * area, 12 * area, 12 * area, true));
        }
      }

      ////隙間風と熱容量設定*************************************************************************
      for (int fl = 0; fl < 7; fl++)
      {
        for (int i = 0; i < znNs[fl].Length; i++)
        {
          znNs[fl][i].HeatCapacity = znNs[fl][i].AirMass * 1006 * 10;
          znNs[fl][i].VentilationRate = znNs[fl][i].AirMass / 3600d * 0.1;
          znNs[fl][i].InitializeAirState(22, 0.0105);
        }
        for (int i = 0; i < znSs[fl].Length; i++)
        {
          znSs[fl][i].HeatCapacity = znSs[fl][i].AirMass * 1006 * 10;
          znSs[fl][i].VentilationRate = znSs[fl][i].AirMass / 3600d * 0.1;
          znSs[fl][i].InitializeAirState(22, 0.0105);
        }
        for (int i = 0; i < znCs[fl].Length; i++)
        {
          znCs[fl][i].HeatCapacity = 0;
          znCs[fl][i].VentilationRate = znCs[fl][i].AirMass / 3600d * 0.1;
          znCs[fl][i].InitializeAirState(22, 0.0105);
        }
      }

      //壁体の作成***************************************************************************************
      Wall[] walls = new Wall[488];
      //1F
      //外壁
      walls[0] = new Wall(46.76, exWL);
      walls[1] = new Wall(12.60, exbmWL);
      walls[2] = new Wall(10.67, exWL);
      walls[3] = new Wall(2.93, exbmWL);
      walls[4] = new Wall(32.00, exWL);
      walls[5] = new Wall(8.78, exbmWL);
      walls[6] = new Wall(42.66, exWL);
      walls[7] = new Wall(11.70, exbmWL);
      walls[8] = new Wall(46.76, exWL);
      walls[9] = new Wall(12.60, exbmWL);
      walls[10] = new Wall(10.67, exWL);
      walls[11] = new Wall(2.93, exbmWL);
      walls[12] = new Wall(32.00, exWL);
      walls[13] = new Wall(8.78, exbmWL);
      walls[14] = new Wall(16.01, exWL);
      walls[15] = new Wall(5.85, exbmWL);
      walls[16] = new Wall(15.00, exWL);
      walls[17] = new Wall(32.50, exWL);
      walls[18] = new Wall(70.00, exWL);
      walls[19] = new Wall(12.50, exWL);
      //内壁
      walls[20] = new Wall(8.78, inWL);
      walls[21] = new Wall(26.33, inWL);
      walls[22] = new Wall(35.10, inWL);
      walls[23] = new Wall(27.00, inWL);
      walls[24] = new Wall(10.80, inWL);
      walls[25] = new Wall(8.78, inWL);
      walls[26] = new Wall(26.33, inWL);
      walls[27] = new Wall(17.55, inWL);
      walls[28] = new Wall(27.00, inWL);
      walls[29] = new Wall(10.80, inWL);
      walls[30] = new Wall(37.80, inWL);
      walls[31] = new Wall(37.80, inWL);
      walls[32] = new Wall(17.55, inWL);
      walls[33] = new Wall(81.00, inWL);
      walls[34] = new Wall(45.50, flWL);
      walls[35] = new Wall(39.00, flWL);
      walls[36] = new Wall(52.00, flWL);
      walls[37] = new Wall(97.50, flWL);
      walls[38] = new Wall(130.00, flWL);
      walls[39] = new Wall(45.50, flWL);
      walls[40] = new Wall(39.00, flWL);
      walls[41] = new Wall(26.00, flWL);
      walls[42] = new Wall(97.50, flWL);
      walls[43] = new Wall(65.00, flWL);
      walls[44] = new Wall(160.00, flWL);
      walls[45] = new Wall(90.00, flWL);
      walls[46] = new Wall(160.00, flWL);
      //2F-7F
      for (int fl = 1; fl < 7; fl++)
      {
        int ofs = 47 + 70 * (fl - 1);
        //外壁
        walls[ofs + 0] = new Wall(32.76, exWL);
        walls[ofs + 1] = new Wall(12.60, exbmWL);
        walls[ofs + 2] = new Wall(7.42, exWL);
        walls[ofs + 3] = new Wall(2.93, exbmWL);
        walls[ofs + 4] = new Wall(22.25, exWL);
        walls[ofs + 5] = new Wall(8.78, exbmWL);
        walls[ofs + 6] = new Wall(14.83, exWL);
        walls[ofs + 7] = new Wall(5.85, exbmWL);
        walls[ofs + 8] = new Wall(20.36, exWL);
        walls[ofs + 9] = new Wall(9.00, exbmWL);
        walls[ofs + 10] = new Wall(22.25, exWL);
        walls[ofs + 11] = new Wall(8.78, exbmWL);
        walls[ofs + 12] = new Wall(32.76, exWL);
        walls[ofs + 13] = new Wall(12.60, exbmWL);
        walls[ofs + 14] = new Wall(7.42, exWL);
        walls[ofs + 15] = new Wall(2.93, exbmWL);
        walls[ofs + 16] = new Wall(32.76, exWL);
        walls[ofs + 17] = new Wall(12.60, exbmWL);
        walls[ofs + 18] = new Wall(7.42, exWL);
        walls[ofs + 19] = new Wall(2.93, exbmWL);
        walls[ofs + 20] = new Wall(22.25, exWL);
        walls[ofs + 21] = new Wall(8.78, exbmWL);
        walls[ofs + 22] = new Wall(14.83, exWL);
        walls[ofs + 23] = new Wall(5.85, exbmWL);
        walls[ofs + 24] = new Wall(20.36, exWL);
        walls[ofs + 25] = new Wall(9.00, exbmWL);
        walls[ofs + 26] = new Wall(12.17, exWL);
        walls[ofs + 27] = new Wall(5.85, exbmWL);
        walls[ofs + 28] = new Wall(26.00, exWL);
        walls[ofs + 29] = new Wall(56.00, exWL);
        walls[ofs + 30] = new Wall(25.00, exWL);
        //内壁
        walls[ofs + 31] = new Wall(8.78, inWL);
        walls[ofs + 32] = new Wall(26.33, inWL);
        walls[ofs + 33] = new Wall(35.10, inWL);
        walls[ofs + 34] = new Wall(27.00, inWL);
        walls[ofs + 35] = new Wall(26.33, inWL);
        walls[ofs + 36] = new Wall(8.78, inWL);
        walls[ofs + 37] = new Wall(8.78, inWL);
        walls[ofs + 38] = new Wall(26.33, inWL);
        walls[ofs + 39] = new Wall(35.10, inWL);
        walls[ofs + 40] = new Wall(27.00, inWL);
        walls[ofs + 41] = new Wall(17.55, inWL);
        walls[ofs + 42] = new Wall(17.55, inWL);
        walls[ofs + 43] = new Wall(27.00, inWL);
        walls[ofs + 44] = new Wall(10.80, inWL);
        walls[ofs + 45] = new Wall(10.80, inSWL);
        walls[ofs + 46] = new Wall(27.00, inSWL);
        walls[ofs + 47] = new Wall(10.80, inSWL);
        walls[ofs + 48] = new Wall(27.00, inSWL);
        walls[ofs + 49] = new Wall(45.50, flWL);
        walls[ofs + 50] = new Wall(39.00, flWL);
        walls[ofs + 51] = new Wall(26.00, flWL);
        walls[ofs + 52] = new Wall(40.00, flWL);
        walls[ofs + 53] = new Wall(39.00, flWL);
        walls[ofs + 54] = new Wall(45.50, flWL);
        walls[ofs + 55] = new Wall(97.50, flWL);
        walls[ofs + 56] = new Wall(65.00, flWL);
        walls[ofs + 57] = new Wall(100.00, flWL);
        walls[ofs + 58] = new Wall(97.50, flWL);
        walls[ofs + 59] = new Wall(45.50, flWL);
        walls[ofs + 60] = new Wall(39.00, flWL);
        walls[ofs + 61] = new Wall(26.00, flWL);
        walls[ofs + 62] = new Wall(40.00, flWL);
        walls[ofs + 63] = new Wall(26.00, flWL);
        walls[ofs + 64] = new Wall(97.50, flWL);
        walls[ofs + 65] = new Wall(65.00, flWL);
        walls[ofs + 66] = new Wall(100.00, flWL);
        walls[ofs + 67] = new Wall(65.00, flWL);
        walls[ofs + 68] = new Wall(90.00, flWL);
        walls[ofs + 69] = new Wall(160.00, flWL);
      }
      //屋上スラブ
      walls[467] = new Wall(45.50, flWL);
      walls[468] = new Wall(39.00, flWL);
      walls[469] = new Wall(26.00, flWL);
      walls[470] = new Wall(40.00, flWL);
      walls[471] = new Wall(39.00, flWL);
      walls[472] = new Wall(45.50, flWL);
      walls[473] = new Wall(97.50, flWL);
      walls[474] = new Wall(65.00, flWL);
      walls[475] = new Wall(100.00, flWL);
      walls[476] = new Wall(97.50, flWL);
      walls[477] = new Wall(45.50, flWL);
      walls[478] = new Wall(39.00, flWL);
      walls[479] = new Wall(26.00, flWL);
      walls[480] = new Wall(40.00, flWL);
      walls[481] = new Wall(26.00, flWL);
      walls[482] = new Wall(97.50, flWL);
      walls[483] = new Wall(65.00, flWL);
      walls[484] = new Wall(100.00, flWL);
      walls[485] = new Wall(65.00, flWL);
      walls[486] = new Wall(90.00, flWL);
      walls[487] = new Wall(160.00, flWL);
      //壁の初期化
      for (int i = 0; i < walls.Length; i++)
      {
        walls[i].ShortWaveAbsorptanceF = walls[i].ShortWaveAbsorptanceB = 0.8;
        walls[i].LongWaveEmissivityF = walls[i].LongWaveEmissivityB = 0.9;
        walls[i].RadiativeCoefficientF = walls[i].RadiativeCoefficientB = 5;
        string nm = walls[i].Layers[0].Name;
        if (nm == "コンクリート" || nm == "タイル") walls[i].ConvectiveCoefficientF = 18;
        else walls[i].ConvectiveCoefficientF = 4;
        walls[i].ConvectiveCoefficientB = 4;
        walls[i].Initialize(20);
      }

      //窓を作成***************************************************************************************
      double[] TAU_WIN, RHO_WIN;
      TAU_WIN = new double[] { 0.815 }; //ガラスの透過率リスト[-]
      RHO_WIN = new double[] { 0.072 }; //ガラスの反射率リスト[-]
      Window[][][] win = new Window[7][][];
      //1F
      win[0] = new Window[3][];
      win[0][0] = new Window[4];
      win[0][1] = new Window[4];
      win[0][2] = new Window[1];
      win[0][0][0] = new Window(5.32 * 2.0, TAU_WIN, RHO_WIN, incW);
      win[0][0][1] = new Window(5.32 * 0.5, TAU_WIN, RHO_WIN, incN);
      win[0][0][2] = new Window(5.32 * 1.5, TAU_WIN, RHO_WIN, incN);
      win[0][0][3] = new Window(5.32 * 2.0, TAU_WIN, RHO_WIN, incN);
      win[0][1][0] = new Window(5.32 * 2.0, TAU_WIN, RHO_WIN, incW);
      win[0][1][1] = new Window(5.32 * 0.5, TAU_WIN, RHO_WIN, incS);
      win[0][1][2] = new Window(5.32 * 1.5, TAU_WIN, RHO_WIN, incS);
      win[0][1][3] = new Window(5.32 * 1.0, TAU_WIN, RHO_WIN, incS);
      win[0][2][0] = new Window(10.0 * 2.8, TAU_WIN, RHO_WIN, incS);
      //2-7F
      for (int fl = 1; fl < 7; fl++)
      {
        win[fl] = new Window[3][];
        win[fl][0] = new Window[8];
        win[fl][1] = new Window[6];
        win[fl][2] = new Window[0];
        win[fl][0][0] = new Window(5.32 * 2.0, TAU_WIN, RHO_WIN, incW);
        win[fl][0][1] = new Window(5.32 * 0.5, TAU_WIN, RHO_WIN, incN);
        win[fl][0][2] = new Window(5.32 * 1.5, TAU_WIN, RHO_WIN, incN);
        win[fl][0][3] = new Window(5.32 * 1.0, TAU_WIN, RHO_WIN, incN);
        win[fl][0][4] = new Window(5.32 * 2.0, TAU_WIN, RHO_WIN, incN);
        win[fl][0][5] = new Window(5.32 * 1.5, TAU_WIN, RHO_WIN, incN);
        win[fl][0][6] = new Window(5.32 * 0.5, TAU_WIN, RHO_WIN, incN);
        win[fl][0][7] = new Window(5.32 * 2.0, TAU_WIN, RHO_WIN, incE);
        win[fl][1][0] = new Window(5.32 * 2.0, TAU_WIN, RHO_WIN, incW);
        win[fl][1][1] = new Window(5.32 * 0.5, TAU_WIN, RHO_WIN, incS);
        win[fl][1][2] = new Window(5.32 * 1.5, TAU_WIN, RHO_WIN, incS);
        win[fl][1][3] = new Window(5.32 * 1.0, TAU_WIN, RHO_WIN, incS);
        win[fl][1][4] = new Window(5.32 * 2.0, TAU_WIN, RHO_WIN, incS);
        win[fl][1][5] = new Window(5.32 * 1.0, TAU_WIN, RHO_WIN, incS);
      }
      //初期化
      for (int fl = 0; fl < 7; fl++)
      {
        for (int i = 0; i < win[fl].Length; i++)
        {
          for (int j = 0; j < win[fl][i].Length; j++)
          {
            VenetianBlind blind = new VenetianBlind(25, 22.5, 0, 0, 0.66, 0.66);
            blind.SlatAngle = 0;
            win[fl][i][j].SetShadingDevice(1, blind);
            win[fl][i][j].ConvectiveCoefficientF = 18;
            win[fl][i][j].ConvectiveCoefficientB = 4;
            win[fl][i][j].LongWaveEmissivityF = win[fl][i][j].LongWaveEmissivityB = 0.9;
          }
        }
      }

      //多数室の作成************************************************************************************
      MultiRooms[] mRm = new MultiRooms[3 * 7];
      //1F
      mRm[0] = new MultiRooms(1, znNs[0], walls, win[0][0]);
      mRm[1] = new MultiRooms(1, znSs[0], walls, win[0][1]);
      mRm[2] = new MultiRooms(3, znCs[0], walls, win[0][2]);
      for (int i = 0; i < znNs[0].Length; i++) mRm[0].AddZone(0, i);
      for (int i = 0; i < znSs[0].Length; i++) mRm[1].AddZone(0, i);
      for (int i = 0; i < znCs[0].Length; i++) mRm[2].AddZone(i, i);
      //2-7F
      for (int fl = 1; fl < 7; fl++)
      {
        //北側事務室
        int rmN = 3 + (fl - 1) * 3;
        mRm[rmN] = new MultiRooms(2, znNs[fl], walls, win[fl][0]);
        mRm[rmN].AddZone(0, 0); mRm[rmN].AddZone(0, 1); mRm[rmN].AddZone(0, 2); mRm[rmN].AddZone(0, 6); mRm[rmN].AddZone(0, 7); //西側テナント区画
        mRm[rmN].AddZone(1, 3); mRm[rmN].AddZone(1, 4); mRm[rmN].AddZone(1, 5); mRm[rmN].AddZone(1, 8); mRm[rmN].AddZone(1, 9); //東側テナント区画
        //南側事務室
        rmN = 4 + (fl - 1) * 3;
        mRm[rmN] = new MultiRooms(2, znSs[fl], walls, win[fl][1]);
        mRm[rmN].AddZone(0, 0); mRm[rmN].AddZone(0, 1); mRm[rmN].AddZone(0, 2); mRm[rmN].AddZone(0, 5); mRm[rmN].AddZone(0, 6); //西側テナント区画
        mRm[rmN].AddZone(1, 3); mRm[rmN].AddZone(1, 4); mRm[rmN].AddZone(1, 7); mRm[rmN].AddZone(1, 8); //東側テナント区画
        //共用部
        rmN = 5 + (fl - 1) * 3;
        mRm[rmN] = new MultiRooms(2, znCs[fl], walls, win[fl][2]);
        mRm[rmN].AddZone(0, 0); //廊下・EVホール
        mRm[rmN].AddZone(1, 1); //便所
      }

      //外壁を登録***************************************************************************************
      //1F北側事務室
      mRm[0].AddWall(0, 0, false); mRm[0].SetOutsideWall(0, true, incW);
      mRm[0].AddWall(0, 1, false); mRm[0].SetOutsideWall(1, true, incW);
      mRm[0].AddWall(0, 2, false); mRm[0].SetOutsideWall(2, true, incN);
      mRm[0].AddWall(0, 3, false); mRm[0].SetOutsideWall(3, true, incN);
      mRm[0].AddWall(1, 4, false); mRm[0].SetOutsideWall(4, true, incN);
      mRm[0].AddWall(1, 5, false); mRm[0].SetOutsideWall(5, true, incN);
      mRm[0].AddWall(2, 6, false); mRm[0].SetOutsideWall(6, true, incN);
      mRm[0].AddWall(2, 7, false); mRm[0].SetOutsideWall(7, true, incN);
      //1F南側事務室
      mRm[1].AddWall(0, 8, false); mRm[1].SetOutsideWall(8, true, incW);
      mRm[1].AddWall(0, 9, false); mRm[1].SetOutsideWall(9, true, incW);
      mRm[1].AddWall(0, 10, false); mRm[1].SetOutsideWall(10, true, incS);
      mRm[1].AddWall(0, 11, false); mRm[1].SetOutsideWall(11, true, incS);
      mRm[1].AddWall(1, 12, false); mRm[1].SetOutsideWall(12, true, incS);
      mRm[1].AddWall(1, 13, false); mRm[1].SetOutsideWall(13, true, incS);
      mRm[1].AddWall(2, 14, false); mRm[1].SetOutsideWall(14, true, incS);
      mRm[1].AddWall(2, 15, false); mRm[1].SetOutsideWall(15, true, incS);
      //1F共用部
      mRm[2].AddWall(0, 16, false); mRm[2].SetOutsideWall(16, true, incS);
      mRm[2].AddWall(1, 17, false); mRm[2].SetOutsideWall(17, true, incS);
      mRm[2].AddWall(1, 18, false); mRm[2].SetOutsideWall(18, true, incE);
      mRm[2].AddWall(2, 19, false); mRm[2].SetOutsideWall(19, true, incE);
      //2-7F
      for (int fl = 1; fl < 7; fl++)
      {
        int ofs = 47 + 70 * (fl - 1);
        //北側事務室
        int rmN = 3 + (fl - 1) * 3;
        mRm[rmN].AddWall(0, ofs + 0, false); mRm[rmN].SetOutsideWall(ofs + 0, true, incW);
        mRm[rmN].AddWall(0, ofs + 1, false); mRm[rmN].SetOutsideWall(ofs + 1, true, incW);
        mRm[rmN].AddWall(0, ofs + 2, false); mRm[rmN].SetOutsideWall(ofs + 2, true, incN);
        mRm[rmN].AddWall(0, ofs + 3, false); mRm[rmN].SetOutsideWall(ofs + 3, true, incN);
        mRm[rmN].AddWall(1, ofs + 4, false); mRm[rmN].SetOutsideWall(ofs + 4, true, incN);
        mRm[rmN].AddWall(1, ofs + 5, false); mRm[rmN].SetOutsideWall(ofs + 5, true, incN);
        mRm[rmN].AddWall(2, ofs + 6, false); mRm[rmN].SetOutsideWall(ofs + 6, true, incN);
        mRm[rmN].AddWall(2, ofs + 7, false); mRm[rmN].SetOutsideWall(ofs + 7, true, incN);
        mRm[rmN].AddWall(3, ofs + 8, false); mRm[rmN].SetOutsideWall(ofs + 8, true, incN);
        mRm[rmN].AddWall(3, ofs + 9, false); mRm[rmN].SetOutsideWall(ofs + 9, true, incN);
        mRm[rmN].AddWall(4, ofs + 10, false); mRm[rmN].SetOutsideWall(ofs + 10, true, incN);
        mRm[rmN].AddWall(4, ofs + 11, false); mRm[rmN].SetOutsideWall(ofs + 11, true, incN);
        mRm[rmN].AddWall(5, ofs + 12, false); mRm[rmN].SetOutsideWall(ofs + 12, true, incN);
        mRm[rmN].AddWall(5, ofs + 13, false); mRm[rmN].SetOutsideWall(ofs + 13, true, incN);
        mRm[rmN].AddWall(5, ofs + 14, false); mRm[rmN].SetOutsideWall(ofs + 14, true, incE);
        mRm[rmN].AddWall(5, ofs + 15, false); mRm[rmN].SetOutsideWall(ofs + 15, true, incE);
        //南側事務室
        rmN++;
        mRm[rmN].AddWall(0, ofs + 16, false); mRm[rmN].SetOutsideWall(ofs + 16, true, incW);
        mRm[rmN].AddWall(0, ofs + 17, false); mRm[rmN].SetOutsideWall(ofs + 17, true, incW);
        mRm[rmN].AddWall(0, ofs + 18, false); mRm[rmN].SetOutsideWall(ofs + 18, true, incS);
        mRm[rmN].AddWall(0, ofs + 19, false); mRm[rmN].SetOutsideWall(ofs + 19, true, incS);
        mRm[rmN].AddWall(1, ofs + 20, false); mRm[rmN].SetOutsideWall(ofs + 20, true, incS);
        mRm[rmN].AddWall(1, ofs + 21, false); mRm[rmN].SetOutsideWall(ofs + 21, true, incS);
        mRm[rmN].AddWall(2, ofs + 22, false); mRm[rmN].SetOutsideWall(ofs + 22, true, incS);
        mRm[rmN].AddWall(2, ofs + 23, false); mRm[rmN].SetOutsideWall(ofs + 23, true, incS);
        mRm[rmN].AddWall(3, ofs + 24, false); mRm[rmN].SetOutsideWall(ofs + 24, true, incS);
        mRm[rmN].AddWall(3, ofs + 25, false); mRm[rmN].SetOutsideWall(ofs + 25, true, incS);
        mRm[rmN].AddWall(4, ofs + 26, false); mRm[rmN].SetOutsideWall(ofs + 26, true, incS);
        mRm[rmN].AddWall(4, ofs + 27, false); mRm[rmN].SetOutsideWall(ofs + 27, true, incS);
        //共用部
        rmN++;
        mRm[rmN].AddWall(0, ofs + 28, false); mRm[rmN].SetOutsideWall(ofs + 28, true, incS);
        mRm[rmN].AddWall(0, ofs + 29, false); mRm[rmN].SetOutsideWall(ofs + 29, true, incE);
        mRm[rmN].AddWall(1, ofs + 30, false); mRm[rmN].SetOutsideWall(ofs + 30, true, incE);
      }
      //7F屋上
      for (int i = 0; i < 10; i++)
      {
        mRm[18].AddWall(i, 467 + i, false);
        mRm[18].SetOutsideWall(467 + i, true, incH);
      }
      for (int i = 0; i < 9; i++)
      {
        mRm[19].AddWall(i, 477 + i, false);
        mRm[19].SetOutsideWall(477 + i, true, incH);
      }
      mRm[20].AddWall(0, 486, false); mRm[20].SetOutsideWall(486, true, incH);
      mRm[20].AddWall(1, 487, false); mRm[20].SetOutsideWall(487, true, incH);

      //内壁を登録***************************************************************************************
      //1F
      mRm[0].AddWall(0, 20, true); mRm[0].UseAdjacentSpaceFactor(20, false, 0.7);
      mRm[0].AddWall(3, 21, true); mRm[2].AddWall(2, 21, false);
      mRm[0].AddWall(4, 22, true); mRm[2].AddWall(2, 22, false);
      mRm[0].AddWall(4, 23, true); mRm[0].UseAdjacentSpaceFactor(23, false, 0.7);
      mRm[0].AddWall(2, 24, true); mRm[0].UseAdjacentSpaceFactor(24, false, 0.7);
      mRm[1].AddWall(0, 25, true); mRm[1].UseAdjacentSpaceFactor(25, false, 0.7);
      mRm[1].AddWall(3, 26, true); mRm[2].AddWall(2, 26, false);
      mRm[1].AddWall(4, 27, true); mRm[2].AddWall(2, 27, false);
      mRm[1].AddWall(4, 28, true); mRm[2].AddWall(0, 28, false);
      mRm[1].AddWall(2, 29, true); mRm[2].AddWall(0, 29, false);
      mRm[2].AddWall(0, 30, true); mRm[2].UseAdjacentSpaceFactor(30, false, 0.3);
      mRm[2].AddWall(1, 31, true); mRm[2].UseAdjacentSpaceFactor(31, false, 0.3);
      mRm[2].AddWall(1, 32, true); mRm[2].AddWall(2, 32, false);
      mRm[2].AddWall(2, 33, true); mRm[2].UseAdjacentSpaceFactor(33, false, 0.3);
      mRm[0].AddWall(0, 34, true); mRm[0].UseAdjacentSpaceFactor(34, false, 0.3);
      mRm[0].AddWall(1, 35, true); mRm[0].UseAdjacentSpaceFactor(35, false, 0.3);
      mRm[0].AddWall(2, 36, true); mRm[0].UseAdjacentSpaceFactor(36, false, 0.3);
      mRm[0].AddWall(3, 37, true); mRm[0].UseAdjacentSpaceFactor(37, false, 0.3);
      mRm[0].AddWall(4, 38, true); mRm[0].UseAdjacentSpaceFactor(38, false, 0.3);
      mRm[1].AddWall(0, 39, true); mRm[1].UseAdjacentSpaceFactor(39, false, 0.3);
      mRm[1].AddWall(1, 40, true); mRm[1].UseAdjacentSpaceFactor(40, false, 0.3);
      mRm[1].AddWall(2, 41, true); mRm[1].UseAdjacentSpaceFactor(41, false, 0.3);
      mRm[1].AddWall(3, 42, true); mRm[1].UseAdjacentSpaceFactor(42, false, 0.3);
      mRm[1].AddWall(4, 43, true); mRm[1].UseAdjacentSpaceFactor(43, false, 0.3);
      mRm[2].AddWall(0, 44, true); mRm[2].UseAdjacentSpaceFactor(44, false, 0.3);
      mRm[2].AddWall(1, 45, true); mRm[2].UseAdjacentSpaceFactor(45, false, 0.3);
      mRm[2].AddWall(2, 46, true); mRm[2].UseAdjacentSpaceFactor(46, false, 0.3);
      //2-7F
      for (int fl = 1; fl < 7; fl++)
      {
        int ofs = 47 + 70 * (fl - 1);
        int rmN0 = 3 + (fl - 1) * 3;
        int rmN1 = rmN0 + 1;
        int rmN2 = rmN1 + 1;
        mRm[rmN0].AddWall(0, ofs + 31, true); mRm[rmN0].UseAdjacentSpaceFactor(ofs + 31, false, 0.7);
        mRm[rmN0].AddWall(6, ofs + 32, true); mRm[rmN2].AddWall(1, ofs + 32, false);
        mRm[rmN0].AddWall(7, ofs + 33, true); mRm[rmN2].AddWall(1, ofs + 33, false);
        mRm[rmN0].AddWall(8, ofs + 34, true); mRm[rmN2].AddWall(1, ofs + 34, false);
        mRm[rmN0].AddWall(9, ofs + 35, true); mRm[rmN2].AddWall(1, ofs + 35, false);
        mRm[rmN0].AddWall(5, ofs + 36, true); mRm[rmN0].UseAdjacentSpaceFactor(ofs + 36, false, 0.7);
        mRm[rmN1].AddWall(0, ofs + 37, true); mRm[rmN1].UseAdjacentSpaceFactor(ofs + 37, false, 0.7);
        mRm[rmN1].AddWall(5, ofs + 38, true); mRm[rmN2].AddWall(1, ofs + 38, false);
        mRm[rmN1].AddWall(6, ofs + 39, true); mRm[rmN2].AddWall(1, ofs + 39, false);
        mRm[rmN1].AddWall(7, ofs + 40, true); mRm[rmN2].AddWall(1, ofs + 40, false);
        mRm[rmN1].AddWall(8, ofs + 41, true); mRm[rmN2].AddWall(1, ofs + 41, false);
        mRm[rmN2].AddWall(0, ofs + 42, true); mRm[rmN2].AddWall(1, ofs + 42, false);
        mRm[rmN2].AddWall(0, ofs + 43, true); mRm[rmN1].AddWall(8, ofs + 43, false);
        mRm[rmN2].AddWall(0, ofs + 44, true); mRm[rmN1].AddWall(4, ofs + 44, false);
        mRm[rmN0].AddWall(2, ofs + 45, true); mRm[rmN0].AddWall(3, ofs + 45, false);
        mRm[rmN0].AddWall(7, ofs + 46, true); mRm[rmN0].AddWall(8, ofs + 46, false);
        mRm[rmN1].AddWall(2, ofs + 47, true); mRm[rmN1].AddWall(3, ofs + 47, false);
        mRm[rmN1].AddWall(6, ofs + 48, true); mRm[rmN1].AddWall(7, ofs + 48, false);
        //床
        if (fl != 1)
        {
          for (int i = 0; i < 10; i++)
          {
            mRm[rmN0].AddWall(i, ofs + 49 + i, true);
            mRm[rmN0 - 3].AddWall(i, ofs + 49 + i, false);
          }
          for (int i = 0; i < 9; i++)
          {
            mRm[rmN1].AddWall(i, ofs + 59 + i, true);
            mRm[rmN1 - 3].AddWall(i, ofs + 59 + i, false);
          }
          mRm[rmN2].AddWall(0, ofs + 68, true); mRm[rmN2 - 3].AddWall(0, ofs + 68, false);
          mRm[rmN2].AddWall(1, ofs + 69, true); mRm[rmN2 - 3].AddWall(1, ofs + 69, false);
        }
      }
      //1F-2F間の床は対応関係が特殊
      mRm[3].AddWall(0, 96, true); mRm[0].AddWall(0, 96, false);
      mRm[3].AddWall(1, 97, true); mRm[0].AddWall(1, 97, false);
      mRm[3].AddWall(2, 98, true); mRm[0].AddWall(2, 98, false);
      mRm[3].AddWall(3, 99, true); mRm[0].AddWall(3, 99, false);
      mRm[3].AddWall(4, 100, true); mRm[3].UseAdjacentSpaceFactor(100, false, 0.3);
      mRm[3].AddWall(5, 101, true); mRm[3].UseAdjacentSpaceFactor(101, false, 0.3);
      mRm[3].AddWall(6, 102, true); mRm[0].AddWall(3, 102, false);
      mRm[3].AddWall(7, 103, true); mRm[0].AddWall(4, 103, false);
      mRm[3].AddWall(8, 104, true); mRm[0].AddWall(4, 104, false);
      mRm[3].AddWall(9, 105, true); mRm[3].UseAdjacentSpaceFactor(105, false, 0.3);
      mRm[4].AddWall(0, 106, true); mRm[1].AddWall(0, 106, false);
      mRm[4].AddWall(1, 107, true); mRm[1].AddWall(1, 107, false);
      mRm[4].AddWall(2, 108, true); mRm[1].AddWall(2, 108, false);
      mRm[4].AddWall(3, 109, true); mRm[2].AddWall(0, 109, false);
      mRm[4].AddWall(4, 110, true); mRm[4].UseAdjacentSpaceFactor(110, false, 0.3);
      mRm[4].AddWall(5, 111, true); mRm[1].AddWall(1, 111, false);
      mRm[4].AddWall(6, 112, true); mRm[1].AddWall(2, 112, false);
      mRm[4].AddWall(7, 113, true); mRm[2].AddWall(0, 113, false);
      mRm[4].AddWall(8, 114, true); mRm[4].UseAdjacentSpaceFactor(114, false, 0.3);
      mRm[5].AddWall(0, 115, true); mRm[2].AddWall(1, 115, false);
      mRm[5].AddWall(1, 116, true); mRm[2].AddWall(2, 116, false);
      
      //窓を登録***************************************************************************************
      //1F
      mRm[0].AddWindow(0, 0);
      mRm[0].AddWindow(0, 1);
      mRm[0].AddWindow(1, 2);
      mRm[0].AddWindow(2, 3);
      mRm[1].AddWindow(0, 0);
      mRm[1].AddWindow(0, 1);
      mRm[1].AddWindow(1, 2);
      mRm[1].AddWindow(2, 3);
      mRm[2].AddWindow(0, 0);
      //2-7F
      for (int fl = 1; fl < 7; fl++)
      {
        int rmN = 3 + (fl - 1) * 3;
        mRm[rmN].AddWindow(0, 0);
        mRm[rmN].AddWindow(0, 1);
        mRm[rmN].AddWindow(1, 2);
        mRm[rmN].AddWindow(2, 3);
        mRm[rmN].AddWindow(3, 4);
        mRm[rmN].AddWindow(4, 5);
        mRm[rmN].AddWindow(5, 6);
        mRm[rmN].AddWindow(5, 7);
        mRm[rmN + 1].AddWindow(0, 0);
        mRm[rmN + 1].AddWindow(0, 1);
        mRm[rmN + 1].AddWindow(1, 2);
        mRm[rmN + 1].AddWindow(2, 3);
        mRm[rmN + 1].AddWindow(3, 4);
        mRm[rmN + 1].AddWindow(4, 5);
      }

      //ペリメータ床に短波長優先配分
      const double SW_RATE_TO_FLOOR = 0.7;
      //1F
      mRm[0].SetSWDistributionRateToFloor(0, 34, true, SW_RATE_TO_FLOOR);
      mRm[0].SetSWDistributionRateToFloor(1, 34, true, SW_RATE_TO_FLOOR);
      mRm[0].SetSWDistributionRateToFloor(2, 35, true, SW_RATE_TO_FLOOR);
      mRm[0].SetSWDistributionRateToFloor(3, 36, true, SW_RATE_TO_FLOOR);
      mRm[1].SetSWDistributionRateToFloor(0, 39, true, SW_RATE_TO_FLOOR);
      mRm[1].SetSWDistributionRateToFloor(1, 39, true, SW_RATE_TO_FLOOR);
      mRm[1].SetSWDistributionRateToFloor(2, 40, true, SW_RATE_TO_FLOOR);
      mRm[1].SetSWDistributionRateToFloor(3, 41, true, SW_RATE_TO_FLOOR);
      mRm[2].SetSWDistributionRateToFloor(0, 44, true, SW_RATE_TO_FLOOR);
      //2-7F
      for (int fl = 1; fl < 7; fl++)
      {
        int ofs = 47 + 70 * (fl - 1);
        int rmN = 3 + (fl - 1) * 3;
        mRm[rmN].SetSWDistributionRateToFloor(0, ofs + 49, true, SW_RATE_TO_FLOOR);
        mRm[rmN].SetSWDistributionRateToFloor(1, ofs + 49, true, SW_RATE_TO_FLOOR);
        mRm[rmN].SetSWDistributionRateToFloor(2, ofs + 50, true, SW_RATE_TO_FLOOR);
        mRm[rmN].SetSWDistributionRateToFloor(3, ofs + 51, true, SW_RATE_TO_FLOOR);
        mRm[rmN].SetSWDistributionRateToFloor(4, ofs + 52, true, SW_RATE_TO_FLOOR);
        mRm[rmN].SetSWDistributionRateToFloor(5, ofs + 53, true, SW_RATE_TO_FLOOR);
        mRm[rmN].SetSWDistributionRateToFloor(6, ofs + 54, true, SW_RATE_TO_FLOOR);
        mRm[rmN].SetSWDistributionRateToFloor(7, ofs + 54, true, SW_RATE_TO_FLOOR);
        mRm[rmN + 1].SetSWDistributionRateToFloor(0, ofs + 59, true, SW_RATE_TO_FLOOR);
        mRm[rmN + 1].SetSWDistributionRateToFloor(1, ofs + 59, true, SW_RATE_TO_FLOOR);
        mRm[rmN + 1].SetSWDistributionRateToFloor(2, ofs + 60, true, SW_RATE_TO_FLOOR);
        mRm[rmN + 1].SetSWDistributionRateToFloor(3, ofs + 61, true, SW_RATE_TO_FLOOR);
        mRm[rmN + 1].SetSWDistributionRateToFloor(4, ofs + 62, true, SW_RATE_TO_FLOOR);
        mRm[rmN + 1].SetSWDistributionRateToFloor(5, ofs + 63, true, SW_RATE_TO_FLOOR);
      }

      //建物モデルの作成
      BuildingThermalModel bModel = new BuildingThermalModel(mRm);
      bModel.TimeStep = 3600;

      //ゾーン間換気の設定
      const double cvRate = 150d * 1.2 / 3600d;
      //1F
      bModel.SetCrossVentilation(0, 0, 0, 1, 4.0 * cvRate);
      bModel.SetCrossVentilation(0, 0, 0, 3, 10.0 * cvRate);
      bModel.SetCrossVentilation(0, 1, 0, 3, 9.75 * cvRate);
      bModel.SetCrossVentilation(0, 1, 0, 2, 4.0 * cvRate);
      bModel.SetCrossVentilation(0, 3, 0, 4, 10.0 * cvRate);
      bModel.SetCrossVentilation(0, 2, 0, 4, 13.0 * cvRate);
      bModel.SetCrossVentilation(1, 0, 1, 1, 4.0 * cvRate);
      bModel.SetCrossVentilation(1, 0, 1, 3, 10.0 * cvRate);
      bModel.SetCrossVentilation(1, 1, 1, 3, 9.75 * cvRate);
      bModel.SetCrossVentilation(1, 1, 1, 2, 4.0 * cvRate);
      bModel.SetCrossVentilation(1, 3, 1, 4, 10.0 * cvRate);
      bModel.SetCrossVentilation(1, 2, 1, 4, 6.5 * cvRate);
      bModel.SetCrossVentilation(2, 0, 2, 2, 10.0 * cvRate);
      bModel.SetCrossVentilation(2, 1, 2, 2, 6.5 * cvRate);
      //2-7F
      for (int fl = 1; fl < 7; fl++)
      {
        int rmN = 3 + (fl - 1) * 3;
        bModel.SetCrossVentilation(rmN, 0, rmN, 1, 4.0 * cvRate);
        bModel.SetCrossVentilation(rmN, 1, rmN, 2, 4.0 * cvRate);
        bModel.SetCrossVentilation(rmN, 2, rmN, 3, 4.0 * cvRate);
        bModel.SetCrossVentilation(rmN, 3, rmN, 4, 4.0 * cvRate);
        bModel.SetCrossVentilation(rmN, 4, rmN, 5, 4.0 * cvRate);
        bModel.SetCrossVentilation(rmN, 0, rmN, 6, 10.0 * cvRate);
        bModel.SetCrossVentilation(rmN, 6, rmN, 7, 10.0 * cvRate);
        bModel.SetCrossVentilation(rmN, 7, rmN, 8, 10.0 * cvRate);
        bModel.SetCrossVentilation(rmN, 8, rmN, 9, 10.0 * cvRate);
        bModel.SetCrossVentilation(rmN, 9, rmN, 5, 10.0 * cvRate);
        bModel.SetCrossVentilation(rmN, 1, rmN, 6, 9.75 * cvRate);
        bModel.SetCrossVentilation(rmN, 2, rmN, 7, 6.5 * cvRate);
        bModel.SetCrossVentilation(rmN, 3, rmN, 8, 10.0 * cvRate);
        bModel.SetCrossVentilation(rmN, 4, rmN, 9, 9.75 * cvRate);
        bModel.SetCrossVentilation(rmN + 1, 0, rmN + 1, 1, 4.0 * cvRate);
        bModel.SetCrossVentilation(rmN + 1, 1, rmN + 1, 2, 4.0 * cvRate);
        bModel.SetCrossVentilation(rmN + 1, 2, rmN + 1, 3, 4.0 * cvRate);
        bModel.SetCrossVentilation(rmN + 1, 3, rmN + 1, 4, 4.0 * cvRate);
        bModel.SetCrossVentilation(rmN + 1, 0, rmN + 1, 5, 10.0 * cvRate);
        bModel.SetCrossVentilation(rmN + 1, 5, rmN + 1, 6, 10.0 * cvRate);
        bModel.SetCrossVentilation(rmN + 1, 6, rmN + 1, 7, 10.0 * cvRate);
        bModel.SetCrossVentilation(rmN + 1, 7, rmN + 1, 8, 10.0 * cvRate);
        bModel.SetCrossVentilation(rmN + 1, 1, rmN + 1, 5, 9.75 * cvRate);
        bModel.SetCrossVentilation(rmN + 1, 2, rmN + 1, 6, 6.5 * cvRate);
        bModel.SetCrossVentilation(rmN + 1, 3, rmN + 1, 7, 10.0 * cvRate);
        bModel.SetCrossVentilation(rmN + 1, 4, rmN + 1, 8, 6.5 * cvRate);
      }

      return bModel;
    }

    #endregion

    #endregion

    #region 地中熱交換器テスト

    private static void gshpTest()
    {
      SimpleGroundHeatExchanger ghex = new SimpleGroundHeatExchanger(7.6 * 1000d / 3600d, 4.186, 0.75, SimpleGroundHeatExchanger.Type.Vertical);
      ghex.ConstantGroundTemperature = 18.7;
      ghex.InitTemperature(22);

      using (StreamReader sReader = new StreamReader("gshpTest.csv"))
      using (StreamWriter sWriter = new StreamWriter("gshpTestResult.csv"))
      {
        string line;
        while ((line = sReader.ReadLine()) != null)
        {
          string[] dat = line.Split(',');
          ghex.Update(double.Parse(dat[1]), double.Parse(dat[0]));

          sWriter.WriteLine(line + "," + ghex.NearGroundTemperature + "," + ghex.DistantGroundTemperature + "," + ghex.HeatExchange + "," + ghex.FluidOutletTemperature);
        }
      }
    }

    #endregion

  }
}
